@@ -4,13 +4,14 @@ import logging
 from django.apps import apps
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.encoding import force_text
+from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.common.utils import get_related_field
 
 logger = logging.getLogger(name=__name__)
 
 
-class ModelPermission(object):
+class ModelPermission:
     _field_query_functions = {}
     _inheritances = {}
     _inheritances_reverse = {}
@@ -118,6 +119,7 @@ class ModelPermission(object):
         to the ACLs via a GenericRelation field.
         """
         from django.contrib.contenttypes.fields import GenericRelation
+        from mayan.apps.common.classes import ModelCopy
 
         cls._model_permissions.setdefault(model, [])
         try:
@@ -136,9 +138,13 @@ class ModelPermission(object):
         )
 
         model.add_to_class(
-            name='acls', value=GenericRelation(AccessControlList)
+            name='acls', value=GenericRelation(
+                to=AccessControlList, verbose_name=_('ACLs')
+            )
         )
 
+        ModelCopy.add_fields_lazy(model=model, field_names=('acls',))
+
     @classmethod
     def register_field_query_function(cls, model, function):
         cls._field_query_functions[model] = function
