@@ -1,9 +1,8 @@
-from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ImproperlyConfigured
 
-from mayan.apps.common.tests.mixins import TestModelTestMixin
+from mayan.apps.testing.tests.mixins import TestModelTestMixin
 from mayan.apps.permissions.tests.mixins import (
-    PermissionTestMixin, RoleTestCaseMixin, RoleTestMixin
+    RoleTestCaseMixin, RoleTestMixin
 )
 from mayan.apps.user_management.tests.mixins import UserTestCaseMixin
 
@@ -12,7 +11,7 @@ from ..models import AccessControlList
 from ..permissions import permission_acl_edit, permission_acl_view
 
 
-class ACLAPIViewTestMixin(object):
+class ACLAPIViewTestMixin:
     def _request_test_acl_create_api_view(self, extra_data=None):
         data = {'role_pk': self.test_role.pk}
 
@@ -21,7 +20,7 @@ class ACLAPIViewTestMixin(object):
 
         return self.post(
             viewname='rest_api:accesscontrollist-list',
-            kwargs=self.test_content_object_view_kwargs, data=data
+            kwargs=self.test_object_view_kwargs, data=data
         )
 
     def _request_test_acl_delete_api_view(self):
@@ -114,37 +113,29 @@ class ACLTestCaseMixin(RoleTestCaseMixin, UserTestCaseMixin):
         )
 
 
-class ACLTestMixin(PermissionTestMixin, RoleTestMixin, TestModelTestMixin):
+class ACLTestMixin(RoleTestMixin, TestModelTestMixin):
     auto_create_test_role = True
-    auto_create_test_object = False
+    auto_create_acl_test_object = False
 
     def setUp(self):
         super(ACLTestMixin, self).setUp()
         if self.auto_create_test_role:
             self._create_test_role()
 
-        if self.auto_create_test_object:
-            self._setup_test_object()
+        if self.auto_create_acl_test_object:
+            self._create_acl_test_object()
 
     def _create_test_acl(self):
         self.test_acl = AccessControlList.objects.create(
             content_object=self.test_object, role=self.test_role
         )
 
-    def _inject_test_object_content_type(self):
-        self.test_object_content_type = ContentType.objects.get_for_model(
-            model=self.test_object
-        )
+    def _create_acl_test_object(
+        self, model_name=None, create_test_permission=True,
+        register_model_permissions=True
+    ):
+        self._create_test_object(create_test_permission=create_test_permission)
 
-        self.test_content_object_view_kwargs = {
-            'app_label': self.test_object_content_type.app_label,
-            'model_name': self.test_object_content_type.model,
-            'object_id': self.test_object.pk
-        }
-
-    def _setup_test_object(self, model_name=None, register_model_permissions=True):
-        self.TestModel = self._create_test_model(model_name=model_name)
-        self.test_object = self.TestModel.objects.create()
         if register_model_permissions:
             ModelPermission.register(
                 model=self.TestModel, permissions=(
@@ -152,23 +143,12 @@ class ACLTestMixin(PermissionTestMixin, RoleTestMixin, TestModelTestMixin):
                 )
             )
 
-        self._create_test_permission()
-
-        if register_model_permissions:
-            ModelPermission.register(
-                model=self.TestModel, permissions=(
-                    self.test_permission,
-                )
-            )
-
-        self._inject_test_object_content_type()
-
-    def _setup_test_object_base(self):
-        self.test_object_base = self._setup_test_object(
+    def _create_acl_test_object_base(self):
+        self.test_object_base = self._create_acl_test_object(
             model_name='TestModelBase'
         )
 
-    def _setup_test_object_proxy(self):
+    def _create_acl_test_object_proxy(self):
         self.TestModelProxy = self._create_test_model(
             base_class=self.TestModel, model_name='TestModelProxy',
             options={
@@ -178,11 +158,11 @@ class ACLTestMixin(PermissionTestMixin, RoleTestMixin, TestModelTestMixin):
         self.test_object_proxy = self.TestModelProxy.objects.create()
 
 
-class AccessControlListViewTestMixin(object):
+class AccessControlListViewTestMixin:
     def _request_test_acl_create_get_view(self):
         return self.get(
             viewname='acls:acl_create',
-            kwargs=self.test_content_object_view_kwargs, data={
+            kwargs=self.test_object_view_kwargs, data={
                 'role': self.test_role.pk
             }
         )
@@ -190,7 +170,7 @@ class AccessControlListViewTestMixin(object):
     def _request_test_acl_create_post_view(self):
         return self.post(
             viewname='acls:acl_create',
-            kwargs=self.test_content_object_view_kwargs, data={
+            kwargs=self.test_object_view_kwargs, data={
                 'role': self.test_role.pk
             }
         )
@@ -203,7 +183,7 @@ class AccessControlListViewTestMixin(object):
     def _request_test_acl_list_view(self):
         return self.get(
             viewname='acls:acl_list',
-            kwargs=self.test_content_object_view_kwargs
+            kwargs=self.test_object_view_kwargs
         )
 
     def _request_test_acl_permission_list_get_view(self):
