@@ -1,7 +1,7 @@
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.dependencies.classes import (
-    GoogleFontDependency, JavaScriptDependency
+    GoogleFontDependency, JavaScriptDependency, PythonDependency
 )
 
 GoogleFontDependency(
@@ -51,7 +51,7 @@ JavaScriptDependency(
 )
 JavaScriptDependency(
     label=_('Select 2'), module=__name__, name='select2',
-    version_string='=4.0.3'
+    version_string='=4.0.13'
 )
 JavaScriptDependency(
     label=_('Toastr'), module=__name__, name='toastr', version_string='=2.1.4'
@@ -59,3 +59,7 @@ JavaScriptDependency(
 JavaScriptDependency(
     label=_('URI.js'), module=__name__, name='urijs', version_string='=1.19.1'
 )
+
+PythonDependency(
+    module=__name__, name='bleach', version_string='==3.1.5'
+)
