@@ -1,3 +1,5 @@
+import bleach
+
 from django.apps import apps
 from django.conf import settings
 from django.template import Library
@@ -52,6 +54,20 @@ def appearance_get_icon(icon_path):
     return import_string(dotted_path=icon_path).render()
 
 
+@register.simple_tag
+def appearance_get_user_theme_stylesheet(user):
+    if user and user.is_authenticated:
+        theme = user.theme_settings.theme
+
+        if theme:
+            return bleach.clean(
+                text=user.theme_settings.theme.stylesheet,
+                tags=('style',)
+            )
+
+    return ''
+
+
 @register.simple_tag
 def appearance_icon_render(icon_class, enable_shadow=False):
     return icon_class.render(extra_context={'enable_shadow': enable_shadow})
