@@ -4,6 +4,7 @@ from django.utils.translation import ugettext_lazy as _
 from mayan.apps.acls.classes import ModelPermission
 from mayan.apps.acls.permissions import permission_acl_edit, permission_acl_view
 from mayan.apps.common.apps import MayanAppConfig
+from mayan.apps.common.classes import ModelCopy, ModelQueryFields
 from mayan.apps.common.menus import (
     menu_facet, menu_list_facet, menu_main, menu_multi_item, menu_object,
     menu_secondary
@@ -13,7 +14,6 @@ from mayan.apps.events.links import (
     link_events_for_object, link_object_event_types_user_subcriptions_list,
 )
 from mayan.apps.events.permissions import permission_events_view
-from mayan.apps.documents.search import document_page_search, document_search
 from mayan.apps.navigation.classes import SourceColumn
 
 from .events import (
@@ -45,6 +45,11 @@ class CabinetsApp(MayanAppConfig):
     has_static_media = True
     has_tests = True
     name = 'mayan.apps.cabinets'
+    static_media_ignore_patterns = (
+        'cabinets/node_modules/jstree/component.json',
+        'cabinets/node_modules/jstree/jstree.jquery.json',
+        'cabinets/node_modules/jstree/src/*',
+    )
     verbose_name = _('Cabinets')
 
     def ready(self):
@@ -69,6 +74,24 @@ class CabinetsApp(MayanAppConfig):
 
         EventModelRegistry.register(model=Cabinet)
 
+        def cabinet_model_copy_condition(instance):
+            return instance.is_root_node()
+
+        def cabinet_unique_conditional(instance, new_instance_dictionary):
+            if instance.parent:
+                return instance.parent_id == new_instance_dictionary['parent_id'] and instance.label == new_instance_dictionary['label']
+            else:
+                return not new_instance_dictionary['parent_id'] and instance.label == new_instance_dictionary['label']
+
+        ModelCopy(
+            model=Cabinet, condition=cabinet_model_copy_condition,
+            bind_link=True, register_permission=True
+        ).add_fields(
+            field_names=('label', 'documents'), unique_conditional={
+                'label': cabinet_unique_conditional
+            }
+        )
+
         ModelEventType.register(
             model=Cabinet, event_types=(
                 event_cabinet_edited, event_cabinet_add_document,
@@ -93,6 +116,9 @@ class CabinetsApp(MayanAppConfig):
             )
         )
 
+        model_query_fields_document = ModelQueryFields(model=Document)
+        model_query_fields_document.add_prefetch_related_field(field_name='cabinets')
+
         def get_root_filter():
             return {
                 'acl_filter': {'level': 0},
@@ -130,14 +156,6 @@ class CabinetsApp(MayanAppConfig):
             ), label=_('Cabinets'), order=1, source=DocumentPageResult
         )
 
-        document_page_search.add_model_field(
-            field='document_version__document__cabinets__label',
-            label=_('Cabinets')
-        )
-        document_search.add_model_field(
-            field='cabinets__label', label=_('Cabinets')
-        )
-
         menu_facet.bind_links(
             links=(link_document_cabinet_list,), sources=(Document,)
         )
