@@ -1,3 +1,5 @@
+from mayan.apps.documents.tests.literals import TEST_SMALL_DOCUMENT_PATH
+
 from ..models import Cabinet
 
 from .literals import (
@@ -5,7 +7,7 @@ from .literals import (
 )
 
 
-class CabinetAPIViewTestMixin(object):
+class CabinetAPIViewTestMixin:
     def _request_test_cabinet_create_api_view(self, extra_data=None):
         data = {'label': TEST_CABINET_LABEL}
 
@@ -53,7 +55,24 @@ class CabinetAPIViewTestMixin(object):
         return self.get(viewname='rest_api:cabinet-list')
 
 
-class CabinetTestMixin(object):
+class CabinetDocumentUploadTestMixin:
+    def _request_upload_interactive_document_create_view(self):
+        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+            return self.post(
+                viewname='sources:document_upload_interactive', kwargs={
+                    'source_id': self.test_source.pk
+                }, data={
+                    'document_type_id': self.test_document_type.pk,
+                    'source-file': file_object,
+                    'cabinets': Cabinet.objects.values_list('pk', flat=True)
+                }
+            )
+
+    def _request_wizard_view(self):
+        return self.get(viewname='sources:document_create_multiple')
+
+
+class CabinetTestMixin:
     def setUp(self):
         super(CabinetTestMixin, self).setUp()
         if not hasattr(self, 'test_cabinets'):
@@ -69,7 +88,7 @@ class CabinetTestMixin(object):
         )
 
 
-class CabinetViewTestMixin(object):
+class CabinetViewTestMixin:
     def setUp(self):
         super(CabinetViewTestMixin, self).setUp()
         if not hasattr(self, 'test_cabinets'):
@@ -165,7 +184,7 @@ class CabinetViewTestMixin(object):
         )
 
 
-class DocumentCabinetAPIViewTestMixin(object):
+class DocumentCabinetAPIViewTestMixin:
     def _request_test_document_cabinet_list_view(self):
         return self.get(
             viewname='rest_api:document-cabinet-list', kwargs={
@@ -174,7 +193,7 @@ class DocumentCabinetAPIViewTestMixin(object):
         )
 
 
-class DocumentCabinetViewTestMixin(object):
+class DocumentCabinetViewTestMixin:
     def _request_test_document_cabinet_list_view(self):
         return self.get(
             viewname='cabinets:document_cabinet_list', kwargs={
