@@ -1,6 +1,6 @@
-from mayan.apps.common.tests.base import GenericViewTestCase
 from mayan.apps.documents.permissions import permission_document_view
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
+from mayan.apps.testing.tests.base import GenericViewTestCase
 
 from ..models import Cabinet
 from ..permissions import (
