@@ -4,6 +4,7 @@ from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.acls.classes import ModelPermission
 from mayan.apps.common.apps import MayanAppConfig
+from mayan.apps.common.classes import ModelQueryFields
 from mayan.apps.common.menus import (
     menu_facet, menu_main, menu_multi_item, menu_secondary
 )
@@ -31,8 +32,6 @@ from .permissions import (
     permission_document_check_in, permission_document_check_in_override,
     permission_document_check_out, permission_document_check_out_detail_view
 )
-from .tasks import task_check_expired_check_outs  # NOQA
-# This import is required so that celerybeat can find the task
 
 
 class CheckoutsApp(MayanAppConfig):
@@ -89,6 +88,9 @@ class CheckoutsApp(MayanAppConfig):
             model=DocumentCheckout, related='document'
         )
 
+        model_query_fields_document = ModelQueryFields(model=Document)
+        model_query_fields_document.add_select_related_field(field_name='documentcheckout')
+
         SourceColumn(
             attribute='get_user_display', include_label=True, order=99,
             source=CheckedOutDocument
