@@ -1,4 +1,3 @@
-from django.utils.encoding import python_2_unicode_compatible
 from django.utils.translation import ugettext
 
 
@@ -16,7 +15,6 @@ class DocumentNotCheckedOut(DocumentCheckoutError):
         return ugettext('Document not checked out.')
 
 
-@python_2_unicode_compatible
 class DocumentAlreadyCheckedOut(DocumentCheckoutError):
     """
     Raised when trying to checkout an already checkedout document.
