@@ -4,7 +4,7 @@ from django.conf import settings
 from django.core.exceptions import ValidationError
 from django.db import models, transaction
 from django.urls import reverse
-from django.utils.encoding import force_text, python_2_unicode_compatible
+from django.utils.encoding import force_text
 from django.utils.timezone import now
 from django.utils.translation import ugettext_lazy as _
 
@@ -20,7 +20,6 @@ from .managers import (
 logger = logging.getLogger(name=__name__)
 
 
-@python_2_unicode_compatible
 class DocumentCheckout(models.Model):
     """
     Model to store the state and information of a document checkout.
@@ -74,7 +73,7 @@ class DocumentCheckout(models.Model):
     def get_absolute_url(self):
         return reverse(
             viewname='checkouts:check_out_info', kwargs={
-                'document_id': self.document.pk
+                'document_id': self.document_id
             }
         )
 
