@@ -1,9 +1,9 @@
 import time
 
-from mayan.apps.common.tests.base import BaseTestCase
 from mayan.apps.documents.tests.base import GenericDocumentTestCase
 from mayan.apps.documents.tests.literals import TEST_SMALL_DOCUMENT_PATH
 from mayan.apps.documents.tests.mixins import DocumentTestMixin
+from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..exceptions import (
     DocumentAlreadyCheckedOut, DocumentNotCheckedOut,
@@ -88,7 +88,7 @@ class NewVersionBlockTestCase(
         NewVersionBlock.objects.block(document=self.test_document)
 
         with self.assertRaises(expected_exception=NewDocumentVersionNotAllowed):
-            with open(TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+            with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
                 self.test_document.new_version(file_object=file_object)
 
     def test_unblocking(self):
@@ -120,5 +120,5 @@ class NewVersionBlockTestCase(
         self._check_out_test_document()
 
         with self.assertRaises(expected_exception=NewDocumentVersionNotAllowed):
-            with open(TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+            with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
                 self.test_document.new_version(file_object=file_object)
