@@ -1,15 +1,10 @@
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.dependencies.classes import (
-    BinaryDependency, PythonDependency
-)
+from mayan.apps.dependencies.classes import PythonDependency
 from mayan.apps.dependencies.environments import (
     environment_build, environment_development, environment_documentation,
-    environment_testing
 )
 
-from .literals import DEFAULT_FIREFOX_GECKODRIVER_PATH
-
 PythonDependency(
     copyright_text='''
         Copyright (c) Django Software Foundation and individual contributors.
@@ -39,7 +34,7 @@ PythonDependency(
         ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
         (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
         SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-    ''', module=__name__, name='django', version_string='==2.2.12'
+    ''', module=__name__, name='django', version_string='==2.2.16'
 )
 PythonDependency(
     copyright_text='''
@@ -64,43 +59,6 @@ PythonDependency(
         SOFTWARE.
     ''', module=__name__, name='PyYAML', version_string='==5.3.1'
 )
-PythonDependency(
-    module=__name__, name='django-formtools', version_string='==2.2'
-)
-PythonDependency(
-    copyright_text='''
-        Copyright (c) James Pacileo and contributors.
-        All rights reserved.
-
-        Redistribution and use in source and binary forms, with or without modification,
-        are permitted provided that the following conditions are met:
-
-        1. Redistributions of source code must retain the above copyright notice,
-        this list of conditions and the following disclaimer.
-
-        2. Redistributions in binary form must reproduce the above copyright
-        notice, this list of conditions and the following disclaimer in the
-        documentation and/or other materials provided with the distribution.
-
-        3. Neither the name of Django nor the names of its contributors may be used
-        to endorse or promote products derived from this software without
-        specific prior written permission.
-
-        THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
-        ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-        WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-        DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
-        ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
-        (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
-        LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
-        ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-        (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-        SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-    ''', module=__name__, name='django-pure-pagination', version_string='==0.3.0'
-)
-PythonDependency(
-    module=__name__, name='django-mathfilters', version_string='==1.0.0'
-)
 PythonDependency(
     copyright_text='''
         Copyright (c) 2009-2015, Carl Meyer and contributors
@@ -158,47 +116,6 @@ PythonDependency(
         CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
     ''', module=__name__, name='django-mptt', version_string='==0.11.0'
 )
-PythonDependency(
-    module=__name__, name='django-stronghold', version_string='==0.4.0'
-)
-PythonDependency(
-    copyright_text='''
-        Copyright (c) 2011-2015 Mikhail Korobov
-
-        Permission is hereby granted, free of charge, to any person obtaining a copy
-        of this software and associated documentation files (the "Software"), to deal
-        in the Software without restriction, including without limitation the rights
-        to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-        copies of the Software, and to permit persons to whom the Software is
-        furnished to do so, subject to the following conditions:
-
-        The above copyright notice and this permission notice shall be included in
-        all copies or substantial portions of the Software.
-
-        THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-        IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-        FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-        AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-        LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-        OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-        THE SOFTWARE.
-    ''', module=__name__, name='django-widget-tweaks', version_string='==1.4.8'
-)
-PythonDependency(
-    module=__name__, name='furl', version_string='==2.1.0'
-)
-PythonDependency(
-    module=__name__, name='extract-msg', version_string='==0.23.3'
-)
-PythonDependency(
-    module=__name__, name='gevent', version_string='==1.4.0'
-)
-PythonDependency(
-    module=__name__, name='gunicorn', version_string='==20.0.4'
-)
-PythonDependency(
-    module=__name__, name='mock', version_string='==4.0.2'
-)
 PythonDependency(
     copyright_text='''
         Author: Christian Theune
@@ -226,7 +143,7 @@ PythonDependency(
         LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
         FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
         DEALINGS IN THE SOFTWARE.
-    ''', module=__name__, name='pytz', version_string='==2019.1'
+    ''', module=__name__, name='pytz', version_string='==2020.1'
 )
 PythonDependency(
     module=__name__, name='requests', version_string='==2.23.0'
@@ -252,10 +169,7 @@ PythonDependency(
         LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
         OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
         THE SOFTWARE.
-    ''', module=__name__, name='sh', version_string='==1.12.14'
-)
-PythonDependency(
-    module=__name__, name='whitenoise', version_string='==5.0.1'
+    ''', module=__name__, name='sh', version_string='==1.13.1'
 )
 
 # Development
@@ -274,22 +188,26 @@ PythonDependency(
 )
 PythonDependency(
     environment=environment_development, module=__name__,
-    name='django-extensions', version_string='==2.2.8'
+    name='django-extensions', version_string='==2.2.9'
 )
 PythonDependency(
     environment=environment_development, help_text=_(
         'Used to allow offline translation of the code text strings.'
-    ), module=__name__, name='django-rosetta', version_string='==0.9.3'
+    ), module=__name__, name='django-rosetta', version_string='==0.9.4'
+)
+PythonDependency(
+    environment=environment_development, module=__name__,
+    name='django-silk', version_string='==4.0.1'
 )
 PythonDependency(
     environment=environment_development, help_text=_(
         'Provides style checking.'
-    ), module=__name__, name='flake8', version_string='==3.7.9'
+    ), module=__name__, name='flake8', version_string='==3.8.3'
 )
 PythonDependency(
     environment=environment_development, help_text=_(
         'Command line environment with autocompletion.'
-    ), module=__name__, name='ipython', version_string='==7.13.0'
+    ), module=__name__, name='ipython', version_string='==7.15.0'
 )
 PythonDependency(
     environment=environment_development, help_text=_(
@@ -298,48 +216,11 @@ PythonDependency(
 )
 PythonDependency(
     environment=environment_development,
-    module=__name__, name='safety', version_string='==1.8.7'
+    module=__name__, name='safety', version_string='==1.9.0'
 )
 PythonDependency(
     environment=environment_development,
-    module=__name__, name='transifex-client', version_string='==0.13.8'
-)
-
-# Testing
-
-BinaryDependency(
-    environment=environment_testing, label='firefox-geckodriver',
-    module=__name__, name='geckodriver',
-    path=DEFAULT_FIREFOX_GECKODRIVER_PATH
-)
-PythonDependency(
-    environment=environment_testing, module=__name__, name='coverage',
-    version_string='==5.0.4'
-)
-PythonDependency(
-    environment=environment_testing, module=__name__, name='coveralls',
-    version_string='==1.11.1'
-)
-PythonDependency(
-    environment=environment_testing, module=__name__,
-    name='django-test-migrations', version_string='==0.2.0'
-)
-PythonDependency(
-    environment=environment_testing,
-    module=__name__, name='django-test-without-migrations',
-    version_string='==0.6'
-)
-PythonDependency(
-    environment=environment_testing, module=__name__, name='selenium',
-    version_string='==3.141.0'
-)
-PythonDependency(
-    environment=environment_testing, module=__name__, name='tox',
-    version_string='==3.14.5'
-)
-PythonDependency(
-    environment=environment_testing, module=__name__, name='psutil',
-    version_string='==5.7.0'
+    module=__name__, name='transifex-client', version_string='==0.13.10'
 )
 
 # Build
@@ -357,7 +238,7 @@ PythonDependency(
 
 PythonDependency(
     environment=environment_documentation, module=__name__, name='Sphinx',
-    version_string='==2.4.4'
+    version_string='==3.0.4'
 )
 PythonDependency(
     environment=environment_documentation, module=__name__,
@@ -382,10 +263,8 @@ PythonDependency(
 PythonDependency(
     environment=environment_documentation, module=__name__,
     name='sphinxcontrib-spelling',
-    version_string='==4.3.0'
+    version_string='==5.0.0'
 )
-# sphinx-autobuild has a dependency on Tornado,
-# but Tornado 6.0 dropped support for Python 2.7
 PythonDependency(
     environment=environment_documentation, module=__name__, name='tornado',
     version_string='==6.0.4'
