@@ -11,15 +11,16 @@ import sh
 from django.apps import apps
 from django.core.exceptions import ImproperlyConfigured
 from django.db import transaction
-from django.utils.encoding import force_text, python_2_unicode_compatible
+from django.utils.encoding import force_text
 from django.utils.functional import cached_property
+from django.utils.module_loading import import_string
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.appearance.classes import Icon
-from mayan.apps.common.compressed_files import MsgArchive
-from mayan.apps.common.literals import MSG_MIME_TYPES
 from mayan.apps.mimetype.api import get_mimetype
 from mayan.apps.navigation.classes import Link
+from mayan.apps.storage.compressed_files import MsgArchive
+from mayan.apps.storage.literals import MSG_MIME_TYPES
 from mayan.apps.storage.settings import setting_temporary_directory
 from mayan.apps.storage.utils import (
     NamedTemporaryFile, fs_cleanup, mkdtemp
@@ -30,7 +31,12 @@ from .literals import (
     CONVERTER_OFFICE_FILE_MIMETYPES, DEFAULT_LIBREOFFICE_PATH,
     DEFAULT_PAGE_NUMBER, DEFAULT_PILLOW_FORMAT
 )
-from .settings import setting_graphics_backend_arguments
+from .settings import (
+    setting_graphics_backend, setting_graphics_backend_arguments
+)
+
+logger = logging.getLogger(name=__name__)
+
 
 libreoffice_path = setting_graphics_backend_arguments.value.get(
     'libreoffice_path', DEFAULT_LIBREOFFICE_PATH
@@ -39,7 +45,11 @@ libreoffice_path = setting_graphics_backend_arguments.value.get(
 logger = logging.getLogger(name=__name__)
 
 
-class ConverterBase(object):
+class ConverterBase:
+    @staticmethod
+    def get_converter_class():
+        return import_string(dotted_path=setting_graphics_backend.value)
+
     def __init__(self, file_object, mime_type=None):
         self.file_object = file_object
         self.image = None
@@ -100,7 +110,7 @@ class ConverterBase(object):
         self.file_object.seek(0)
 
         try:
-            self.image = Image.open(self.file_object)
+            self.image = Image.open(fp=self.file_object)
         except IOError:
             # Cannot identify image file
             self.image = self.convert(page_number=page_number)
@@ -193,7 +203,7 @@ class ConverterBase(object):
 
         # Copy the LibreOffice output file to a new named temporary file
         # and delete the converted file
-        with open(converted_file_path, mode='rb') as converted_file_object:
+        with open(file=converted_file_path, mode='rb') as converted_file_object:
             shutil.copyfileobj(
                 fsrc=converted_file_object, fdst=temporary_converted_file_object
             )
@@ -239,8 +249,7 @@ class ConverterBase(object):
             self.image = transformation.execute_on(image=self.image)
 
 
-@python_2_unicode_compatible
-class Layer(object):
+class Layer:
     _registry = {}
 
     @classmethod
@@ -431,7 +440,7 @@ class LayerLink(Link):
         )
 
 
-class LayerLinkKwargsFactory(object):
+class LayerLinkKwargsFactory:
     def __init__(self, layer_name=None, variable_name='resolved_object'):
         self.layer_name = layer_name
         self.variable_name = variable_name
