@@ -1,21 +1,82 @@
 import logging
+import uuid
 
 from django.contrib.contenttypes.fields import GenericForeignKey
 from django.contrib.contenttypes.models import ContentType
 from django.db import models
 from django.db.models import Max
-from django.utils.encoding import python_2_unicode_compatible
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import ugettext, ugettext_lazy as _
+
+from mayan.apps.common.validators import (
+    YAMLValidator, validate_internal_name
+)
+from mayan.apps.events.classes import EventManagerSave
+from mayan.apps.events.decorators import method_event
+from mayan.apps.storage.classes import DefinedStorageLazy
 
 from .classes import Layer
-from .managers import LayerTransformationManager
+from .events import event_asset_created, event_asset_edited
+from .literals import STORAGE_NAME_ASSETS
+from .managers import LayerTransformationManager, ObjectLayerManager
 from .transformations import BaseTransformation
-from .validators import YAMLValidator
 
 logger = logging.getLogger(name=__name__)
 
 
-@python_2_unicode_compatible
+def upload_to(instance, filename):
+    return 'converter-asset-{}'.format(uuid.uuid4().hex)
+
+
+class Asset(models.Model):
+    """
+    This model keeps track of files that will be available for use with
+    transformations.
+    """
+    label = models.CharField(
+        max_length=96, unique=True, verbose_name=_('Label')
+    )
+    internal_name = models.CharField(
+        db_index=True, help_text=_(
+            'This value will be used when referencing this asset. '
+            'Can only contain letters, numbers, and underscores.'
+        ), max_length=255, unique=True, validators=[validate_internal_name],
+        verbose_name=_('Internal name')
+    )
+    file = models.FileField(
+        storage=DefinedStorageLazy(name=STORAGE_NAME_ASSETS),
+        upload_to=upload_to, verbose_name=_('File')
+    )
+
+    class Meta:
+        ordering = ('label',)
+        verbose_name = _('Asset')
+        verbose_name_plural = _('Assets')
+
+    def __str__(self):
+        return self.label
+
+    def delete(self, *args, **kwargs):
+        self.file.storage.delete(name=self.file.name)
+        return super().delete(*args, **kwargs)
+
+    def open(self):
+        return self.file.storage.open(name=self.file.name)
+
+    @method_event(
+        event_manager_class=EventManagerSave,
+        created={
+            'event': event_asset_created,
+            'target': 'self',
+        },
+        edited={
+            'event': event_asset_edited,
+            'target': 'self',
+        }
+    )
+    def save(self, *args, **kwargs):
+        return super().save(*args, **kwargs)
+
+
 class StoredLayer(models.Model):
     name = models.CharField(
         max_length=64, unique=True, verbose_name=_('Name')
@@ -24,14 +85,14 @@ class StoredLayer(models.Model):
         db_index=True, unique=True, verbose_name=_('Order')
     )
 
-    def __str__(self):
-        return self.name
-
     class Meta:
         ordering = ('order',)
         verbose_name = _('Stored layer')
         verbose_name_plural = _('Stored layers')
 
+    def __str__(self):
+        return self.name
+
     def get_layer(self):
         return Layer.get(name=self.name)
 
@@ -48,14 +109,25 @@ class ObjectLayer(models.Model):
         verbose_name=_('Stored layer')
     )
 
+    objects = ObjectLayerManager()
+
     class Meta:
         ordering = ('stored_layer__order',)
         unique_together = ('content_type', 'object_id', 'stored_layer')
         verbose_name = _('Object layer')
         verbose_name_plural = _('Object layers')
 
+    def get_next_order(self):
+        last_order = self.transformations.aggregate(
+            Max('order')
+        )['order__max']
+
+        if last_order is not None:
+            return last_order + 1
+        else:
+            return 0
+
 
-@python_2_unicode_compatible
 class LayerTransformation(models.Model):
     """
     Model that stores the transformation and transformation arguments
@@ -78,10 +150,7 @@ class LayerTransformation(models.Model):
             'unchanged, an automatic order value will be assigned.'
         ), verbose_name=_('Order')
     )
-    name = models.CharField(
-        choices=BaseTransformation.get_transformation_choices(),
-        max_length=128, verbose_name=_('Name')
-    )
+    name = models.CharField(max_length=128, verbose_name=_('Name'))
     arguments = models.TextField(
         blank=True, help_text=_(
             'Enter the arguments for the transformation as a YAML '
@@ -99,16 +168,15 @@ class LayerTransformation(models.Model):
         verbose_name_plural = _('Layer transformations')
 
     def __str__(self):
-        return self.get_name_display()
+        try:
+            return str(BaseTransformation.get(name=self.name))
+        except KeyError:
+            return ugettext('Unknown transformation class')
 
     def get_transformation_class(self):
         return BaseTransformation.get(name=self.name)
 
     def save(self, *args, **kwargs):
         if not self.order:
-            last_order = LayerTransformation.objects.filter(
-                object_layer=self.object_layer
-            ).aggregate(Max('order'))['order__max']
-            if last_order is not None:
-                self.order = last_order + 1
+            self.order = self.object_layer.get_next_order()
         super(LayerTransformation, self).save(*args, **kwargs)
