@@ -1,6 +1,9 @@
+import os
+
+from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.smart_settings.classes import Namespace
+from mayan.apps.smart_settings.classes import SettingNamespace
 
 from .literals import (
     DEFAULT_LIBREOFFICE_PATH, DEFAULT_PDFTOPPM_DPI, DEFAULT_PDFTOPPM_FORMAT,
@@ -9,7 +12,7 @@ from .literals import (
 )
 from .setting_migrations import ConvertSettingMigration
 
-namespace = Namespace(
+namespace = SettingNamespace(
     label=_('Converter'), migration_class=ConvertSettingMigration,
     name='converter', version='0002'
 )
@@ -32,3 +35,17 @@ setting_graphics_backend_arguments = namespace.add_setting(
         'Configuration options for the graphics conversion backend.'
     ), global_name='CONVERTER_GRAPHICS_BACKEND_ARGUMENTS'
 )
+setting_storage_backend = namespace.add_setting(
+    default='django.core.files.storage.FileSystemStorage',
+    global_name='CONVERTER_ASSET_STORAGE_BACKEND', help_text=_(
+        'Path to the Storage subclass to use when storing assets.'
+    )
+)
+setting_storage_backend_arguments = namespace.add_setting(
+    global_name='CONVERTER_ASSET_STORAGE_BACKEND_ARGUMENTS',
+    default={
+        'location': os.path.join(settings.MEDIA_ROOT, 'converter_assets')
+    }, help_text=_(
+        'Arguments to pass to the CONVERTER_ASSET_STORAGE_BACKEND.'
+    )
+)
