@@ -1,5 +1,5 @@
 import json
-from importlib import import_module
+from io import BytesIO
 import logging
 from packaging import version
 from pathlib import Path
@@ -13,16 +13,13 @@ import requests
 from semver import max_satisfying
 
 from django.apps import apps
-from django.utils.encoding import (
-    force_bytes, force_text, python_2_unicode_compatible
-)
+from django.utils.encoding import force_text
 from django.utils.functional import cached_property
 from django.utils.module_loading import import_string
-from django.utils.six import PY3
 from django.utils.termcolors import colorize
 from django.utils.translation import ugettext_lazy as _, ugettext
 
-from mayan.apps.common.compat import FileNotFoundErrorException
+from mayan.apps.common.class_mixins import AppsModuleLoaderMixin
 from mayan.apps.common.utils import resolve_attribute
 from mayan.apps.storage.utils import mkdtemp, patch_files as storage_patch_files
 
@@ -33,7 +30,7 @@ from .exceptions import DependenciesException
 logger = logging.getLogger(name=__name__)
 
 
-class Provider(object):
+class Provider:
     """Base provider class"""
 
 
@@ -53,8 +50,7 @@ class OperatingSystemProvider(Provider):
     """Placeholder for the OS provider"""
 
 
-@python_2_unicode_compatible
-class DependencyGroup(object):
+class DependencyGroup:
     _registry = {}
 
     @classmethod
@@ -100,8 +96,7 @@ class DependencyGroup(object):
         raise KeyError('Entry not found.')
 
 
-@python_2_unicode_compatible
-class DependencyGroupEntry(object):
+class DependencyGroupEntry:
     def __init__(self, dependency_group, label, name, help_text=None):
         self.dependency_group = dependency_group
         self.help_text = help_text or ''
@@ -120,21 +115,10 @@ class DependencyGroupEntry(object):
         return Dependency.return_sorted(dependencies=dependencies)
 
 
-class Dependency(object):
+class Dependency(AppsModuleLoaderMixin):
+    _loader_module_name = 'dependencies'
     _registry = {}
 
-    @staticmethod
-    def initialize():
-        for app in apps.get_app_configs():
-            try:
-                import_module('{}.dependencies'.format(app.name))
-            except ImportError as exception:
-                if force_text(exception) not in ('No module named dependencies', 'No module named \'{}.dependencies\''.format(app.name)):
-                    logger.error(
-                        'Error importing %s dependencies.py file; %s', app.name,
-                        exception
-                    )
-
     @staticmethod
     def return_sorted(dependencies):
         return sorted(dependencies, key=lambda x: x.get_label())
@@ -444,15 +428,11 @@ class JavaScriptDependency(Dependency):
     def _check(self):
         try:
             package_info = self._read_package_file()
-        except FileNotFoundErrorException:
+        except FileNotFoundError:
             return False
 
-        if PY3:
-            versions = [package_info['version']]
-            version_string = self.version_string
-        else:
-            versions = [force_bytes(package_info['version'])]
-            version_string = force_bytes(self.version_string)
+        versions = [package_info['version']]
+        version_string = self.version_string
 
         return max_satisfying(
             versions=versions, range_=version_string,
@@ -527,17 +507,8 @@ class JavaScriptDependency(Dependency):
                 shutil.copyfileobj(fsrc=response.raw, fdst=file_object)
 
     def get_best_version(self):
-        # PY3
-        # node-semver does a direct str() comparison which means
-        # different things on PY2 and PY3
-        # Typecast to str in PY3 which is unicode and
-        # bytes in PY2 which is str to fool node-semver
-        if PY3:
-            versions = self.versions
-            version_string = self.version_string
-        else:
-            versions = [force_bytes(version) for version in self.versions]
-            version_string = force_bytes(self.version_string)
+        versions = self.versions
+        version_string = self.version_string
 
         return max_satisfying(
             versions=versions, range_=version_string, loose=True
@@ -554,7 +525,7 @@ class JavaScriptDependency(Dependency):
 
         try:
             package_info = self._read_package_file()
-        except FileNotFoundErrorException:
+        except FileNotFoundError:
             return super(JavaScriptDependency, self).get_copyright()
         else:
             copyright_text.append(
@@ -577,7 +548,7 @@ class JavaScriptDependency(Dependency):
 
         try:
             description = self._read_package_file().get('description')
-        except FileNotFoundErrorException:
+        except FileNotFoundError:
             return super(JavaScriptDependency, self).get_help_text()
         else:
             return description
@@ -650,7 +621,7 @@ class JavaScriptDependency(Dependency):
             )
 
 
-class PythonVersion(object):
+class PythonVersion:
     def __init__(self, string):
         self.version = version.parse(string)
 
@@ -754,7 +725,14 @@ class GoogleFontDependency(Dependency):
                         path_font_filename = self.path_cache / font_filename
                         with path_font_filename.open(mode='wb') as font_file_object:
                             with requests.get(font_url, stream=True) as response:
-                                shutil.copyfileobj(fsrc=response.raw, fdst=font_file_object)
+                                # Use response.content instead of response.raw
+                                # to allow requests to handle gzip and deflate
+                                # content.
+                                # https://2.python-requests.org/en/master/user/quickstart/#binary-response-content
+                                shutil.copyfileobj(
+                                    fsrc=BytesIO(response.content),
+                                    fdst=font_file_object
+                                )
 
                         line = line.replace(font_url, font_filename)
 
