@@ -1,12 +1,24 @@
 from datetime import date
 
+from django.utils.module_loading import import_string
+
+from .settings import (
+    setting_gpg_backend, setting_gpg_backend_arguments
+)
+
+
+class GPGBackend:
+    @staticmethod
+    def get_instance():
+        return import_string(dotted_path=setting_gpg_backend.value)(
+            **setting_gpg_backend_arguments.value
+        )
 
-class GPGBackend(object):
     def __init__(self, **kwargs):
         self.kwargs = kwargs
 
 
-class KeyStub(object):
+class KeyStub:
     def __init__(self, raw):
         self.fingerprint = raw['keyid']
         self.key_type = raw['type']
@@ -23,7 +35,7 @@ class KeyStub(object):
         return self.fingerprint[-8:]
 
 
-class SignatureVerification(object):
+class SignatureVerification:
     def __init__(self, raw):
         self.user_id = raw['username']
         self.status = raw['status']
