@@ -5,8 +5,8 @@ import mock
 
 from django.utils.encoding import force_bytes
 
-from mayan.apps.common.tests.base import BaseTestCase
 from mayan.apps.storage.utils import TemporaryFile
+from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..exceptions import (
     DecryptionError, KeyDoesNotExist, NeedPassphrase, PassphraseError,
@@ -64,7 +64,7 @@ class KeyTestCase(BaseTestCase):
         cleartext_file.close()
 
     def test_embedded_verification_no_key(self):
-        with open(TEST_SIGNED_FILE, mode='rb') as signed_file:
+        with open(file=TEST_SIGNED_FILE, mode='rb') as signed_file:
             result = Key.objects.verify_file(signed_file)
 
         self.assertTrue(result.key_id in TEST_KEY_PRIVATE_FINGERPRINT)
@@ -72,7 +72,7 @@ class KeyTestCase(BaseTestCase):
     def test_embedded_verification_with_key(self):
         Key.objects.create(key_data=TEST_KEY_PRIVATE_DATA)
 
-        with open(TEST_SIGNED_FILE, mode='rb') as signed_file:
+        with open(file=TEST_SIGNED_FILE, mode='rb') as signed_file:
             result = Key.objects.verify_file(signed_file)
 
         self.assertEqual(result.fingerprint, TEST_KEY_PRIVATE_FINGERPRINT)
@@ -80,7 +80,7 @@ class KeyTestCase(BaseTestCase):
     def test_embedded_verification_with_correct_fingerprint(self):
         Key.objects.create(key_data=TEST_KEY_PRIVATE_DATA)
 
-        with open(TEST_SIGNED_FILE, mode='rb') as signed_file:
+        with open(file=TEST_SIGNED_FILE, mode='rb') as signed_file:
             result = Key.objects.verify_file(
                 signed_file, key_fingerprint=TEST_KEY_PRIVATE_FINGERPRINT
             )
@@ -91,14 +91,14 @@ class KeyTestCase(BaseTestCase):
     def test_embedded_verification_with_incorrect_fingerprint(self):
         Key.objects.create(key_data=TEST_KEY_PRIVATE_DATA)
 
-        with open(TEST_SIGNED_FILE, mode='rb') as signed_file:
+        with open(file=TEST_SIGNED_FILE, mode='rb') as signed_file:
             with self.assertRaises(expected_exception=KeyDoesNotExist):
                 Key.objects.verify_file(signed_file, key_fingerprint='999')
 
     def test_signed_file_decryption(self):
         Key.objects.create(key_data=TEST_KEY_PRIVATE_DATA)
 
-        with open(TEST_SIGNED_FILE, mode='rb') as signed_file:
+        with open(file=TEST_SIGNED_FILE, mode='rb') as signed_file:
             result = Key.objects.decrypt_file(file_object=signed_file)
 
         self.assertEqual(result.read(), TEST_SIGNED_FILE_CONTENT)
@@ -114,8 +114,8 @@ class KeyTestCase(BaseTestCase):
         cleartext_file.close()
 
     def test_detached_verification_no_key(self):
-        with open(TEST_DETACHED_SIGNATURE, mode='rb') as signature_file:
-            with open(TEST_FILE, mode='rb') as test_file:
+        with open(file=TEST_DETACHED_SIGNATURE, mode='rb') as signature_file:
+            with open(file=TEST_FILE, mode='rb') as test_file:
                 result = Key.objects.verify_file(
                     file_object=test_file, signature_file=signature_file
                 )
@@ -125,8 +125,8 @@ class KeyTestCase(BaseTestCase):
     def test_detached_verification_with_key(self):
         Key.objects.create(key_data=TEST_KEY_PRIVATE_DATA)
 
-        with open(TEST_DETACHED_SIGNATURE, mode='rb') as signature_file:
-            with open(TEST_FILE, mode='rb') as test_file:
+        with open(file=TEST_DETACHED_SIGNATURE, mode='rb') as signature_file:
+            with open(file=TEST_FILE, mode='rb') as test_file:
                 result = Key.objects.verify_file(
                     file_object=test_file, signature_file=signature_file
                 )
@@ -138,7 +138,7 @@ class KeyTestCase(BaseTestCase):
         key = Key.objects.create(key_data=TEST_KEY_PRIVATE_DATA)
 
         with self.assertRaises(expected_exception=NeedPassphrase):
-            with open(TEST_FILE, mode='rb') as test_file:
+            with open(file=TEST_FILE, mode='rb') as test_file:
                 key.sign_file(
                     file_object=test_file, detached=True,
                 )
@@ -147,7 +147,7 @@ class KeyTestCase(BaseTestCase):
         key = Key.objects.create(key_data=TEST_KEY_PRIVATE_DATA)
 
         with self.assertRaises(expected_exception=PassphraseError):
-            with open(TEST_FILE, mode='rb') as test_file:
+            with open(file=TEST_FILE, mode='rb') as test_file:
                 key.sign_file(
                     file_object=test_file, detached=True,
                     passphrase='bad passphrase'
@@ -156,7 +156,7 @@ class KeyTestCase(BaseTestCase):
     def test_detached_signing_with_passphrase(self):
         key = Key.objects.create(key_data=TEST_KEY_PRIVATE_DATA)
 
-        with open(TEST_FILE, mode='rb') as test_file:
+        with open(file=TEST_FILE, mode='rb') as test_file:
             detached_signature = key.sign_file(
                 file_object=test_file, detached=True,
                 passphrase=TEST_KEY_PRIVATE_PASSPHRASE
@@ -166,7 +166,7 @@ class KeyTestCase(BaseTestCase):
         signature_file.write(force_bytes(detached_signature))
         signature_file.seek(0)
 
-        with open(TEST_FILE, mode='rb') as test_file:
+        with open(file=TEST_FILE, mode='rb') as test_file:
             result = Key.objects.verify_file(
                 file_object=test_file, signature_file=signature_file
             )
