@@ -19,7 +19,11 @@ class CommentEventsTestCase(
     DocumentCommentTestMixin, DocumentCommentViewTestMixin,
     GenericDocumentViewTestCase
 ):
-    def test_comment_create_event_no_permissions(self):
+    def setUp(self):
+        super().setUp()
+        self._create_test_user()
+
+    def test_comment_create_event_no_permission(self):
         action_count = Action.objects.count()
 
         response = self._request_test_comment_create_view()
@@ -46,7 +50,7 @@ class CommentEventsTestCase(
         self.assertEqual(event.target, comment)
         self.assertEqual(event.verb, event_document_comment_created.id)
 
-    def test_comment_delete_event_no_permissions(self):
+    def test_comment_delete_event_no_permission(self):
         self._create_test_comment()
 
         action_count = Action.objects.count()
@@ -78,7 +82,7 @@ class CommentEventsTestCase(
         self.assertEqual(event.target, self.test_document)
         self.assertEqual(event.verb, event_document_comment_deleted.id)
 
-    def test_comment_edit_event_no_permissions(self):
+    def test_comment_edit_event_no_permission(self):
         self._create_test_comment()
 
         action_count = Action.objects.count()
