@@ -6,6 +6,10 @@ from .mixins import DocumentCommentTestMixin
 class DocumentCommentModelTestCase(
     DocumentCommentTestMixin, GenericDocumentViewTestCase
 ):
+    def setUp(self):
+        super().setUp()
+        self._create_test_user()
+
     def test_method_get_absolute_url(self):
         self._create_test_comment()
 
