@@ -2,12 +2,12 @@ from django.template import RequestContext
 from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.common.generics import (
+from mayan.apps.documents.models import Document
+from mayan.apps.views.generics import (
     SingleObjectCreateView, SingleObjectDeleteView, SingleObjectDetailView,
     SingleObjectEditView, SingleObjectListView
 )
-from mayan.apps.common.mixins import ExternalObjectMixin
-from mayan.apps.documents.models import Document
+from mayan.apps.views.mixins import ExternalObjectMixin
 
 from .forms import DocumentCommentDetailForm
 from .icons import icon_comments_for_document
@@ -46,20 +46,12 @@ class DocumentCommentCreateView(ExternalObjectMixin, SingleObjectCreateView):
     def get_queryset(self):
         return self.external_object.comments.all()
 
-    def get_save_extra_data(self):
-        return {
-            '_user': self.request.user,
-        }
-
 
 class DocumentCommentDeleteView(SingleObjectDeleteView):
     model = Comment
     object_permission = permission_document_comment_delete
     pk_url_kwarg = 'comment_id'
 
-    def get_delete_extra_data(self):
-        return {'_user': self.request.user}
-
     def get_extra_context(self):
         return {
             'comment': self.object,
@@ -68,10 +60,15 @@ class DocumentCommentDeleteView(SingleObjectDeleteView):
             'title': _('Delete comment: %s?') % self.object,
         }
 
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user,
+        }
+
     def get_post_action_redirect(self):
         return reverse(
             viewname='comments:comments_for_document', kwargs={
-                'document_id': self.object.document.pk
+                'document_id': self.object.document_id
             }
         )
 
@@ -97,9 +94,6 @@ class DocumentCommentEditView(SingleObjectEditView):
     pk_url_kwarg = 'comment_id'
     object_permission = permission_document_comment_edit
 
-    def get_save_extra_data(self):
-        return {'_user': self.request.user}
-
     def get_extra_context(self):
         return {
             'comment': self.object,
@@ -108,10 +102,15 @@ class DocumentCommentEditView(SingleObjectEditView):
             'title': _('Edit comment: %s?') % self.object,
         }
 
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user,
+        }
+
     def get_post_action_redirect(self):
         return reverse(
             viewname='comments:comments_for_document', kwargs={
-                'document_id': self.object.document.pk
+                'document_id': self.object.document_id
             }
         )
 
