@@ -6,17 +6,19 @@ from mayan.apps.acls.classes import ModelPermission
 from mayan.apps.acls.links import link_acl_list
 from mayan.apps.acls.permissions import permission_acl_edit, permission_acl_view
 from mayan.apps.common.apps import MayanAppConfig
-from mayan.apps.common.html_widgets import TwoStateWidget
+from mayan.apps.common.classes import ModelCopy
 from mayan.apps.common.menus import (
-    menu_facet, menu_list_facet, menu_main, menu_object, menu_secondary,
-    menu_setup, menu_tools
+    menu_facet, menu_list_facet, menu_main, menu_object, menu_related,
+    menu_secondary, menu_setup, menu_tools
 )
-from mayan.apps.documents.signals import post_document_created, post_initial_document_type
+from mayan.apps.documents.links.document_type_links import link_document_type_list
+from mayan.apps.documents.signals import signal_post_document_created, signal_post_initial_document_type
 from mayan.apps.events.classes import EventModelRegistry, ModelEventType
 from mayan.apps.events.links import (
     link_events_for_object, link_object_event_types_user_subcriptions_list
 )
 from mayan.apps.navigation.classes import SourceColumn
+from mayan.apps.views.html_widgets import TwoStateWidget
 
 from .events import event_index_template_created, event_index_template_edited
 from .handlers import (
@@ -42,7 +44,6 @@ from .permissions import (
     permission_document_indexing_instance_view,
     permission_document_indexing_rebuild, permission_document_indexing_view
 )
-from .search import *  # NOQA
 
 
 class DocumentIndexingApp(MayanAppConfig):
@@ -78,6 +79,22 @@ class DocumentIndexingApp(MayanAppConfig):
 
         EventModelRegistry.register(model=Index)
 
+        ModelCopy(
+            model=IndexTemplateNode, excludes={'parent__isnull': False},
+            extra_kwargs={'get_or_create': True}
+        ).add_fields(
+            field_names=(
+                'index', 'expression', 'enabled', 'link_documents'
+            ),
+        )
+        ModelCopy(
+            model=Index, bind_link=True, register_permission=True
+        ).add_fields(
+            field_names=(
+                'label', 'slug', 'enabled', 'document_types', 'node_templates'
+            ),
+        )
+
         ModelEventType.register(
             event_types=(
                 event_index_template_created, event_index_template_edited
@@ -115,7 +132,7 @@ class DocumentIndexingApp(MayanAppConfig):
             attribute='slug', include_label=True, is_sortable=True,
             source=Index
         )
-        column_index_slug.add_exclude(IndexInstance)
+        column_index_slug.add_exclude(source=IndexInstance)
         column_index_enabled = SourceColumn(
             attribute='enabled', include_label=True, is_sortable=True,
             source=Index, widget=TwoStateWidget
@@ -151,11 +168,14 @@ class DocumentIndexingApp(MayanAppConfig):
             source=IndexTemplateNode, widget=TwoStateWidget
         )
 
-        SourceColumn(
+        column_index_instance_node_level = SourceColumn(
             func=lambda context: index_instance_item_link(context['object']),
             is_identifier=True, is_sortable=True, label=_('Level'),
             sort_field='value', source=IndexInstanceNode
         )
+        column_index_instance_node_level.add_exclude(
+            source=DocumentIndexInstanceNode
+        )
         SourceColumn(
             func=lambda context: context['object'].get_descendants_count(),
             include_label=True, label=_('Levels'), source=IndexInstanceNode
@@ -168,14 +188,6 @@ class DocumentIndexingApp(MayanAppConfig):
             ), include_label=True, label=_('Documents'),
             source=IndexInstanceNode
         )
-        SourceColumn(
-            func=lambda context: context[
-                'object'
-            ].get_descendants_document_count(
-                user=context['request'].user
-            ), include_label=True, label=_('Documents'),
-            source=IndexInstanceNode
-        )
         SourceColumn(
             func=lambda context: index_instance_item_link(context['object']),
             is_identifier=True, is_sortable=True, label=_('Level'),
@@ -191,19 +203,6 @@ class DocumentIndexingApp(MayanAppConfig):
             ), include_label=True, is_sortable=True, label=_('Level'),
             sort_field='value', source=DocumentIndexInstanceNode
         )
-        SourceColumn(
-            func=lambda context: context['object'].get_descendants_count(),
-            include_label=True, label=_('Levels'),
-            source=DocumentIndexInstanceNode
-        )
-        SourceColumn(
-            func=lambda context: context[
-                'object'
-            ].get_descendants_document_count(
-                user=context['request'].user
-            ), include_label=True, label=_('Documents'),
-            source=DocumentIndexInstanceNode
-        )
 
         menu_facet.bind_links(
             links=(
@@ -235,6 +234,20 @@ class DocumentIndexingApp(MayanAppConfig):
             ), sources=(IndexTemplateNode,)
         )
         menu_main.bind_links(links=(link_index_instance_menu,), position=98)
+        menu_related.bind_links(
+            links=(link_index_template_list,),
+            sources=(
+                DocumentType, 'documents:document_type_list',
+                'documents:document_type_create'
+            )
+        )
+        menu_related.bind_links(
+            links=(link_document_type_list,),
+            sources=(
+                Index, 'indexing:index_setup_list',
+                'indexing:index_setup_create'
+            )
+        )
         menu_secondary.bind_links(
             links=(link_index_template_list, link_index_template_create),
             sources=(
@@ -247,28 +260,28 @@ class DocumentIndexingApp(MayanAppConfig):
             links=(link_index_instances_rebuild, link_index_instances_reset)
         )
 
-        post_delete.connect(
-            dispatch_uid='document_indexing_handler_delete_empty',
-            receiver=handler_delete_empty,
-            sender=Document
-        )
-        post_document_created.connect(
-            dispatch_uid='document_indexing_handler_index_document',
-            receiver=handler_index_document,
-            sender=Document
-        )
-        post_initial_document_type.connect(
-            dispatch_uid='document_indexing_handler_create_default_document_index',
-            receiver=handler_create_default_document_index,
-            sender=DocumentType
-        )
         post_save.connect(
             dispatch_uid='document_indexing_handler_post_save_index_document',
             receiver=handler_post_save_index_document,
             sender=Document
         )
+        post_delete.connect(
+            dispatch_uid='document_indexing_handler_delete_empty',
+            receiver=handler_delete_empty,
+            sender=Document
+        )
         pre_delete.connect(
             dispatch_uid='document_indexing_handler_remove_document',
             receiver=handler_remove_document,
             sender=Document
         )
+        signal_post_document_created.connect(
+            dispatch_uid='document_indexing_handler_index_document',
+            receiver=handler_index_document,
+            sender=Document
+        )
+        signal_post_initial_document_type.connect(
+            dispatch_uid='document_indexing_handler_create_default_document_index',
+            receiver=handler_create_default_document_index,
+            sender=DocumentType
+        )
