@@ -2,7 +2,7 @@ import logging
 
 from django.db import models, transaction
 from django.urls import reverse
-from django.utils.encoding import force_text, python_2_unicode_compatible
+from django.utils.encoding import force_text
 from django.utils.translation import ugettext, ugettext_lazy as _
 
 from mptt.fields import TreeForeignKey
@@ -12,8 +12,8 @@ from mayan.apps.acls.models import AccessControlList
 from mayan.apps.documents.events import event_document_type_edited
 from mayan.apps.documents.models import Document, DocumentType
 from mayan.apps.documents.permissions import permission_document_view
+from mayan.apps.lock_manager.backends.base import LockingBackend
 from mayan.apps.lock_manager.exceptions import LockError
-from mayan.apps.lock_manager.runtime import locking_backend
 from mayan.apps.templating.classes import Template
 
 from .events import event_index_template_created, event_index_template_edited
@@ -24,7 +24,6 @@ from .managers import (
 logger = logging.getLogger(name=__name__)
 
 
-@python_2_unicode_compatible
 class Index(models.Model):
     """
     Parent model that defines an index and hold all the relationship for its
@@ -112,19 +111,21 @@ class Index(models.Model):
         """
         logger.debug('Index; Indexing document: %s', document)
 
-        self.initialize_instance_root()
+        if Document.valid.filter(pk=document.pk).exists():
+            # Only index valid documents
+            self.initialize_instance_root()
 
-        with transaction.atomic():
-            # Remove the document from all instance nodes from
-            # this index
-            for index_instance_node in IndexInstanceNode.objects.filter(index_template_node__index=self, documents=document):
-                index_instance_node.remove_document(document=document)
+            with transaction.atomic():
+                # Remove the document from all instance nodes from
+                # this index
+                for index_instance_node in IndexInstanceNode.objects.filter(index_template_node__index=self, documents=document):
+                    index_instance_node.remove_document(document=document)
 
-            # Delete all empty nodes. Starting from the bottom up
-            for index_instance_node in self.instance_root.get_leafnodes():
-                index_instance_node.delete_empty()
+                # Delete all empty nodes. Starting from the bottom up
+                for index_instance_node in self.instance_root.get_leafnodes():
+                    index_instance_node.delete_empty()
 
-        self.template_root.index_document(document=document)
+            self.template_root.index_document(document=document)
 
     def initialize_instance_root(self):
         return self.template_root.initialize_index_instance_root_node()
@@ -198,31 +199,6 @@ class Index(models.Model):
         return self.node_templates.get(parent=None)
 
 
-class IndexInstance(Index):
-    """
-    Model that represents an evaluated index. This is an index whose nodes
-    have been evaluated against a series of documents. If is a proxy model
-    at the moment.
-    """
-    class Meta:
-        proxy = True
-        verbose_name = _('Index instance')
-        verbose_name_plural = _('Index instances')
-
-    def get_instance_node_count(self):
-        try:
-            return self.instance_root.get_descendant_count()
-        except IndexInstanceNode.DoesNotExist:
-            return 0
-
-    def get_item_count(self, user):
-        try:
-            return self.instance_root.get_item_count(user=user)
-        except IndexInstanceNode.DoesNotExist:
-            return 0
-
-
-@python_2_unicode_compatible
 class IndexTemplateNode(MPTTModel):
     """
     The template to generate an index. Each entry represents a level in a
@@ -230,7 +206,8 @@ class IndexTemplateNode(MPTTModel):
     documents but not both.
     """
     parent = TreeForeignKey(
-        blank=True, null=True, on_delete=models.CASCADE, to='self',
+        blank=True, null=True, on_delete=models.CASCADE,
+        related_name='children', to='self',
     )
     index = models.ForeignKey(
         on_delete=models.CASCADE, related_name='node_templates', to=Index,
@@ -282,7 +259,7 @@ class IndexTemplateNode(MPTTModel):
         # the database.
         try:
             if acquire_lock:
-                lock = locking_backend.acquire_lock(
+                lock = LockingBackend.get_instance().acquire_lock(
                     self.get_lock_string()
                 )
         except LockError:
@@ -358,7 +335,42 @@ class IndexTemplateNode(MPTTModel):
         self.index_instance_nodes.get_or_create(parent=None)
 
 
-@python_2_unicode_compatible
+class IndexInstance(Index):
+    """
+    Model that represents an evaluated index. This is an index whose nodes
+    have been evaluated against a series of documents. If is a proxy model
+    at the moment.
+    """
+    class Meta:
+        proxy = True
+        verbose_name = _('Index instance')
+        verbose_name_plural = _('Index instances')
+
+    def get_children(self):
+        root_node_queryset = self.get_nodes().filter(parent=None)
+        if root_node_queryset.exists():
+            return root_node_queryset.first().get_children()
+        else:
+            return root_node_queryset
+
+    def get_nodes(self):
+        return IndexInstanceNode.objects.filter(
+            index_template_node__index=self
+        )
+
+    def get_instance_node_count(self):
+        try:
+            return self.instance_root.get_descendant_count()
+        except IndexInstanceNode.DoesNotExist:
+            return 0
+
+    def get_item_count(self, user):
+        try:
+            return self.instance_root.get_item_count(user=user)
+        except IndexInstanceNode.DoesNotExist:
+            return 0
+
+
 class IndexInstanceNode(MPTTModel):
     """
     This model represent one instance node from a index template node. That is
@@ -367,7 +379,8 @@ class IndexInstanceNode(MPTTModel):
     model also point to the original node template.
     """
     parent = TreeForeignKey(
-        blank=True, null=True, on_delete=models.CASCADE, to='self',
+        blank=True, null=True, on_delete=models.CASCADE,
+        related_name='children', to='self'
     )
     index_template_node = models.ForeignKey(
         on_delete=models.CASCADE, related_name='index_instance_nodes',
@@ -396,14 +409,14 @@ class IndexInstanceNode(MPTTModel):
         """
         # Prevent another process to delete this node.
         try:
-            lock = locking_backend.acquire_lock(
+            lock = LockingBackend.get_instance().acquire_lock(
                 self.index_template_node.get_lock_string()
             )
         except LockError:
             raise
         else:
             try:
-                if self.documents.count() == 0 and self.get_children().count() == 0:
+                if self.get_documents().count() == 0 and self.get_children().count() == 0:
                     if not self.is_root_node():
                         # I'm not a root node, I can be deleted
                         self.delete()
@@ -437,6 +450,9 @@ class IndexInstanceNode(MPTTModel):
             ), user=user
         ).count()
 
+    def get_documents(self):
+        return Document.valid.filter(pk__in=self.documents.values('pk'))
+
     def get_full_path(self):
         result = []
         for node in self.get_ancestors(include_self=True):
@@ -454,8 +470,8 @@ class IndexInstanceNode(MPTTModel):
     def get_item_count(self, user):
         if self.index_template_node.link_documents:
             queryset = AccessControlList.objects.restrict_queryset(
-                permission=permission_document_view, queryset=self.documents,
-                user=user
+                permission=permission_document_view,
+                queryset=self.get_documents(), user=user
             )
 
             return queryset.count()
@@ -481,7 +497,7 @@ class IndexInstanceNode(MPTTModel):
         # Prevent another process to work on this node. We use the node's
         # parent template node for the lock
         try:
-            lock = locking_backend.acquire_lock(
+            lock = LockingBackend.get_instance().acquire_lock(
                 self.index_template_node.get_lock_string()
             )
         except LockError:
