@@ -1,12 +1,12 @@
 from django.utils.encoding import force_text
 
-from mayan.apps.common.tests.base import BaseTestCase
 from mayan.apps.documents.tests.base import DocumentTestMixin
 from mayan.apps.documents.tests.literals import (
     TEST_DOCUMENT_DESCRIPTION, TEST_DOCUMENT_DESCRIPTION_EDITED,
     TEST_DOCUMENT_LABEL_EDITED, TEST_SMALL_DOCUMENT_PATH
 )
 from mayan.apps.metadata.models import MetadataType, DocumentTypeMetadataType
+from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..models import Index, IndexInstanceNode, IndexTemplateNode
 
@@ -105,7 +105,7 @@ class IndexTestCase(IndexTestMixin, DocumentTestMixin, BaseTestCase):
         values and two second levels with the same value but as separate
         children of each of the first levels. GitLab issue #391
         """
-        with open(TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
             self.test_document_2 = self.test_document_type.new_document(
                 file_object=file_object
             )
