@@ -4,7 +4,7 @@ from django.utils.html import conditional_escape
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _, ugettext
 
-from mayan.apps.common.widgets import TextAreaDiv
+from mayan.apps.views.widgets import TextAreaDiv
 
 from .models import DocumentPageContent
 
