@@ -1,10 +1,10 @@
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.smart_settings.classes import Namespace
+from mayan.apps.smart_settings.classes import SettingNamespace
 
 from .literals import DEFAULT_PDFTOTEXT_PATH
 
-namespace = Namespace(label=_('Document parsing'), name='document_parsing')
+namespace = SettingNamespace(label=_('Document parsing'), name='document_parsing')
 
 setting_auto_parsing = namespace.add_setting(
     global_name='DOCUMENT_PARSING_AUTO_PARSING', default=True,
