@@ -1,4 +1,4 @@
-class DocumentContentToolsViewsTestMixin(object):
+class DocumentContentToolsViewsTestMixin:
     def _request_document_parsing_error_list_view(self):
         return self.get(viewname='document_parsing:error_list')
 
@@ -10,7 +10,7 @@ class DocumentContentToolsViewsTestMixin(object):
         )
 
 
-class DocumentContentViewTestMixin(object):
+class DocumentContentViewTestMixin:
     def _request_test_document_content_delete_view(self):
         return self.post(
             viewname='document_parsing:document_content_delete', kwargs={
@@ -47,9 +47,42 @@ class DocumentContentViewTestMixin(object):
         )
 
 
-class DocumentTypeContentViewsTestMixin(object):
+class DocumentParsingAPITestMixin:
+    def _request_document_page_content_view(self):
+        return self.get(
+            viewname='rest_api:document-page-content-view', kwargs={
+                'document_pk': self.test_document.pk,
+                'version_pk': self.test_document.latest_version.pk,
+                'page_pk': self.test_document.latest_version.pages.first().pk
+            }
+        )
+
+
+class DocumentTypeContentViewsTestMixin:
     def _request_test_document_type_parsing_settings(self):
         return self.get(
             viewname='document_parsing:document_type_parsing_settings',
             kwargs={'document_type_id': self.test_document_type.pk}
         )
+
+
+class DocumentTypeParsingSettingsAPIViewTestMixin():
+    def _request_document_type_parsing_settings_details_api_view(self):
+        return self.get(
+            viewname='rest_api:document-type-parsing-settings-view',
+            kwargs={'pk': self.test_document_type.pk}
+        )
+
+    def _request_document_type_parsing_settings_patch_api_view(self):
+        return self.patch(
+            viewname='rest_api:document-type-parsing-settings-view',
+            kwargs={'pk': self.test_document_type.pk},
+            data={'auto_parsing': True}
+        )
+
+    def _request_document_type_parsing_settings_put_api_view(self):
+        return self.put(
+            viewname='rest_api:document-type-parsing-settings-view',
+            kwargs={'pk': self.test_document_type.pk},
+            data={'auto_parsing': True}
+        )
