@@ -1,6 +1,6 @@
-from mayan.apps.common.tests.base import BaseTestCase
 from mayan.apps.documents.tests.literals import TEST_HYBRID_DOCUMENT
 from mayan.apps.documents.tests.mixins import DocumentTestMixin
+from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..parsers import PopplerParser
 
