@@ -7,9 +7,9 @@ from ..models import DetachedSignature
 from .literals import TEST_SIGNATURE_FILE_PATH
 
 
-class DetachedSignatureAPIViewTestMixin(object):
+class DetachedSignatureAPIViewTestMixin:
     def _request_test_document_signature_detached_create_view(self):
-        with open(TEST_SIGNATURE_FILE_PATH, mode='rb') as file_object:
+        with open(file=TEST_SIGNATURE_FILE_PATH, mode='rb') as file_object:
             return self.post(
                 viewname='rest_api:document-version-signature-detached-list',
                 kwargs={
@@ -60,7 +60,7 @@ class DetachedSignatureAPIViewTestMixin(object):
         )
 
 
-class DetachedSignatureViewTestMixin(object):
+class DetachedSignatureViewTestMixin:
     def _request_test_document_version_signature_create_view(self):
         return self.post(
             viewname='signatures:document_version_signature_detached_create',
@@ -79,7 +79,7 @@ class DetachedSignatureViewTestMixin(object):
         )
 
     def _request_test_document_version_signature_upload_view(self):
-        with open(TEST_SIGNATURE_FILE_PATH, mode='rb') as file_object:
+        with open(file=TEST_SIGNATURE_FILE_PATH, mode='rb') as file_object:
             return self.post(
                 viewname='signatures:document_version_signature_upload',
                 kwargs={
@@ -88,7 +88,7 @@ class DetachedSignatureViewTestMixin(object):
             )
 
 
-class EmbeddedSignatureAPIViewTestMixin(object):
+class EmbeddedSignatureAPIViewTestMixin:
     def _request_test_document_signature_embedded_detail_view(self):
         return self.get(
             viewname='rest_api:embeddedsignature-detail',
@@ -121,7 +121,7 @@ class EmbeddedSignatureAPIViewTestMixin(object):
         )
 
 
-class EmbeddedSignatureViewTestMixin(object):
+class EmbeddedSignatureViewTestMixin:
     def _request_test_document_version_signature_create_view(self):
         return self.post(
             viewname='signatures:document_version_signature_embedded_create',
@@ -134,16 +134,16 @@ class EmbeddedSignatureViewTestMixin(object):
         )
 
 
-class SignatureTestMixin(object):
+class SignatureTestMixin:
     def _upload_test_detached_signature(self):
-        with open(TEST_SIGNATURE_FILE_PATH, mode='rb') as file_object:
+        with open(file=TEST_SIGNATURE_FILE_PATH, mode='rb') as file_object:
             self.test_signature = DetachedSignature.objects.create(
                 document_version=self.test_document.latest_version,
                 signature_file=File(file_object)
             )
 
 
-class SignatureViewTestMixin(object):
+class SignatureViewTestMixin:
     def _request_test_document_version_signature_delete_view(self):
         return self.post(
             viewname='signatures:document_version_signature_delete', kwargs={
