@@ -1,10 +1,10 @@
 import importlib
 import logging
 
-from mayan.apps.common.tests.base import BaseTestCase
 from mayan.apps.document_signatures import storages
 from mayan.apps.smart_settings.tests.mixins import SmartSettingTestMixin
 from mayan.apps.storage.classes import DefinedStorage
+from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..literals import STORAGE_NAME_DOCUMENT_SIGNATURES_DETACHED_SIGNATURE
 from ..settings import setting_storage_backend_arguments
