@@ -3,7 +3,10 @@ import json
 from mayan.apps.django_gpg.tests.literals import TEST_KEY_PRIVATE_PASSPHRASE
 from mayan.apps.django_gpg.tests.mixins import KeyTestMixin
 from mayan.apps.document_states.literals import WORKFLOW_ACTION_ON_ENTRY
-from mayan.apps.document_states.tests.mixins import WorkflowTestMixin
+from mayan.apps.document_states.permissions import permission_workflow_edit
+from mayan.apps.document_states.tests.mixins import (
+    WorkflowTestMixin, WorkflowStateActionViewTestMixin
+)
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
 
 from ..models import DetachedSignature, EmbeddedSignature
@@ -11,12 +14,42 @@ from ..workflow_actions import (
     DocumentSignatureDetachedAction, DocumentSignatureEmbeddedAction
 )
 
+from .literals import (
+    DOCUMENT_SIGNATURE_DETACHED_ACTION_CLASS_PATH,
+    DOCUMENT_SIGNATURE_EMBEDDED_ACTION_CLASS_PATH
+)
+
 
 class DocumentSignatureWorkflowActionTestCase(
     GenericDocumentViewTestCase, KeyTestMixin, WorkflowTestMixin,
+    WorkflowStateActionViewTestMixin
 ):
     auto_upload_test_document = False
 
+    def test_document_signature_detached_action_create_view(self):
+        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_state()
+        self.grant_access(
+            obj=self.test_workflow, permission=permission_workflow_edit
+        )
+
+        request = self._request_test_workflow_template_state_action_create_get_view(
+            class_path=DOCUMENT_SIGNATURE_DETACHED_ACTION_CLASS_PATH
+        )
+        self.assertEqual(request.status_code, 200)
+
+    def test_document_signature_embedded_action_create_view(self):
+        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_state()
+        self.grant_access(
+            obj=self.test_workflow, permission=permission_workflow_edit
+        )
+
+        request = self._request_test_workflow_template_state_action_create_get_view(
+            class_path=DOCUMENT_SIGNATURE_EMBEDDED_ACTION_CLASS_PATH
+        )
+        self.assertEqual(request.status_code, 200)
+
     def test_document_signature_detached_action(self):
         self._upload_test_document()
         self._create_test_key_private()
