@@ -13,7 +13,7 @@ from django.db import IntegrityError, models, transaction
 from django.db.models import F, Max, Q
 from django.urls import reverse
 from django.utils.encoding import (
-    force_bytes, force_text, python_2_unicode_compatible
+    force_bytes, force_text
 )
 from django.utils.functional import cached_property
 from django.utils.module_loading import import_string
@@ -24,10 +24,14 @@ from mayan.apps.common.serialization import yaml_load
 from mayan.apps.common.validators import YAMLValidator, validate_internal_name
 from mayan.apps.documents.models import Document, DocumentType
 from mayan.apps.documents.permissions import permission_document_view
+from mayan.apps.events.classes import (
+    EventManagerMethodAfter, EventManagerSave
+)
+from mayan.apps.events.decorators import method_event
 from mayan.apps.events.models import StoredEventType
+
 from mayan.apps.templating.classes import Template
 
-from .error_logs import error_log_state_actions
 from .events import event_workflow_created, event_workflow_edited
 from .literals import (
     FIELD_TYPE_CHOICES, STORAGE_NAME_WORKFLOW_CACHE, WIDGET_CLASS_CHOICES,
@@ -41,12 +45,16 @@ SYMBOL_MATH_CONDITIONAL = '&rarr;'
 logger = logging.getLogger(name=__name__)
 
 
-@python_2_unicode_compatible
 class Workflow(models.Model):
     """
     Fields:
     * label - Identifier. A name/label to call the workflow
     """
+    auto_launch = models.BooleanField(
+        default=True, help_text=_(
+            'Launch workflow when document is created.'
+        ), verbose_name=_('Auto launch')
+    )
     internal_name = models.CharField(
         db_index=True, help_text=_(
             'This value will be used by other apps to reference this '
@@ -149,27 +157,39 @@ class Workflow(models.Model):
     get_initial_state.short_description = _('Initial state')
 
     def launch_for(self, document):
-        try:
-            logger.info(
-                'Launching workflow %s for document %s', self, document
-            )
-            workflow_instance = self.instances.create(document=document)
-            initial_state = self.get_initial_state()
-            if initial_state:
-                for action in initial_state.entry_actions.filter(enabled=True):
-                    action.execute(
-                        context=workflow_instance.get_context(),
-                        workflow_instance=workflow_instance
-                    )
-        except IntegrityError:
-            logger.info(
-                'Workflow %s already launched for document %s', self, document
-            )
+        if document.document_type in self.document_types.all():
+            try:
+                logger.info(
+                    'Launching workflow %s for document %s', self, document
+                )
+                workflow_instance = self.instances.create(document=document)
+                initial_state = self.get_initial_state()
+                if initial_state:
+                    for action in initial_state.entry_actions.filter(enabled=True):
+                        context = workflow_instance.get_context()
+                        context.update(
+                            {
+                                'action': action
+                            }
+                        )
+                        action.execute(
+                            context=context,
+                            workflow_instance=workflow_instance
+                        )
+            except IntegrityError:
+                logger.info(
+                    'Workflow %s already launched for document %s', self, document
+                )
+            else:
+                logger.info(
+                    'Workflow %s launched for document %s', self, document
+                )
+                return workflow_instance
         else:
-            logger.info(
-                'Workflow %s launched for document %s', self, document
+            logger.error(
+                'This workflow is not valid for the document type of the '
+                'document.'
             )
-            return workflow_instance
 
     def render(self):
         diagram = Digraph(
@@ -272,7 +292,6 @@ class Workflow(models.Model):
             return result
 
 
-@python_2_unicode_compatible
 class WorkflowInstance(models.Model):
     workflow = models.ForeignKey(
         on_delete=models.CASCADE, related_name='instances', to=Workflow,
@@ -295,7 +314,7 @@ class WorkflowInstance(models.Model):
     def __str__(self):
         return force_text(getattr(self, 'workflow', 'WI'))
 
-    def do_transition(self, transition, extra_data=None, user=None, comment=None):
+    def do_transition(self, transition, comment=None, extra_data=None, user=None):
         with transaction.atomic():
             try:
                 if transition in self.get_current_state().origin_transitions.all():
@@ -311,7 +330,8 @@ class WorkflowInstance(models.Model):
                     )
             except AttributeError:
                 # No initial state has been set for this workflow
-                pass
+                if settings.DEBUG:
+                    raise
 
     def dumps(self, context):
         """
@@ -328,6 +348,10 @@ class WorkflowInstance(models.Model):
         )
 
     def get_context(self):
+        # Keep the document instance in the workflow instance fresh when
+        # there are cascade state actions, where a second state action is
+        # triggered by the events generated by a first state action.
+        self.document.refresh_from_db()
         context = {
             'document': self.document, 'workflow': self.workflow,
             'workflow_instance': self,
@@ -419,7 +443,6 @@ class WorkflowInstance(models.Model):
         return json.loads(s=self.context or '{}')
 
 
-@python_2_unicode_compatible
 class WorkflowInstanceLogEntry(models.Model):
     """
     Fields:
@@ -461,7 +484,15 @@ class WorkflowInstanceLogEntry(models.Model):
     def get_extra_data(self):
         result = {}
         for key, value in self.loads().items():
-            result[self.transition.fields.get(name=key).label] = value
+            try:
+                field = self.transition.fields.get(name=key)
+            except WorkflowTransitionField.DoesNotExist:
+                """
+                There is a reference for a field that does not exist or
+                has been deleted.
+                """
+            else:
+                result[field.label] = value
 
         return result
 
@@ -504,7 +535,6 @@ class WorkflowInstanceLogEntry(models.Model):
             return result
 
 
-@python_2_unicode_compatible
 class WorkflowState(models.Model):
     """
     Fields:
@@ -547,6 +577,15 @@ class WorkflowState(models.Model):
     def __str__(self):
         return self.label
 
+    @method_event(
+        action_object='self',
+        event_manager_class=EventManagerMethodAfter,
+        event=event_workflow_edited,
+        target='workflow',
+    )
+    def delete(self, *args, **kwargs):
+        return super().delete(*args, **kwargs)
+
     @property
     def entry_actions(self):
         return self.actions.filter(when=WORKFLOW_ACTION_ON_ENTRY)
@@ -580,6 +619,19 @@ class WorkflowState(models.Model):
             )
         ).distinct()
 
+    @method_event(
+        event_manager_class=EventManagerSave,
+        created={
+            'action_object': 'self',
+            'event': event_workflow_edited,
+            'target': 'workflow',
+        },
+        edited={
+            'action_object': 'self',
+            'event': event_workflow_edited,
+            'target': 'workflow',
+        }
+    )
     def save(self, *args, **kwargs):
         # Solve issue #557 "Break workflows with invalid input"
         # without using a migration.
@@ -596,7 +648,6 @@ class WorkflowState(models.Model):
         return super(WorkflowState, self).save(*args, **kwargs)
 
 
-@python_2_unicode_compatible
 class WorkflowStateAction(models.Model):
     state = models.ForeignKey(
         on_delete=models.CASCADE, related_name='actions', to=WorkflowState,
@@ -625,9 +676,10 @@ class WorkflowStateAction(models.Model):
         blank=True, help_text=_(
             'The condition that will determine if this state action '
             'is executed or not. The condition is evaluated against the '
-            'workflow instance. Conditions that return None or an empty '
-            'string (\'\') are considered to be logical false, any other '
-            'value is considered to be the logical true.'
+            'workflow instance. Conditions that do not return any value, '
+            'that return the Python logical None, or an empty string (\'\') '
+            'are considered to be logical false, any other value is '
+            'considered to be the logical true.'
         ), verbose_name=_('Condition')
     )
 
@@ -640,6 +692,15 @@ class WorkflowStateAction(models.Model):
     def __str__(self):
         return self.label
 
+    @method_event(
+        action_object='self',
+        event_manager_class=EventManagerMethodAfter,
+        event=event_workflow_edited,
+        target='state.workflow',
+    )
+    def delete(self, *args, **kwargs):
+        return super().delete(*args, **kwargs)
+
     def dumps(self, data):
         self.action_data = json.dumps(obj=data)
         self.save()
@@ -657,14 +718,16 @@ class WorkflowStateAction(models.Model):
             try:
                 self.get_class_instance().execute(context=context)
             except Exception as exception:
-                error_log_state_actions.create(
-                    obj=self, result='{}; {}'.format(
+                self.error_log.create(
+                    text='{}; {}'.format(
                         exception.__class__.__name__, exception
                     )
                 )
 
                 if settings.DEBUG:
                     raise
+            else:
+                self.error_log.all().delete()
 
     def get_class(self):
         return import_string(dotted_path=self.action_path)
@@ -689,8 +752,23 @@ class WorkflowStateAction(models.Model):
     def loads(self):
         return json.loads(s=self.action_data or '{}')
 
+    @method_event(
+        event_manager_class=EventManagerSave,
+        created={
+            'action_object': 'self',
+            'event': event_workflow_edited,
+            'target': 'state.workflow',
+        },
+        edited={
+            'action_object': 'self',
+            'event': event_workflow_edited,
+            'target': 'state.workflow',
+        }
+    )
+    def save(self, *args, **kwargs):
+        return super().save(*args, **kwargs)
+
 
-@python_2_unicode_compatible
 class WorkflowTransition(models.Model):
     workflow = models.ForeignKey(
         on_delete=models.CASCADE, related_name='transitions', to=Workflow,
@@ -712,9 +790,10 @@ class WorkflowTransition(models.Model):
         blank=True, help_text=_(
             'The condition that will determine if this transition '
             'is enabled or not. The condition is evaluated against the '
-            'workflow instance. Conditions that return None or an empty '
-            'string (\'\') are considered to be logical false, any other '
-            'value is considered to be the logical true.'
+            'workflow instance. Conditions that do not return any value, '
+            'that return the Python logical None, or an empty string (\'\') '
+            'are considered to be logical false, any other value is '
+            'considered to be the logical true.'
         ), verbose_name=_('Condition')
     )
 
@@ -729,6 +808,15 @@ class WorkflowTransition(models.Model):
     def __str__(self):
         return self.label
 
+    @method_event(
+        action_object='self',
+        event_manager_class=EventManagerMethodAfter,
+        event=event_workflow_edited,
+        target='workflow',
+    )
+    def delete(self, *args, **kwargs):
+        return super().delete(*args, **kwargs)
+
     def evaluate_condition(self, workflow_instance):
         if self.has_condition():
             return Template(template_string=self.condition).render(
@@ -737,6 +825,13 @@ class WorkflowTransition(models.Model):
         else:
             return True
 
+    def get_field_display(self):
+        field_list = sorted([str(field) for field in self.fields.all()])
+
+        return ', '.join(field_list)
+
+    get_field_display.short_description = _('Fields')
+
     def has_condition(self):
         return self.condition.strip()
     has_condition.help_text = _(
@@ -745,8 +840,23 @@ class WorkflowTransition(models.Model):
     )
     has_condition.short_description = _('Has a condition?')
 
+    @method_event(
+        event_manager_class=EventManagerSave,
+        created={
+            'action_object': 'self',
+            'event': event_workflow_edited,
+            'target': 'workflow',
+        },
+        edited={
+            'action_object': 'self',
+            'event': event_workflow_edited,
+            'target': 'workflow',
+        }
+    )
+    def save(self, *args, **kwargs):
+        return super().save(*args, **kwargs)
+
 
-@python_2_unicode_compatible
 class WorkflowTransitionField(models.Model):
     transition = models.ForeignKey(
         on_delete=models.CASCADE, related_name='fields',
@@ -797,11 +907,35 @@ class WorkflowTransitionField(models.Model):
     def __str__(self):
         return self.label
 
+    @method_event(
+        action_object='self',
+        event_manager_class=EventManagerMethodAfter,
+        event=event_workflow_edited,
+        target='transition.workflow',
+    )
+    def delete(self, *args, **kwargs):
+        return super().delete(*args, **kwargs)
+
     def get_widget_kwargs(self):
-        return yaml_load(stream=self.widget_kwargs)
+        return yaml_load(stream=self.widget_kwargs or '{}')
+
+    @method_event(
+        event_manager_class=EventManagerSave,
+        created={
+            'action_object': 'self',
+            'event': event_workflow_edited,
+            'target': 'transition.workflow',
+        },
+        edited={
+            'action_object': 'self',
+            'event': event_workflow_edited,
+            'target': 'transition.workflow',
+        }
+    )
+    def save(self, *args, **kwargs):
+        return super().save(*args, **kwargs)
 
 
-@python_2_unicode_compatible
 class WorkflowTransitionTriggerEvent(models.Model):
     transition = models.ForeignKey(
         on_delete=models.CASCADE, related_name='trigger_events',
