@@ -5,10 +5,10 @@ class ActionTestCase(GenericDocumentTestCase):
     def setUp(self):
         super(ActionTestCase, self).setUp()
 
-        class MockWorkflowInstance(object):
+        class MockWorkflowInstance:
             document = self.test_document
 
-        class MockEntryLog(object):
+        class MockEntryLog:
             workflow_instance = MockWorkflowInstance()
 
         self.entry_log = MockEntryLog()
