@@ -12,101 +12,206 @@ from ..permissions import (
 )
 
 from .literals import (
-    TEST_WORKFLOW_INTERNAL_NAME, TEST_WORKFLOW_LABEL,
-    TEST_WORKFLOW_LABEL_EDITED, TEST_WORKFLOW_STATE_COMPLETION,
+    TEST_WORKFLOW_LABEL, TEST_WORKFLOW_LABEL_EDITED,
     TEST_WORKFLOW_STATE_LABEL, TEST_WORKFLOW_STATE_LABEL_EDITED,
     TEST_WORKFLOW_TRANSITION_LABEL, TEST_WORKFLOW_TRANSITION_LABEL_EDITED
 )
 
-from .mixins import WorkflowTestMixin
+from .mixins import (
+    DocumentWorkflowAPIViewTestMixin, WorkflowAPIViewTestMixin,
+    WorkflowStateAPIViewTestMixin, WorkflowTransitionAPIViewTestMixin,
+    WorkflowTestMixin
+)
 
 
-class WorkflowAPIViewTestMixin(object):
-    def _request_test_document_type_workflow_list_api_view(self):
-        return self.get(
-            viewname='rest_api:documenttype-workflow-list',
-            kwargs={'pk': self.test_document_type.pk}
+class DocumentWorkflowsAPIViewTestCase(
+    DocumentWorkflowAPIViewTestMixin, DocumentTestMixin, WorkflowTestMixin,
+    BaseAPITestCase
+):
+    auto_upload_test_document = False
+
+    def test_workflow_instance_detail_view_no_permission(self):
+        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_states()
+        self._create_test_workflow_transition()
+        self._upload_test_document()
+
+        response = self._request_test_workflow_instance_detail_api_view()
+        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
+        self.assertFalse('workflow' in response.data)
+
+    def test_workflow_instance_detail_view_with_workflow_access(self):
+        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_states()
+        self._create_test_workflow_transition()
+        self._upload_test_document()
+
+        self.grant_access(
+            obj=self.test_workflow, permission=permission_workflow_view
         )
 
-    def _request_test_workflow_create_api_view(self, extra_data=None):
-        data = {
-            'internal_name': TEST_WORKFLOW_INTERNAL_NAME,
-            'label': TEST_WORKFLOW_LABEL,
-        }
+        response = self._request_test_workflow_instance_detail_api_view()
+        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
+        self.assertFalse('workflow' in response.data)
 
-        if extra_data:
-            data.update(extra_data)
+    def test_workflow_instance_detail_view_with_document_access(self):
+        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_states()
+        self._create_test_workflow_transition()
+        self._upload_test_document()
 
-        return self.post(
-            viewname='rest_api:workflow-list', data=data
+        self.grant_access(
+            obj=self.test_document, permission=permission_workflow_view
         )
 
-    def _request_test_workflow_delete_api_view(self):
-        return self.delete(
-            viewname='rest_api:workflow-detail', kwargs={
-                'pk': self.test_workflow.pk
-            }
+        response = self._request_test_workflow_instance_detail_api_view()
+        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+        self.assertFalse('workflow' in response.data)
+
+    def test_workflow_instance_detail_view_with_access(self):
+        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_states()
+        self._create_test_workflow_transition()
+        self._upload_test_document()
+
+        self.grant_access(
+            obj=self.test_workflow, permission=permission_workflow_view
+        )
+        self.grant_access(
+            obj=self.test_document, permission=permission_workflow_view
         )
 
-    def _request_test_workflow_detail_api_view(self):
-        return self.get(
-            viewname='rest_api:workflow-detail', kwargs={
-                'pk': self.test_workflow.pk
-            }
+        response = self._request_test_workflow_instance_detail_api_view()
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(
+            response.data['workflow']['label'],
+            TEST_WORKFLOW_LABEL
         )
 
-    def _request_test_workflow_document_type_delete_api_view(self):
-        return self.delete(
-            viewname='rest_api:workflow-document-type-detail',
-            kwargs={
-                'pk': self.test_workflow.pk,
-                'document_type_pk': self.test_document_type.pk
-            }
+    def test_workflow_instance_list_view_no_permission(self):
+        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_states()
+        self._create_test_workflow_transition()
+        self._upload_test_document()
+
+        response = self._request_test_workflow_instance_list_api_view()
+        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
+        self.assertFalse('result' in response.data)
+
+    def test_workflow_instance_list_view_with_document_access(self):
+        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_states()
+        self._create_test_workflow_transition()
+        self._upload_test_document()
+
+        self.grant_access(
+            obj=self.test_document, permission=permission_workflow_view
         )
 
-    def _request_test_workflow_document_type_detail_api_view(self):
-        return self.get(
-            viewname='rest_api:workflow-document-type-detail',
-            kwargs={
-                'pk': self.test_workflow.pk,
-                'document_type_pk': self.test_document_type.pk
-            }
+        response = self._request_test_workflow_instance_list_api_view()
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(response.data['count'], 0)
+
+    def test_workflow_instance_list_view_with_workflow_access(self):
+        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_states()
+        self._create_test_workflow_transition()
+        self._upload_test_document()
+
+        self.grant_access(
+            obj=self.test_workflow, permission=permission_workflow_view
         )
 
-    def _request_test_workflow_document_type_list_create_api_view(self):
-        return self.post(
-            viewname='rest_api:workflow-document-type-list',
-            kwargs={'pk': self.test_workflow.pk}, data={
-                'document_type_pk': self.test_document_type.pk
-            }
+        response = self._request_test_workflow_instance_list_api_view()
+        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
+        self.assertFalse('result' in response.data)
+
+    def test_workflow_instance_list_view_with_access(self):
+        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_states()
+        self._create_test_workflow_transition()
+        self._upload_test_document()
+
+        self.grant_access(
+            obj=self.test_workflow, permission=permission_workflow_view
+        )
+        self.grant_access(
+            obj=self.test_document, permission=permission_workflow_view
         )
 
-    def _request_test_workflow_document_type_list_api_view(self):
-        return self.get(
-            viewname='rest_api:workflow-document-type-list', kwargs={
-                'pk': self.test_workflow.pk
-            }
+        response = self._request_test_workflow_instance_list_api_view()
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(
+            response.data['results'][0]['workflow']['label'],
+            TEST_WORKFLOW_LABEL
         )
 
-    def _request_test_workflow_edit_patch_view(self):
-        return self.patch(
-            viewname='rest_api:workflow-detail', kwargs={
-                'pk': self.test_workflow.pk
-            }, data={'label': TEST_WORKFLOW_LABEL_EDITED}
+    def test_workflow_instance_log_entries_create_view_no_permission(self):
+        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_states()
+        self._create_test_workflow_transition()
+        self._upload_test_document()
+
+        workflow_instance = self.test_document.workflows.first()
+        response = self._request_test_workflow_instance_log_entry_create_api_view(
+            workflow_instance=workflow_instance
+        )
+        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
+        # We get bad request because we try to create a transition for which
+        # we don't have permission and therefore is not valid for this
+        # workflow instance current state
+        self.assertEqual(workflow_instance.log_entries.count(), 0)
+
+    def test_workflow_instance_log_entries_create_view_with_workflow_access(self):
+        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_states()
+        self._create_test_workflow_transition()
+        self._upload_test_document()
+
+        self.grant_access(
+            obj=self.test_workflow, permission=permission_workflow_transition
+        )
+        workflow_instance = self.test_document.workflows.first()
+
+        response = self._request_test_workflow_instance_log_entry_create_api_view(
+            workflow_instance=workflow_instance
+        )
+        self.assertEqual(response.status_code, status.HTTP_201_CREATED)
+
+        workflow_instance.refresh_from_db()
+        self.assertEqual(
+            workflow_instance.log_entries.first().transition.label,
+            TEST_WORKFLOW_TRANSITION_LABEL
         )
 
-    def _request_test_workflow_edit_put_view(self):
-        return self.put(
-            viewname='rest_api:workflow-detail', kwargs={
-                'pk': self.test_workflow.pk
-            }, data={
-                'internal_name': TEST_WORKFLOW_INTERNAL_NAME,
-                'label': TEST_WORKFLOW_LABEL_EDITED
-            }
+    def test_workflow_instance_log_entries_list_view_no_permission(self):
+        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_states()
+        self._create_test_workflow_transition()
+        self._upload_test_document()
+        self._create_test_workflow_instance_log_entry()
+
+        response = self._request_test_workflow_instance_log_entry_list_api_view()
+        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
+        self.assertFalse('results' in response.data)
+
+    def test_workflow_instance_log_entries_list_view_with_document_access(self):
+        self._create_test_workflow(add_document_type=True)
+        self._create_test_workflow_states()
+        self._create_test_workflow_transition()
+        self._upload_test_document()
+        self._create_test_workflow_instance_log_entry()
+
+        self.grant_access(
+            obj=self.test_document, permission=permission_workflow_view
         )
 
-    def _request_test_workflow_list_api_view(self):
-        return self.get(viewname='rest_api:workflow-list')
+        response = self._request_test_workflow_instance_log_entry_list_api_view()
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(
+            response.data['results'][0]['transition']['label'],
+            TEST_WORKFLOW_TRANSITION_LABEL
+        )
 
 
 class WorkflowAPIViewTestCase(
@@ -179,7 +284,7 @@ class WorkflowAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
         self.assertEqual(Workflow.objects.count(), 0)
 
-    def test_workflow_detail_view_no_access(self):
+    def test_workflow_detail_view_no_permission(self):
         self._create_test_workflow()
 
         response = self._request_test_workflow_detail_api_view()
@@ -197,7 +302,7 @@ class WorkflowAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(response.data['label'], self.test_workflow.label)
 
-    def test_workflow_document_type_create_view_no_access(self):
+    def test_workflow_document_type_create_view_no_permission(self):
         self._create_test_workflow(add_document_type=False)
 
         response = self._request_test_workflow_document_type_list_create_api_view()
@@ -219,7 +324,7 @@ class WorkflowAPIViewTestCase(
             (repr(self.test_document_type),)
         )
 
-    def test_workflow_document_type_delete_view_no_access(self):
+    def test_workflow_document_type_delete_view_no_permission(self):
         self._create_test_workflow(add_document_type=True)
 
         response = self._request_test_workflow_document_type_delete_api_view()
@@ -241,7 +346,7 @@ class WorkflowAPIViewTestCase(
         self.test_workflow.refresh_from_db()
         self.assertEqual(self.test_workflow.document_types.count(), 0)
 
-    def test_workflow_document_type_detail_view_no_access(self):
+    def test_workflow_document_type_detail_view_no_permission(self):
         self._create_test_workflow(add_document_type=True)
 
         response = self._request_test_workflow_document_type_detail_api_view()
@@ -288,7 +393,7 @@ class WorkflowAPIViewTestCase(
             response.data['label'], self.test_document_type.label
         )
 
-    def test_workflow_document_type_list_view_no_access(self):
+    def test_workflow_document_type_list_view_no_permission(self):
         self._create_test_workflow(add_document_type=True)
 
         response = self._request_test_workflow_document_type_list_api_view()
@@ -333,7 +438,7 @@ class WorkflowAPIViewTestCase(
             response.data['results'][0]['label'], self.test_document_type.label
         )
 
-    def test_workflow_list_view_no_access(self):
+    def test_workflow_list_view_no_permission(self):
         self._create_test_workflow()
 
         response = self._request_test_workflow_list_api_view()
@@ -353,7 +458,7 @@ class WorkflowAPIViewTestCase(
             response.data['results'][0]['label'], self.test_workflow.label
         )
 
-    def test_workflow_patch_view_no_access(self):
+    def test_workflow_patch_view_no_permission(self):
         self._create_test_workflow()
 
         response = self._request_test_workflow_edit_patch_view()
@@ -375,7 +480,7 @@ class WorkflowAPIViewTestCase(
         self.test_workflow.refresh_from_db()
         self.assertEqual(self.test_workflow.label, TEST_WORKFLOW_LABEL_EDITED)
 
-    def test_workflow_put_view_no_access(self):
+    def test_workflow_put_view_no_permission(self):
         self._create_test_workflow()
 
         response = self._request_test_workflow_edit_put_view()
@@ -397,7 +502,7 @@ class WorkflowAPIViewTestCase(
         self.test_workflow.refresh_from_db()
         self.assertEqual(self.test_workflow.label, TEST_WORKFLOW_LABEL_EDITED)
 
-    def test_document_type_workflow_list_no_access(self):
+    def test_document_type_workflow_list_no_permission(self):
         self._create_test_workflow(add_document_type=True)
 
         response = self._request_test_document_type_workflow_list_api_view()
@@ -445,71 +550,13 @@ class WorkflowAPIViewTestCase(
         )
 
 
-class WorkflowStateAPIViewTestMixin(object):
-    def _request_test_workflow_state_create_api_view(self):
-        return self.post(
-            viewname='rest_api:workflowstate-list',
-            kwargs={'pk': self.test_workflow.pk}, data={
-                'completion': TEST_WORKFLOW_STATE_COMPLETION,
-                'label': TEST_WORKFLOW_STATE_LABEL
-            }
-        )
-
-    def _request_test_workflow_state_delete_api_view(self):
-        return self.delete(
-            viewname='rest_api:workflowstate-detail',
-            kwargs={
-                'pk': self.test_workflow.pk,
-                'state_pk': self.test_workflow_state.pk
-            }
-        )
-
-    def _request_test_workflow_state_detail_api_view(self):
-        return self.get(
-            viewname='rest_api:workflowstate-detail',
-            kwargs={
-                'pk': self.test_workflow.pk,
-                'state_pk': self.test_workflow_state.pk
-            }
-        )
-
-    def _request_test_workflow_state_list_api_view(self):
-        return self.get(
-            viewname='rest_api:workflowstate-list', kwargs={
-                'pk': self.test_workflow.pk
-            }
-        )
-
-    def _request_test_workflow_state_edit_patch_api_view(self):
-        return self.patch(
-            viewname='rest_api:workflowstate-detail',
-            kwargs={
-                'pk': self.test_workflow.pk,
-                'state_pk': self.test_workflow_state.pk
-            }, data={
-                'label': TEST_WORKFLOW_STATE_LABEL_EDITED
-            }
-        )
-
-    def _request_test_workflow_state_edit_put_api_view(self):
-        return self.put(
-            viewname='rest_api:workflowstate-detail',
-            kwargs={
-                'pk': self.test_workflow.pk,
-                'state_pk': self.test_workflow_state.pk
-            }, data={
-                'label': TEST_WORKFLOW_STATE_LABEL_EDITED
-            }
-        )
-
-
 class WorkflowStatesAPIViewTestCase(
     WorkflowStateAPIViewTestMixin, DocumentTestMixin, WorkflowTestMixin,
     BaseAPITestCase
 ):
     auto_upload_test_document = False
 
-    def test_workflow_state_create_view_no_access(self):
+    def test_workflow_state_create_view_no_permission(self):
         self._create_test_workflow()
 
         response = self._request_test_workflow_state_create_api_view()
@@ -533,7 +580,7 @@ class WorkflowStatesAPIViewTestCase(
             self.test_workflow.states.first().label, TEST_WORKFLOW_STATE_LABEL
         )
 
-    def test_workflow_state_delete_view_no_access(self):
+    def test_workflow_state_delete_view_no_permission(self):
         self._create_test_workflow()
         self._create_test_workflow_state()
 
@@ -557,7 +604,7 @@ class WorkflowStatesAPIViewTestCase(
         self.test_workflow.refresh_from_db()
         self.assertEqual(self.test_workflow.states.count(), 0)
 
-    def test_workflow_state_detail_view_no_access(self):
+    def test_workflow_state_detail_view_no_permission(self):
         self._create_test_workflow()
         self._create_test_workflow_state()
 
@@ -580,7 +627,7 @@ class WorkflowStatesAPIViewTestCase(
             response.data['label'], TEST_WORKFLOW_STATE_LABEL
         )
 
-    def test_workflow_state_list_view_no_access(self):
+    def test_workflow_state_list_view_no_permission(self):
         self._create_test_workflow()
         self._create_test_workflow_state()
 
@@ -600,7 +647,7 @@ class WorkflowStatesAPIViewTestCase(
             response.data['results'][0]['label'], TEST_WORKFLOW_STATE_LABEL
         )
 
-    def test_workflow_state_edit_view_via_patch_no_access(self):
+    def test_workflow_state_edit_view_via_patch_no_permission(self):
         self._create_test_workflow()
         self._create_test_workflow_state()
 
@@ -626,7 +673,7 @@ class WorkflowStatesAPIViewTestCase(
             self.test_workflow_state.label, TEST_WORKFLOW_STATE_LABEL_EDITED
         )
 
-    def test_workflow_state_edit_view_via_put_no_access(self):
+    def test_workflow_state_edit_view_via_put_no_permission(self):
         self._create_test_workflow()
         self._create_test_workflow_state()
 
@@ -653,75 +700,13 @@ class WorkflowStatesAPIViewTestCase(
         )
 
 
-class WorkflowTransitionAPIViewTestMixin(object):
-    def _request_test_workflow_transition_create_api_view(self):
-        return self.post(
-            viewname='rest_api:workflowtransition-list',
-            kwargs={'pk': self.test_workflow.pk}, data={
-                'label': TEST_WORKFLOW_TRANSITION_LABEL,
-                'origin_state_pk': self.test_workflow_state_1.pk,
-                'destination_state_pk': self.test_workflow_state_2.pk,
-            }
-        )
-
-    def _request_test_workflow_transition_delete_api_view(self):
-        return self.delete(
-            viewname='rest_api:workflowtransition-detail',
-            kwargs={
-                'pk': self.test_workflow.pk,
-                'transition_pk': self.test_workflow_transition.pk
-            }
-        )
-
-    def _request_test_workflow_transition_detail_api_view(self):
-        return self.get(
-            viewname='rest_api:workflowtransition-detail',
-            kwargs={
-                'pk': self.test_workflow.pk,
-                'transition_pk': self.test_workflow_transition.pk
-            }
-        )
-
-    def _request_test_workflow_transition_list_api_view(self):
-        return self.get(
-            viewname='rest_api:workflowtransition-list',
-            kwargs={'pk': self.test_workflow.pk}
-        )
-
-    def _request_test_workflow_transition_edit_patch_api_view(self):
-        return self.patch(
-            viewname='rest_api:workflowtransition-detail',
-            kwargs={
-                'pk': self.test_workflow.pk,
-                'transition_pk': self.test_workflow_transition.pk
-            }, data={
-                'label': TEST_WORKFLOW_TRANSITION_LABEL_EDITED,
-                'origin_state_pk': self.test_workflow_state_2.pk,
-                'destination_state_pk': self.test_workflow_state_1.pk,
-            }
-        )
-
-    def _request_test_workflow_transition_edit_put_api_view_via(self):
-        return self.put(
-            viewname='rest_api:workflowtransition-detail',
-            kwargs={
-                'pk': self.test_workflow.pk,
-                'transition_pk': self.test_workflow_transition.pk
-            }, data={
-                'label': TEST_WORKFLOW_TRANSITION_LABEL_EDITED,
-                'origin_state_pk': self.test_workflow_state_2.pk,
-                'destination_state_pk': self.test_workflow_state_1.pk,
-            }
-        )
-
-
 class WorkflowTransitionsAPIViewTestCase(
     WorkflowTransitionAPIViewTestMixin, DocumentTestMixin, WorkflowTestMixin,
     BaseAPITestCase
 ):
     auto_upload_test_document = False
 
-    def test_workflow_transition_create_view_no_access(self):
+    def test_workflow_transition_create_view_no_permission(self):
         self._create_test_workflow()
         self._create_test_workflow_states()
 
@@ -748,7 +733,7 @@ class WorkflowTransitionsAPIViewTestCase(
             TEST_WORKFLOW_TRANSITION_LABEL
         )
 
-    def test_workflow_transition_delete_view_no_access(self):
+    def test_workflow_transition_delete_view_no_permission(self):
         self._create_test_workflow()
         self._create_test_workflow_states()
         self._create_test_workflow_transition()
@@ -774,7 +759,7 @@ class WorkflowTransitionsAPIViewTestCase(
         self.test_workflow.refresh_from_db()
         self.assertEqual(self.test_workflow.transitions.count(), 0)
 
-    def test_workflow_transition_detail_view_no_access(self):
+    def test_workflow_transition_detail_view_no_permission(self):
         self._create_test_workflow()
         self._create_test_workflow_states()
         self._create_test_workflow_transition()
@@ -798,7 +783,7 @@ class WorkflowTransitionsAPIViewTestCase(
             response.data['label'], TEST_WORKFLOW_TRANSITION_LABEL
         )
 
-    def test_workflow_transition_list_view_no_access(self):
+    def test_workflow_transition_list_view_no_permission(self):
         self._create_test_workflow()
         self._create_test_workflow_states()
         self._create_test_workflow_transition()
@@ -823,7 +808,7 @@ class WorkflowTransitionsAPIViewTestCase(
             TEST_WORKFLOW_TRANSITION_LABEL
         )
 
-    def test_workflow_transition_edit_view_via_patch_no_access(self):
+    def test_workflow_transition_edit_view_via_patch_no_permission(self):
         self._create_test_workflow()
         self._create_test_workflow_states()
         self._create_test_workflow_transition()
@@ -871,7 +856,7 @@ class WorkflowTransitionsAPIViewTestCase(
             self.test_workflow_state_1
         )
 
-    def test_workflow_transition_edit_view_via_put_no_access(self):
+    def test_workflow_transition_edit_view_via_put_no_permission(self):
         self._create_test_workflow()
         self._create_test_workflow_states()
         self._create_test_workflow_transition()
@@ -917,225 +902,3 @@ class WorkflowTransitionsAPIViewTestCase(
             self.test_workflow_transition.destination_state,
             self.test_workflow_state_1
         )
-
-
-class DocumentWorkflowAPIViewTestMixin(object):
-    def _request_test_workflow_instance_detail_api_view(self):
-        return self.get(
-            viewname='rest_api:workflowinstance-detail', kwargs={
-                'pk': self.test_document.pk,
-                'workflow_pk': self.test_document.workflows.first().pk
-            }
-        )
-
-    def _request_test_workflow_instance_list_api_view(self):
-        return self.get(
-            viewname='rest_api:workflowinstance-list',
-            kwargs={'pk': self.test_document.pk}
-        )
-
-    def _request_test_workflow_instance_log_entry_create_api_view(self, workflow_instance):
-        return self.post(
-            viewname='rest_api:workflowinstancelogentry-list', kwargs={
-                'pk': self.test_document.pk,
-                'workflow_pk': workflow_instance.pk
-            }, data={'transition_pk': self.test_workflow_transition.pk}
-        )
-
-    def _request_test_workflow_instance_log_entry_list_api_view(self):
-        return self.get(
-            viewname='rest_api:workflowinstancelogentry-list', kwargs={
-                'pk': self.test_document.pk,
-                'workflow_pk': self.test_document.workflows.first().pk
-            }
-        )
-
-
-class DocumentWorkflowsAPIViewTestCase(
-    DocumentWorkflowAPIViewTestMixin, DocumentTestMixin, WorkflowTestMixin,
-    BaseAPITestCase
-):
-    auto_upload_test_document = False
-
-    def test_workflow_instance_detail_view_no_access(self):
-        self._create_test_workflow(add_document_type=True)
-        self._create_test_workflow_states()
-        self._create_test_workflow_transition()
-        self._upload_test_document()
-
-        response = self._request_test_workflow_instance_detail_api_view()
-        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
-        self.assertFalse('workflow' in response.data)
-
-    def test_workflow_instance_detail_view_with_workflow_access(self):
-        self._create_test_workflow(add_document_type=True)
-        self._create_test_workflow_states()
-        self._create_test_workflow_transition()
-        self._upload_test_document()
-
-        self.grant_access(
-            obj=self.test_workflow, permission=permission_workflow_view
-        )
-
-        response = self._request_test_workflow_instance_detail_api_view()
-        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
-        self.assertFalse('workflow' in response.data)
-
-    def test_workflow_instance_detail_view_with_document_access(self):
-        self._create_test_workflow(add_document_type=True)
-        self._create_test_workflow_states()
-        self._create_test_workflow_transition()
-        self._upload_test_document()
-
-        self.grant_access(
-            obj=self.test_document, permission=permission_workflow_view
-        )
-
-        response = self._request_test_workflow_instance_detail_api_view()
-        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
-        self.assertFalse('workflow' in response.data)
-
-    def test_workflow_instance_detail_view_with_access(self):
-        self._create_test_workflow(add_document_type=True)
-        self._create_test_workflow_states()
-        self._create_test_workflow_transition()
-        self._upload_test_document()
-
-        self.grant_access(
-            obj=self.test_workflow, permission=permission_workflow_view
-        )
-        self.grant_access(
-            obj=self.test_document, permission=permission_workflow_view
-        )
-
-        response = self._request_test_workflow_instance_detail_api_view()
-        self.assertEqual(response.status_code, status.HTTP_200_OK)
-        self.assertEqual(
-            response.data['workflow']['label'],
-            TEST_WORKFLOW_LABEL
-        )
-
-    def test_workflow_instance_list_view_no_access(self):
-        self._create_test_workflow(add_document_type=True)
-        self._create_test_workflow_states()
-        self._create_test_workflow_transition()
-        self._upload_test_document()
-
-        response = self._request_test_workflow_instance_list_api_view()
-        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
-        self.assertFalse('result' in response.data)
-
-    def test_workflow_instance_list_view_with_document_access(self):
-        self._create_test_workflow(add_document_type=True)
-        self._create_test_workflow_states()
-        self._create_test_workflow_transition()
-        self._upload_test_document()
-
-        self.grant_access(
-            obj=self.test_document, permission=permission_workflow_view
-        )
-
-        response = self._request_test_workflow_instance_list_api_view()
-        self.assertEqual(response.status_code, status.HTTP_200_OK)
-        self.assertEqual(response.data['count'], 0)
-
-    def test_workflow_instance_list_view_with_workflow_access(self):
-        self._create_test_workflow(add_document_type=True)
-        self._create_test_workflow_states()
-        self._create_test_workflow_transition()
-        self._upload_test_document()
-
-        self.grant_access(
-            obj=self.test_workflow, permission=permission_workflow_view
-        )
-
-        response = self._request_test_workflow_instance_list_api_view()
-        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
-        self.assertFalse('result' in response.data)
-
-    def test_workflow_instance_list_view_with_access(self):
-        self._create_test_workflow(add_document_type=True)
-        self._create_test_workflow_states()
-        self._create_test_workflow_transition()
-        self._upload_test_document()
-
-        self.grant_access(
-            obj=self.test_workflow, permission=permission_workflow_view
-        )
-        self.grant_access(
-            obj=self.test_document, permission=permission_workflow_view
-        )
-
-        response = self._request_test_workflow_instance_list_api_view()
-        self.assertEqual(response.status_code, status.HTTP_200_OK)
-        self.assertEqual(
-            response.data['results'][0]['workflow']['label'],
-            TEST_WORKFLOW_LABEL
-        )
-
-    def test_workflow_instance_log_entries_create_view_no_access(self):
-        self._create_test_workflow(add_document_type=True)
-        self._create_test_workflow_states()
-        self._create_test_workflow_transition()
-        self._upload_test_document()
-
-        workflow_instance = self.test_document.workflows.first()
-        response = self._request_test_workflow_instance_log_entry_create_api_view(
-            workflow_instance=workflow_instance
-        )
-        self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
-        # We get bad request because we try to create a transition for which
-        # we don't have permission and therefore is not valid for this
-        # workflow instance current state
-        self.assertEqual(workflow_instance.log_entries.count(), 0)
-
-    def test_workflow_instance_log_entries_create_view_with_workflow_access(self):
-        self._create_test_workflow(add_document_type=True)
-        self._create_test_workflow_states()
-        self._create_test_workflow_transition()
-        self._upload_test_document()
-
-        self.grant_access(
-            obj=self.test_workflow, permission=permission_workflow_transition
-        )
-        workflow_instance = self.test_document.workflows.first()
-
-        response = self._request_test_workflow_instance_log_entry_create_api_view(
-            workflow_instance=workflow_instance
-        )
-        self.assertEqual(response.status_code, status.HTTP_201_CREATED)
-
-        workflow_instance.refresh_from_db()
-        self.assertEqual(
-            workflow_instance.log_entries.first().transition.label,
-            TEST_WORKFLOW_TRANSITION_LABEL
-        )
-
-    def test_workflow_instance_log_entries_list_view_no_access(self):
-        self._create_test_workflow(add_document_type=True)
-        self._create_test_workflow_states()
-        self._create_test_workflow_transition()
-        self._upload_test_document()
-        self._create_test_workflow_instance_log_entry()
-
-        response = self._request_test_workflow_instance_log_entry_list_api_view()
-        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
-        self.assertFalse('results' in response.data)
-
-    def test_workflow_instance_log_entries_list_view_with_document_access(self):
-        self._create_test_workflow(add_document_type=True)
-        self._create_test_workflow_states()
-        self._create_test_workflow_transition()
-        self._upload_test_document()
-        self._create_test_workflow_instance_log_entry()
-
-        self.grant_access(
-            obj=self.test_document, permission=permission_workflow_view
-        )
-
-        response = self._request_test_workflow_instance_log_entry_list_api_view()
-        self.assertEqual(response.status_code, status.HTTP_200_OK)
-        self.assertEqual(
-            response.data['results'][0]['transition']['label'],
-            TEST_WORKFLOW_TRANSITION_LABEL
-        )
