@@ -1,5 +1,5 @@
-from mayan.apps.common.tests.base import GenericViewTestCase
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
+from mayan.apps.testing.tests.base import GenericViewTestCase
 
 from ..models import Workflow
 from ..permissions import (
@@ -10,10 +10,82 @@ from ..permissions import (
 
 from .literals import TEST_WORKFLOW_LABEL, TEST_WORKFLOW_LABEL_EDITED
 from .mixins import (
-    WorkflowTestMixin, WorkflowToolViewTestMixin, WorkflowViewTestMixin
+    DocumentWorkflowTemplateViewTestMixin, WorkflowTestMixin,
+    WorkflowToolViewTestMixin, WorkflowViewTestMixin
 )
 
 
+class DocumentWorkflowTemplateViewTestCase(
+    DocumentWorkflowTemplateViewTestMixin, WorkflowTestMixin,
+    GenericDocumentViewTestCase
+):
+    auto_upload_document = False
+
+    def setUp(self):
+        super().setUp()
+        self._create_test_workflow()
+        self._create_test_workflow_states()
+        self._create_test_workflow_transition()
+        self.test_workflow.document_types.add(self.test_document_type)
+        self.test_workflow.auto_launch = False
+        self.test_workflow.save()
+
+    def test_document_single_workflow_launch_view_no_permission(self):
+        workflow_instance_count = self.test_document.workflows.count()
+
+        response = self._request_test_document_single_workflow_launch_view()
+        self.assertEqual(response.status_code, 404)
+
+        self.assertEqual(
+            self.test_document.workflows.count(), workflow_instance_count
+        )
+
+    def test_document_single_workflow_launch_view_with_document_access(self):
+        self.grant_access(
+            obj=self.test_document, permission=permission_workflow_tools
+        )
+
+        workflow_instance_count = self.test_document.workflows.count()
+
+        response = self._request_test_document_single_workflow_launch_view()
+        self.assertEqual(response.status_code, 200)
+
+        self.assertEqual(
+            self.test_document.workflows.count(), workflow_instance_count
+        )
+
+    def test_document_single_workflow_launch_view_with_workflow_access(self):
+        self.grant_access(
+            obj=self.test_workflow, permission=permission_workflow_tools
+        )
+
+        workflow_instance_count = self.test_document.workflows.count()
+
+        response = self._request_test_document_single_workflow_launch_view()
+        self.assertEqual(response.status_code, 404)
+
+        self.assertEqual(
+            self.test_document.workflows.count(), workflow_instance_count
+        )
+
+    def test_document_single_workflow_launch_view_with_full_access(self):
+        self.grant_access(
+            obj=self.test_document, permission=permission_workflow_tools
+        )
+        self.grant_access(
+            obj=self.test_workflow, permission=permission_workflow_tools
+        )
+
+        workflow_instance_count = self.test_document.workflows.count()
+
+        response = self._request_test_document_single_workflow_launch_view()
+        self.assertEqual(response.status_code, 302)
+
+        self.assertEqual(
+            self.test_document.workflows.count(), workflow_instance_count + 1
+        )
+
+
 class WorkflowViewTestCase(
     WorkflowTestMixin, WorkflowViewTestMixin, GenericViewTestCase
 ):
@@ -32,7 +104,7 @@ class WorkflowViewTestCase(
         self.assertEqual(Workflow.objects.count(), 1)
         self.assertEqual(Workflow.objects.all()[0].label, TEST_WORKFLOW_LABEL)
 
-    def test_workflow_delete_view_no_access(self):
+    def test_workflow_delete_view_no_permission(self):
         self._create_test_workflow()
 
         response = self._request_test_workflow_delete_view()
@@ -52,7 +124,7 @@ class WorkflowViewTestCase(
 
         self.assertFalse(self.test_workflow in Workflow.objects.all())
 
-    def test_workflow_edit_view_no_access(self):
+    def test_workflow_edit_view_no_permission(self):
         self._create_test_workflow()
 
         response = self._request_test_workflow_edit_view()
@@ -74,7 +146,7 @@ class WorkflowViewTestCase(
         self.test_workflow.refresh_from_db()
         self.assertEqual(self.test_workflow.label, TEST_WORKFLOW_LABEL_EDITED)
 
-    def test_workflow_list_view_no_access(self):
+    def test_workflow_list_view_no_permission(self):
         self._create_test_workflow()
 
         response = self._request_test_workflow_list_view()
@@ -93,7 +165,7 @@ class WorkflowViewTestCase(
         self.assertEqual(response.status_code, 200)
         self.assertContains(response, text=self.test_workflow.label)
 
-    def test_workflow_template_preview_view_no_access(self):
+    def test_workflow_template_preview_view_no_permission(self):
         self._create_test_workflow()
 
         response = self._request_test_workflow_template_preview_view()
