@@ -1,10 +1,10 @@
 from django.template import RequestContext
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.common.generics import SingleObjectListView
-from mayan.apps.common.mixins import ExternalObjectMixin
 from mayan.apps.documents.models import Document
 from mayan.apps.documents.views.document_views import DocumentListView
+from mayan.apps.views.generics import SingleObjectListView
+from mayan.apps.views.mixins import ExternalObjectMixin
 
 from ..icons import icon_workflow_template_list
 from ..links import link_workflow_template_create, link_workflow_template_state_create
