@@ -3,12 +3,12 @@ from django.template import RequestContext
 from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.common.generics import (
+from mayan.apps.views.generics import (
     FormView, SingleObjectCreateView, SingleObjectDeleteView,
     SingleObjectDynamicFormCreateView, SingleObjectDynamicFormEditView,
     SingleObjectEditView, SingleObjectListView
 )
-from mayan.apps.common.mixins import ExternalObjectMixin
+from mayan.apps.views.mixins import ExternalObjectMixin
 
 from ..classes import WorkflowAction
 from ..forms import (
@@ -57,10 +57,13 @@ class WorkflowTemplateStateActionCreateView(
         }
 
     def get_form_schema(self):
-        return self.get_class()().get_form_schema(request=self.request)
+        return self.get_class()().get_form_schema(
+            request=self.request, workflow_state=self.external_object
+        )
 
     def get_instance_extra_data(self):
         return {
+            '_event_actor': self.request.user,
             'action_path': self.kwargs['class_path'],
             'state': self.external_object
         }
@@ -90,6 +93,11 @@ class WorkflowTemplateStateActionDeleteView(SingleObjectDeleteView):
             'workflow_state': self.object.state,
         }
 
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
+
     def get_post_action_redirect(self):
         return reverse(
             viewname='document_states:workflow_template_state_action_list',
@@ -124,9 +132,14 @@ class WorkflowTemplateStateActionEditView(SingleObjectDynamicFormEditView):
 
     def get_form_schema(self):
         return self.object.get_class_instance().get_form_schema(
-            request=self.request
+            request=self.request, workflow_state=self.object.state
         )
 
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
+
     def get_post_action_redirect(self):
         return reverse(
             viewname='document_states:workflow_template_state_action_list',
@@ -221,7 +234,10 @@ class WorkflowTemplateStateCreateView(ExternalObjectMixin, SingleObjectCreateVie
         }
 
     def get_instance_extra_data(self):
-        return {'workflow': self.external_object}
+        return {
+            '_event_actor': self.request.user,
+            'workflow': self.external_object
+        }
 
     def get_source_queryset(self):
         return self.external_object.states.all()
@@ -250,6 +266,11 @@ class WorkflowTemplateStateDeleteView(SingleObjectDeleteView):
             'workflow': self.object.workflow,
         }
 
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
+
     def get_success_url(self):
         return reverse(
             viewname='document_states:workflow_template_state_list',
@@ -275,6 +296,11 @@ class WorkflowTemplateStateEditView(SingleObjectEditView):
             'workflow': self.object.workflow,
         }
 
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
+
     def get_success_url(self):
         return reverse(
             viewname='document_states:workflow_template_state_list',
