@@ -3,13 +3,13 @@ from django.template import RequestContext
 from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.common.generics import (
+from mayan.apps.events.classes import EventType
+from mayan.apps.events.models import StoredEventType
+from mayan.apps.views.generics import (
     FormView, SingleObjectCreateView, SingleObjectDeleteView,
     SingleObjectEditView, SingleObjectListView
 )
-from mayan.apps.common.mixins import ExternalObjectMixin
-from mayan.apps.events.classes import EventType
-from mayan.apps.events.models import StoredEventType
+from mayan.apps.views.mixins import ExternalObjectMixin
 
 from ..forms import (
     WorkflowTransitionForm, WorkflowTransitionTriggerEventRelationshipFormSet
@@ -46,7 +46,10 @@ class WorkflowTemplateTransitionCreateView(ExternalObjectMixin, SingleObjectCrea
         return kwargs
 
     def get_instance_extra_data(self):
-        return {'workflow': self.external_object}
+        return {
+            '_event_actor': self.request.user,
+            'workflow': self.external_object
+        }
 
     def get_source_queryset(self):
         return self.external_object.transitions.all()
@@ -77,6 +80,11 @@ class WorkflowTemplateTransitionDeleteView(SingleObjectDeleteView):
             'workflow': self.object.workflow,
         }
 
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
+
     def get_success_url(self):
         return reverse(
             viewname='document_states:workflow_template_transition_list',
@@ -107,6 +115,11 @@ class WorkflowTemplateTransitionEditView(SingleObjectEditView):
         kwargs['workflow'] = self.object.workflow
         return kwargs
 
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
+
     def get_success_url(self):
         return reverse(
             viewname='document_states:workflow_template_transition_list',
@@ -248,6 +261,7 @@ class WorkflowTemplateTransitionFieldCreateView(
 
     def get_instance_extra_data(self):
         return {
+            '_event_actor': self.request.user,
             'transition': self.external_object,
         }
 
@@ -279,6 +293,11 @@ class WorkflowTemplateTransitionFieldDeleteView(SingleObjectDeleteView):
             'workflow_transition': self.object.transition,
         }
 
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
+
     def get_post_action_redirect(self):
         return reverse(
             viewname='document_states:workflow_template_transition_field_list',
@@ -308,6 +327,11 @@ class WorkflowTemplateTransitionFieldEditView(SingleObjectEditView):
             'workflow_transition': self.object.transition,
         }
 
+    def get_instance_extra_data(self):
+        return {
+            '_event_actor': self.request.user
+        }
+
     def get_post_action_redirect(self):
         return reverse(
             viewname='document_states:workflow_template_transition_field_list',
