@@ -10,7 +10,7 @@ from rest_framework.response import Response
 
 from mayan.apps.acls.models import AccessControlList
 from mayan.apps.rest_api import generics
-from mayan.apps.common.generics import DownloadMixin
+from mayan.apps.views.generics import DownloadMixin
 
 from .literals import DOCUMENT_IMAGE_TASK_TIMEOUT
 from .models import (
@@ -168,7 +168,7 @@ class APIDocumentPageImageView(generics.RetrieveAPIView):
         else:
             permission_required = permission_document_edit
 
-        document = get_object_or_404(Document.passthrough, pk=self.kwargs['pk'])
+        document = get_object_or_404(Document, pk=self.kwargs['pk'])
 
         AccessControlList.objects.check_access(
             obj=document, permissions=(permission_required,),
@@ -182,7 +182,7 @@ class APIDocumentPageImageView(generics.RetrieveAPIView):
         )
 
     def get_queryset(self):
-        return self.get_document_version().pages_all.all()
+        return self.get_document_version().pages.all()
 
     def get_serializer(self, *args, **kwargs):
         return None
