@@ -4,22 +4,22 @@ from furl import furl
 
 from django.db import models
 from django.urls import reverse
-from django.utils.encoding import force_text, python_2_unicode_compatible
+from django.utils.encoding import force_text
 from django.utils.functional import cached_property
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.converter.literals import DEFAULT_ZOOM_LEVEL, DEFAULT_ROTATION
 
+from mayan.apps.converter.classes import ConverterBase
 from mayan.apps.converter.models import LayerTransformation
 from mayan.apps.converter.transformations import (
     BaseTransformation, TransformationResize, TransformationRotate,
     TransformationZoom
 )
-from mayan.apps.converter.utils import get_converter_class
+from mayan.apps.lock_manager.backends.base import LockingBackend
 
-from ..managers import DocumentPageManager
+from ..managers import DocumentPageManager, ValidDocumentPageManager
 from ..settings import (
-    setting_disable_base_image_cache, setting_disable_transformed_image_cache,
     setting_display_width, setting_display_height, setting_zoom_max_level,
     setting_zoom_min_level
 )
@@ -30,7 +30,6 @@ __all__ = ('DocumentPage', 'DocumentPageResult')
 logger = logging.getLogger(name=__name__)
 
 
-@python_2_unicode_compatible
 class DocumentPage(models.Model):
     """
     Model that describes a document version page
@@ -46,7 +45,7 @@ class DocumentPage(models.Model):
     )
 
     objects = DocumentPageManager()
-    passthrough = models.Manager()
+    valid = ValidDocumentPageManager()
 
     class Meta:
         ordering = ('page_number',)
@@ -69,7 +68,7 @@ class DocumentPage(models.Model):
 
     def detect_orientation(self):
         with self.document_version.open() as file_object:
-            converter = get_converter_class()(
+            converter = ConverterBase.get_converter_class()(
                 file_object=file_object,
                 mime_type=self.document_version.mimetype
             )
@@ -88,19 +87,32 @@ class DocumentPage(models.Model):
         # Check is transformed image is available
         logger.debug('transformations cache filename: %s', combined_cache_filename)
 
-        if not setting_disable_transformed_image_cache.value and self.cache_partition.get_file(filename=combined_cache_filename):
-            logger.debug(
-                'transformations cache file "%s" found', combined_cache_filename
+        try:
+            lock = LockingBackend.get_instance().acquire_lock(
+                name='document_page_generate_image_{}_{}'.format(
+                    self.pk, combined_cache_filename
+                )
             )
+        except Exception:
+            raise
         else:
-            logger.debug(
-                'transformations cache file "%s" not found', combined_cache_filename
-            )
-            image = self.get_image(transformations=transformation_list)
-            with self.cache_partition.create_file(filename=combined_cache_filename) as file_object:
-                file_object.write(image.getvalue())
-
-        return combined_cache_filename
+            # Second try block to release the lock even on fatal errors inside
+            # the block.
+            try:
+                if self.cache_partition.get_file(filename=combined_cache_filename):
+                    logger.debug(
+                        'transformations cache file "%s" found', combined_cache_filename
+                    )
+                else:
+                    logger.debug(
+                        'transformations cache file "%s" not found', combined_cache_filename
+                    )
+                    image = self.get_image(transformations=transformation_list)
+                    with self.cache_partition.create_file(filename=combined_cache_filename) as file_object:
+                        file_object.write(image.getvalue())
+                return combined_cache_filename
+            finally:
+                lock.release()
 
     def get_absolute_url(self):
         return reverse(
@@ -128,7 +140,7 @@ class DocumentPage(models.Model):
         final_url.args = kwargs
         final_url.path = reverse(
             viewname='rest_api:documentpage-image', kwargs={
-                'pk': self.document.pk, 'version_pk': self.document_version.pk,
+                'pk': self.document_version.document_id, 'version_pk': self.document_version_id,
                 'page_pk': self.pk
             }
         )
@@ -195,11 +207,11 @@ class DocumentPage(models.Model):
 
         cache_file = self.cache_partition.get_file(filename=cache_filename)
 
-        if not setting_disable_base_image_cache.value and cache_file:
+        if cache_file:
             logger.debug('Page cache file "%s" found', cache_filename)
 
             with cache_file.open() as file_object:
-                converter = get_converter_class()(
+                converter = ConverterBase.get_converter_class()(
                     file_object=file_object
                 )
 
@@ -217,7 +229,7 @@ class DocumentPage(models.Model):
 
             try:
                 with self.document_version.get_intermediate_file() as file_object:
-                    converter = get_converter_class()(
+                    converter = ConverterBase.get_converter_class()(
                         file_object=file_object
                     )
                     converter.seek_page(page_number=self.page_number - 1)
@@ -246,13 +258,16 @@ class DocumentPage(models.Model):
         return self.document.is_in_trash
 
     def get_label(self):
-        return _(
-            'Page %(page_num)d out of %(total_pages)d of %(document)s'
-        ) % {
-            'document': force_text(self.document),
-            'page_num': self.page_number,
-            'total_pages': self.document_version.pages_all.count()
-        }
+        if getattr(self, 'document_version', None):
+            return _(
+                'Page %(page_num)d out of %(total_pages)d of %(document)s'
+            ) % {
+                'document': force_text(self.document),
+                'page_num': self.page_number,
+                'total_pages': self.document_version.pages.all().count()
+            }
+        else:
+            return None
     get_label.short_description = _('Label')
 
     def natural_key(self):
@@ -261,7 +276,7 @@ class DocumentPage(models.Model):
 
     @property
     def siblings(self):
-        return DocumentPage.objects.filter(
+        return DocumentPage.valid.filter(
             document_version=self.document_version
         )
 
