@@ -2,10 +2,12 @@ from django.apps import apps
 from django.db import connection
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.common.literals import LIST_MODE_CHOICE_ITEM
 from mayan.apps.dynamic_search.classes import SearchModel
+from mayan.apps.views.literals import LIST_MODE_CHOICE_ITEM
 
-from .permissions import permission_document_view
+from .permissions import (
+    permission_document_type_view, permission_document_view
+)
 
 
 def transformation_format_uuid(term_string):
@@ -30,20 +32,15 @@ document_search = SearchModel(
 )
 
 document_search.add_model_field(
-    field='document_type__label', label=_('Document type')
+    field='document_type__label', label=_('Document type label')
 )
+document_search.add_model_field(field='versions__mimetype')
+document_search.add_model_field(field='label')
+document_search.add_model_field(field='description')
 document_search.add_model_field(
-    field='versions__mimetype', label=_('MIME type')
-)
-document_search.add_model_field(field='label', label=_('Label'))
-document_search.add_model_field(field='description', label=_('Description'))
-document_search.add_model_field(
-    field='uuid', label=_('UUID'),
-    transformation_function=transformation_format_uuid
-)
-document_search.add_model_field(
-    field='versions__checksum', label=_('Checksum')
+    field='uuid', transformation_function=transformation_format_uuid
 )
+document_search.add_model_field(field='versions__checksum')
 
 document_page_search = SearchModel(
     app_label='documents', list_mode=LIST_MODE_CHOICE_ITEM,
@@ -54,18 +51,22 @@ document_page_search = SearchModel(
 
 document_page_search.add_model_field(
     field='document_version__document__document_type__label',
-    label=_('Document type')
+    label=_('Document type label')
 )
 document_page_search.add_model_field(
-    field='document_version__document__versions__mimetype',
-    label=_('MIME type')
+    field='document_version__document__versions__mimetype'
 )
 document_page_search.add_model_field(
-    field='document_version__document__label', label=_('Label')
+    field='document_version__document__label'
 )
 document_page_search.add_model_field(
-    field='document_version__document__description', label=_('Description')
+    field='document_version__document__description'
 )
-document_page_search.add_model_field(
-    field='document_version__checksum', label=_('Checksum')
+document_page_search.add_model_field(field='document_version__checksum')
+
+document_type_search = SearchModel(
+    app_label='documents', list_mode=LIST_MODE_CHOICE_ITEM,
+    model_name='DocumentType', permission=permission_document_type_view,
+    serializer_path='mayan.apps.documents.serializers.DocumentTypeSerializer'
 )
+document_type_search.add_model_field(field='label')
