@@ -1,8 +1,8 @@
-from mayan.apps.smart_settings.classes import NamespaceMigration
+from mayan.apps.smart_settings.classes import SettingNamespaceMigration
 from mayan.apps.smart_settings.utils import smart_yaml_load
 
 
-class DocumentsSettingMigration(NamespaceMigration):
+class DocumentsSettingMigration(SettingNamespaceMigration):
     """
     From version 0001 to 0002 backend arguments are no longer quoted
     but YAML valid too. Changed in version 3.3.
