@@ -3,17 +3,18 @@ import os
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.smart_settings.classes import Namespace
+from mayan.apps.smart_settings.classes import SettingNamespace
 
 from .literals import (
     DEFAULT_DOCUMENTS_CACHE_MAXIMUM_SIZE, DEFAULT_DOCUMENTS_HASH_BLOCK_SIZE,
     DEFAULT_LANGUAGE, DEFAULT_LANGUAGE_CODES,
-    DEFAULT_STUB_EXPIRATION_INTERVAL
+    DEFAULT_STUB_EXPIRATION_INTERVAL,
+    DEFAULT_TASK_GENERATE_DOCUMENT_PAGE_IMAGE_RETRY_DELAY
 )
 from .setting_callbacks import callback_update_cache_size
 from .setting_migrations import DocumentsSettingMigration
 
-namespace = Namespace(
+namespace = SettingNamespace(
     label=_('Documents'), migration_class=DocumentsSettingMigration,
     name='documents', version='0002'
 )
@@ -41,21 +42,6 @@ setting_documentimagecache_storage_arguments = namespace.add_setting(
         'Arguments to pass to the DOCUMENT_CACHE_STORAGE_BACKEND.'
     ),
 )
-setting_disable_base_image_cache = namespace.add_setting(
-    global_name='DOCUMENTS_DISABLE_BASE_IMAGE_CACHE', default=False,
-    help_text=_(
-        'Disables the first cache tier which stores high resolution, '
-        'non transformed versions of documents\'s pages.'
-    )
-)
-setting_disable_transformed_image_cache = namespace.add_setting(
-    global_name='DOCUMENTS_DISABLE_TRANSFORMED_IMAGE_CACHE', default=False,
-    help_text=_(
-        'Disables the second cache tier which stores medium to low '
-        'resolution, transformed (rotated, zoomed, etc) versions '
-        'of documents\' pages.'
-    )
-)
 setting_display_height = namespace.add_setting(
     global_name='DOCUMENTS_DISPLAY_HEIGHT', default=''
 )
@@ -151,6 +137,14 @@ setting_stub_expiration_interval = namespace.add_setting(
         'deleted.'
     )
 )
+setting_task_generate_document_page_image_retry_delay = namespace.add_setting(
+    global_name='DOCUMENT_TASK_GENERATE_DOCUMENT_PAGE_IMAGE_RETRY_DELAY',
+    default=DEFAULT_TASK_GENERATE_DOCUMENT_PAGE_IMAGE_RETRY_DELAY,
+    help_text=_(
+        'Amount of time in seconds, a failed document page image task will '
+        'wait before retrying.'
+    )
+)
 setting_thumbnail_height = namespace.add_setting(
     global_name='DOCUMENTS_THUMBNAIL_HEIGHT', default='', help_text=_(
         'Height in pixels of the document thumbnail image.'
