@@ -4,11 +4,13 @@ from django.apps import apps
 from django.contrib.auth import get_user_model
 from django.db import OperationalError
 
+from mayan.apps.lock_manager.exceptions import LockError
 from mayan.celery import app
 
 from .literals import (
     UPDATE_PAGE_COUNT_RETRY_DELAY, UPLOAD_NEW_VERSION_RETRY_DELAY
 )
+from .settings import setting_task_generate_document_page_image_retry_delay
 
 logger = logging.getLogger(name=__name__)
 
@@ -58,12 +60,17 @@ def task_delete_stubs():
     )
 
     logger.info(msg='Executing')
-    Document.passthrough.delete_stubs()
+    Document.objects.delete_stubs()
     logger.info(msg='Finshed')
 
 
-@app.task()
-def task_generate_document_page_image(document_page_id, user_id=None, **kwargs):
+@app.task(
+    bind=True,
+    default_retry_delay=setting_task_generate_document_page_image_retry_delay.value
+)
+def task_generate_document_page_image(
+    self, document_page_id, user_id=None, **kwargs
+):
     DocumentPage = apps.get_model(
         app_label='documents', model_name='DocumentPage'
     )
@@ -74,8 +81,16 @@ def task_generate_document_page_image(document_page_id, user_id=None, **kwargs):
     else:
         user = None
 
-    document_page = DocumentPage.passthrough.get(pk=document_page_id)
-    return document_page.generate_image(user=user, **kwargs)
+    document_page = DocumentPage.objects.get(pk=document_page_id)
+    try:
+        return document_page.generate_image(user=user, **kwargs)
+    except LockError as exception:
+        logger.warning(
+            'LockError during attempt to generate document page image for '
+            'document id: %d, document page id: %d. Retrying.',
+            document_page.pk, document_page.document.pk
+        )
+        raise self.retry(exc=exception)
 
 
 @app.task(ignore_result=True)
@@ -101,6 +116,18 @@ def task_scan_duplicates_for(document_id):
     DuplicatedDocument.objects.scan_for(document=document)
 
 
+@app.task(ignore_result=True)
+def task_trash_can_empty():
+    DeletedDocument = apps.get_model(
+        app_label='documents', model_name='DeletedDocument'
+    )
+
+    for deleted_document in DeletedDocument.objects.all():
+        task_delete_document.apply_async(
+            kwargs={'trashed_document_id': deleted_document.pk}
+        )
+
+
 @app.task(bind=True, default_retry_delay=UPDATE_PAGE_COUNT_RETRY_DELAY, ignore_result=True)
 def task_update_page_count(self, version_id):
     DocumentVersion = apps.get_model(
@@ -121,10 +148,6 @@ def task_update_page_count(self, version_id):
 
 @app.task(bind=True, default_retry_delay=UPLOAD_NEW_VERSION_RETRY_DELAY, ignore_result=True)
 def task_upload_new_version(self, document_id, shared_uploaded_file_id, user_id, comment=None):
-    SharedUploadedFile = apps.get_model(
-        app_label='common', model_name='SharedUploadedFile'
-    )
-
     Document = apps.get_model(
         app_label='documents', model_name='Document'
     )
@@ -133,8 +156,12 @@ def task_upload_new_version(self, document_id, shared_uploaded_file_id, user_id,
         app_label='documents', model_name='DocumentVersion'
     )
 
+    SharedUploadedFile = apps.get_model(
+        app_label='storage', model_name='SharedUploadedFile'
+    )
+
     try:
-        document = Document.passthrough.get(pk=document_id)
+        document = Document.objects.get(pk=document_id)
         shared_file = SharedUploadedFile.objects.get(
             pk=shared_uploaded_file_id
         )
