@@ -1,5 +1,3 @@
-import time
-
 from django.utils.encoding import force_text
 
 from rest_framework import status
@@ -19,41 +17,15 @@ from ..permissions import (
 
 from .literals import (
     TEST_DOCUMENT_DESCRIPTION_EDITED, TEST_PDF_DOCUMENT_FILENAME,
-    TEST_DOCUMENT_PATH, TEST_DOCUMENT_TYPE_LABEL, TEST_DOCUMENT_TYPE_2_LABEL,
+    TEST_DOCUMENT_TYPE_LABEL, TEST_DOCUMENT_TYPE_2_LABEL,
     TEST_DOCUMENT_TYPE_LABEL_EDITED, TEST_DOCUMENT_VERSION_COMMENT_EDITED,
     TEST_SMALL_DOCUMENT_FILENAME
 )
-from .mixins import DocumentTestMixin, DocumentVersionTestMixin
-
-
-class DocumentTypeAPIViewTestMixin(object):
-    def _request_test_document_type_api_create_view(self):
-        return self.post(
-            viewname='rest_api:documenttype-list', data={
-                'label': TEST_DOCUMENT_TYPE_LABEL
-            }
-        )
-
-    def _request_test_document_type_api_delete_view(self):
-        return self.delete(
-            viewname='rest_api:documenttype-detail', kwargs={
-                'pk': self.test_document_type.pk,
-            }
-        )
-
-    def _request_test_document_type_api_patch_view(self):
-        return self.patch(
-            viewname='rest_api:documenttype-detail', kwargs={
-                'pk': self.test_document_type.pk,
-            }, data={'label': TEST_DOCUMENT_TYPE_LABEL_EDITED}
-        )
-
-    def _request_test_document_type_api_put_view(self):
-        return self.put(
-            viewname='rest_api:documenttype-detail', kwargs={
-                'pk': self.test_document_type.pk,
-            }, data={'label': TEST_DOCUMENT_TYPE_LABEL_EDITED}
-        )
+from .mixins import (
+    DocumentAPIViewTestMixin, DocumentPageAPIViewTestMixin, DocumentTestMixin,
+    DocumentTypeAPIViewTestMixin, DocumentVersionAPIViewTestMixin,
+    DocumentVersionTestMixin, TrashedDocumentAPIViewTestMixin
+)
 
 
 class DocumentTypeAPIViewTestCase(
@@ -150,45 +122,6 @@ class DocumentTypeAPIViewTestCase(
         )
 
 
-class DocumentAPIViewTestMixin(object):
-    def _request_test_document_api_download_view(self):
-        return self.get(
-            viewname='rest_api:document-download', kwargs={
-                'pk': self.test_document.pk
-            }
-        )
-
-    def _request_test_document_api_upload_view(self):
-        with open(TEST_DOCUMENT_PATH, mode='rb') as file_object:
-            return self.post(
-                viewname='rest_api:document-list', data={
-                    'document_type': self.test_document_type.pk,
-                    'file': file_object
-                }
-            )
-
-    def _request_test_document_description_api_edit_via_patch_view(self):
-        return self.patch(
-            viewname='rest_api:document-detail', kwargs={
-                'pk': self.test_document.pk
-            }, data={'description': TEST_DOCUMENT_DESCRIPTION_EDITED}
-        )
-
-    def _request_test_document_description_api_edit_via_put_view(self):
-        return self.put(
-            viewname='rest_api:document-detail', kwargs={
-                'pk': self.test_document.pk
-            }, data={'description': TEST_DOCUMENT_DESCRIPTION_EDITED}
-        )
-
-    def _request_test_document_document_type_change_api_view(self):
-        return self.post(
-            viewname='rest_api:document-type-change', kwargs={
-                'pk': self.test_document.pk
-            }, data={'new_document_type': self.test_document_type_2.pk}
-        )
-
-
 class DocumentAPIViewTestCase(
     DocumentAPIViewTestMixin, DocumentTestMixin, BaseAPITestCase
 ):
@@ -335,62 +268,6 @@ class DocumentAPIViewTestCase(
         )
 
 
-class DocumentVersionAPIViewTestMixin(object):
-    def _request_test_document_version_api_download_view(self):
-        return self.get(
-            viewname='rest_api:documentversion-download', kwargs={
-                'pk': self.test_document.pk,
-                'version_pk': self.test_document.latest_version.pk,
-            }
-        )
-
-    def _request_test_document_version_api_edit_via_patch_view(self):
-        return self.patch(
-            viewname='rest_api:documentversion-detail', kwargs={
-                'pk': self.test_document.pk,
-                'version_pk': self.test_document.latest_version.pk
-            }, data={'comment': TEST_DOCUMENT_VERSION_COMMENT_EDITED}
-        )
-
-    def _request_test_document_version_api_edit_via_put_view(self):
-        return self.put(
-            viewname='rest_api:documentversion-detail', kwargs={
-                'pk': self.test_document.pk,
-                'version_pk': self.test_document.latest_version.pk
-            }, data={'comment': TEST_DOCUMENT_VERSION_COMMENT_EDITED}
-        )
-
-    def _request_test_document_version_api_list_view(self):
-        return self.get(
-            viewname='rest_api:document-version-list', kwargs={
-                'pk': self.test_document.pk
-            }
-        )
-
-    def _request_test_document_version_api_revert_view(self):
-        return self.delete(
-            viewname='rest_api:documentversion-detail', kwargs={
-                'pk': self.test_document.pk,
-                'version_pk': self.test_document.latest_version.pk
-            }
-        )
-
-    def _request_test_document_version_api_upload_view(self):
-        # Artificial delay since MySQL doesn't store microsecond data in
-        # timestamps. Version timestamp is used to determine which version
-        # is the latest.
-        time.sleep(1)
-
-        with open(TEST_DOCUMENT_PATH, mode='rb') as file_descriptor:
-            return self.post(
-                viewname='rest_api:document-version-list', kwargs={
-                    'pk': self.test_document.pk,
-                }, data={
-                    'comment': '', 'file': file_descriptor,
-                }
-            )
-
-
 class DocumentVersionAPIViewTestCase(
     DocumentVersionAPIViewTestMixin, DocumentTestMixin,
     DocumentVersionTestMixin, BaseAPITestCase
@@ -556,21 +433,10 @@ class DocumentVersionAPIViewTestCase(
         self.assertEqual(self.test_document.page_count, 47)
 
 
-class DocumentPageAPIViewTestMixin(object):
-    def _request_document_page_image(self):
-        page = self.test_document.pages.first()
-        return self.get(
-            viewname='rest_api:documentpage-image', kwargs={
-                'pk': page.document.pk, 'version_pk': page.document_version.pk,
-                'page_pk': page.pk
-            }
-        )
-
-
 class DocumentPageAPIViewTestCase(
     DocumentPageAPIViewTestMixin, DocumentTestMixin, BaseAPITestCase
 ):
-    def test_document_page_api_image_view_no_access(self):
+    def test_document_page_api_image_view_no_permission(self):
         response = self._request_document_page_image()
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
@@ -583,52 +449,6 @@ class DocumentPageAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
 
-class TrashedDocumentAPIViewTestMixin(object):
-    def _request_test_document_api_trash_view(self):
-        return self.delete(
-            viewname='rest_api:document-detail', kwargs={
-                'pk': self.test_document.pk
-            }
-        )
-
-    def _request_test_trashed_document_api_delete_view(self):
-        return self.delete(
-            viewname='rest_api:trasheddocument-detail', kwargs={
-                'pk': self.test_document.pk
-            }
-        )
-
-    def _request_test_trashed_document_api_detail_view(self):
-        return self.get(
-            viewname='rest_api:trasheddocument-detail', kwargs={
-                'pk': self.test_document.pk
-            }
-        )
-
-    def _request_test_trashed_document_api_image_view(self):
-        latest_version = self.test_document.latest_version
-
-        return self.get(
-            viewname='rest_api:documentpage-image', kwargs={
-                'pk': latest_version.document.pk,
-                'version_pk': latest_version.pk,
-                'page_pk': latest_version.pages.first().pk
-            }
-        )
-
-    def _request_test_trashed_document_api_list_view(self):
-        return self.get(
-            viewname='rest_api:trasheddocument-list'
-        )
-
-    def _request_test_trashed_document_api_restore_view(self):
-        return self.post(
-            viewname='rest_api:trasheddocument-restore', kwargs={
-                'pk': self.test_document.pk
-            }
-        )
-
-
 class TrashedDocumentAPIViewTestCase(
     TrashedDocumentAPIViewTestMixin, DocumentTestMixin, BaseAPITestCase
 ):
@@ -649,17 +469,17 @@ class TrashedDocumentAPIViewTestCase(
         response = self._request_test_document_api_trash_view()
         self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
 
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
         self.assertEqual(Document.trash.count(), 1)
 
-    def test_trashed_document_api_delete_view_no_access(self):
+    def test_trashed_document_api_delete_view_no_permission(self):
         self._upload_test_document()
         self.test_document.delete()
 
         response = self._request_test_trashed_document_api_delete_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
         self.assertEqual(Document.trash.count(), 1)
 
     def test_trashed_document_api_delete_view_with_access(self):
@@ -672,10 +492,10 @@ class TrashedDocumentAPIViewTestCase(
         response = self._request_test_trashed_document_api_delete_view()
         self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
 
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
         self.assertEqual(Document.trash.count(), 0)
 
-    def test_trashed_document_api_detail_view_no_access(self):
+    def test_trashed_document_api_detail_view_no_permission(self):
         self._upload_test_document()
         self.test_document.delete()
 
@@ -713,7 +533,7 @@ class TrashedDocumentAPIViewTestCase(
         response = self._request_test_trashed_document_api_image_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-    def test_trashed_document_api_list_view_no_access(self):
+    def test_trashed_document_api_list_view_no_permission(self):
         self._upload_test_document()
         self.test_document.delete()
 
@@ -735,7 +555,7 @@ class TrashedDocumentAPIViewTestCase(
             force_text(self.test_document.uuid)
         )
 
-    def test_trashed_document_api_restore_view_no_access(self):
+    def test_trashed_document_api_restore_view_no_permission(self):
         self._upload_test_document()
         self.test_document.delete()
 
@@ -743,7 +563,7 @@ class TrashedDocumentAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertEqual(Document.trash.count(), 1)
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
 
     def test_trashed_document_api_restore_view_with_access(self):
         self._upload_test_document()
@@ -756,4 +576,4 @@ class TrashedDocumentAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
         self.assertEqual(Document.trash.count(), 0)
-        self.assertEqual(Document.objects.count(), 1)
+        self.assertEqual(Document.valid.count(), 1)
