@@ -1,27 +1,13 @@
 from ..permissions import permission_document_view
 
 from .base import GenericDocumentViewTestCase
-
-
-class DuplicatedDocumentsViewsTestMixin(object):
-    def _request_document_duplicates_list_view(self):
-        return self.get(
-            viewname='documents:document_duplicates_list', kwargs={
-                'document_id': self.test_documents[0].pk
-            }
-        )
-
-    def _request_duplicated_document_list_view(self):
-        return self.get(viewname='documents:duplicated_document_list')
-
-    def _upload_duplicate_document(self):
-        self._upload_test_document()
+from .mixins import DuplicatedDocumentsViewsTestMixin
 
 
 class DuplicatedDocumentsViewsTestCase(
     DuplicatedDocumentsViewsTestMixin, GenericDocumentViewTestCase
 ):
-    def test_document_duplicates_list_no_permissions(self):
+    def test_document_duplicates_list_no_permission(self):
         self._upload_duplicate_document()
 
         response = self._request_document_duplicates_list_view()
@@ -66,7 +52,7 @@ class DuplicatedDocumentsViewsTestCase(
             text=self.test_documents[1].pk
         )
 
-    def test_duplicated_document_list_no_permissions(self):
+    def test_duplicated_document_list_no_permission(self):
         self._upload_duplicate_document()
 
         response = self._request_duplicated_document_list_view()
