@@ -3,8 +3,8 @@ import time
 
 from django.test import override_settings
 
-from mayan.apps.common.tests.base import BaseTestCase
 from mayan.apps.converter.layers import layer_saved_transformations
+from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..models import (
     DeletedDocument, Document, DocumentType, DuplicatedDocument
@@ -43,10 +43,10 @@ class DocumentTestCase(GenericDocumentTestCase):
         self.assertEqual(self.test_document.page_count, 1)
 
     def test_version_creation(self):
-        with open(TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
             self.test_document.new_version(file_object=file_object)
 
-        with open(TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
             self.test_document.new_version(
                 file_object=file_object, comment='test comment 1'
             )
@@ -54,30 +54,30 @@ class DocumentTestCase(GenericDocumentTestCase):
         self.assertEqual(self.test_document.versions.count(), 3)
 
     def test_restoring_documents(self):
-        self.assertEqual(Document.objects.count(), 1)
+        self.assertEqual(Document.valid.count(), 1)
 
         # Trash the document
         self.test_document.delete()
         self.assertEqual(DeletedDocument.objects.count(), 1)
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
 
         # Restore the document
         self.test_document.restore()
         self.assertEqual(DeletedDocument.objects.count(), 0)
-        self.assertEqual(Document.objects.count(), 1)
+        self.assertEqual(Document.valid.count(), 1)
 
     def test_trashing_documents(self):
-        self.assertEqual(Document.objects.count(), 1)
+        self.assertEqual(Document.valid.count(), 1)
 
         # Trash the document
         self.test_document.delete()
         self.assertEqual(DeletedDocument.objects.count(), 1)
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
 
         # Delete the document
         self.test_document.delete()
         self.assertEqual(DeletedDocument.objects.count(), 0)
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
 
     def test_auto_trashing(self):
         """
@@ -93,12 +93,12 @@ class DocumentTestCase(GenericDocumentTestCase):
         # field
         time.sleep(1.01)
 
-        self.assertEqual(Document.objects.count(), 1)
+        self.assertEqual(Document.valid.count(), 1)
         self.assertEqual(DeletedDocument.objects.count(), 0)
 
         DocumentType.objects.check_trash_periods()
 
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
         self.assertEqual(DeletedDocument.objects.count(), 1)
 
     def test_auto_delete(self):
@@ -111,12 +111,12 @@ class DocumentTestCase(GenericDocumentTestCase):
         self.test_document_type.delete_time_unit = 'seconds'
         self.test_document_type.save()
 
-        self.assertEqual(Document.objects.count(), 1)
+        self.assertEqual(Document.valid.count(), 1)
         self.assertEqual(DeletedDocument.objects.count(), 0)
 
         self.test_document.delete()
 
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
         self.assertEqual(DeletedDocument.objects.count(), 1)
 
         # Needed by MySQL as milliseconds value is not stored in timestamp
@@ -125,7 +125,7 @@ class DocumentTestCase(GenericDocumentTestCase):
 
         DocumentType.objects.check_delete_periods()
 
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
         self.assertEqual(DeletedDocument.objects.count(), 0)
 
     def test_method_get_absolute_url(self):
@@ -140,7 +140,7 @@ class PDFAlternateRotationTestCase(GenericDocumentTestCase):
 
     def test_rotate(self):
         self.assertQuerysetEqual(
-            qs=Document.objects.all(), values=(repr(self.test_document),)
+            qs=Document.valid.all(), values=(repr(self.test_document),)
         )
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
@@ -155,7 +155,7 @@ class PDFIndirectRotationTestCase(GenericDocumentTestCase):
 
     def test_rotate(self):
         self.assertQuerysetEqual(
-            qs=Document.objects.all(), values=(repr(self.test_document),)
+            qs=Document.valid.all(), values=(repr(self.test_document),)
         )
 
 
@@ -193,7 +193,7 @@ class DocumentVersionTestCase(GenericDocumentTestCase):
     def test_add_new_version(self):
         self.assertEqual(self.test_document.versions.count(), 1)
 
-        with open(TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
             self.test_document.new_version(
                 file_object=file_object
             )
@@ -212,7 +212,7 @@ class DocumentVersionTestCase(GenericDocumentTestCase):
         # field
         time.sleep(1.01)
 
-        with open(TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
             self.test_document.new_version(
                 file_object=file_object
             )
@@ -245,18 +245,18 @@ class DocumentManagerTestCase(BaseTestCase):
             document_type=self.test_document_type
         )
 
-        Document.passthrough.delete_stubs()
+        Document.objects.delete_stubs()
 
-        self.assertEqual(Document.passthrough.count(), 1)
+        self.assertEqual(Document.objects.count(), 1)
 
         document_stub.date_added = document_stub.date_added - timedelta(
             seconds=setting_stub_expiration_interval.value + 1
         )
         document_stub.save()
 
-        Document.passthrough.delete_stubs()
+        Document.objects.delete_stubs()
 
-        self.assertEqual(Document.passthrough.count(), 0)
+        self.assertEqual(Document.objects.count(), 0)
 
 
 class DocumentTypeModelTestCase(GenericDocumentTestCase):
@@ -265,6 +265,15 @@ class DocumentTypeModelTestCase(GenericDocumentTestCase):
     def test_method_get_absolute_url(self):
         self.assertTrue(self.test_document_type.get_absolute_url())
 
+    def test_original_filename_backend(self):
+        self.test_document_type.filename_generator_backend = 'original'
+        self.test_document_type.save()
+        self._upload_test_document()
+        self.assertEqual(
+            self.test_document_filename,
+            self.test_document.latest_version.file
+        )
+
 
 class DuplicatedDocumentsTestCase(GenericDocumentTestCase):
     def test_duplicates_after_delete(self):
@@ -283,16 +292,16 @@ class DuplicatedDocumentsTestCase(GenericDocumentTestCase):
         self.test_documents[1].delete()
 
         self.assertFalse(
-            self.test_documents[1] in DuplicatedDocument.objects.get(
+            self.test_documents[1] in DuplicatedDocument.objects.get_duplicates_of(
                 document=self.test_documents[0]
-            ).documents.all()
+            )
         )
 
     def test_duplicate_scan(self):
         self._upload_test_document()
 
         self.assertTrue(
-            self.test_documents[1] in DuplicatedDocument.objects.get(
+            self.test_documents[1] in DuplicatedDocument.objects.get_duplicates_of(
                 document=self.test_documents[0]
-            ).documents.all()
+            )
         )
