@@ -1,6 +1,6 @@
-from mayan.apps.common.tests.base import BaseTestCase
 from mayan.apps.smart_settings.classes import Setting
 from mayan.apps.smart_settings.tests.mixins import SmartSettingTestMixin
+from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..settings import (
     setting_documentimagecache_storage_arguments,
