@@ -11,32 +11,32 @@ from .mixins import TrashedDocumentViewTestMixin
 class TrashedDocumentViewTestCase(
     TrashedDocumentViewTestMixin, GenericDocumentViewTestCase
 ):
-    def test_document_trash_get_view_no_permissions(self):
-        document_count = Document.objects.count()
+    def test_document_trash_get_view_no_permission(self):
+        document_count = Document.valid.count()
 
         response = self._request_document_trash_get_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertEqual(Document.objects.count(), document_count)
+        self.assertEqual(Document.valid.count(), document_count)
 
     def test_document_trash_get_view_with_access(self):
         self.grant_access(
             obj=self.test_document, permission=permission_document_trash
         )
 
-        document_count = Document.objects.count()
+        document_count = Document.valid.count()
 
         response = self._request_document_trash_get_view()
         self.assertEqual(response.status_code, 200)
 
-        self.assertEqual(Document.objects.count(), document_count)
+        self.assertEqual(Document.valid.count(), document_count)
 
-    def test_document_trash_post_view_no_permissions(self):
+    def test_document_trash_post_view_no_permission(self):
         response = self._request_document_trash_post_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(DeletedDocument.objects.count(), 0)
-        self.assertEqual(Document.objects.count(), 1)
+        self.assertEqual(Document.valid.count(), 1)
 
     def test_document_trash_post_view_with_access(self):
         self.grant_access(
@@ -47,47 +47,47 @@ class TrashedDocumentViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(DeletedDocument.objects.count(), 1)
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
 
     def test_trashed_document_restore_get_view_no_permission(self):
         self.test_document.delete()
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
 
-        document_count = Document.objects.count()
+        document_count = Document.valid.count()
 
         response = self._request_trashed_document_restore_get_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertEqual(Document.objects.count(), document_count)
+        self.assertEqual(Document.valid.count(), document_count)
 
     def test_trashed_document_restore_get_view_with_access(self):
         self.test_document.delete()
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
 
         self.grant_access(
             obj=self.test_document, permission=permission_document_restore
         )
 
-        document_count = Document.objects.count()
+        document_count = Document.valid.count()
 
         response = self._request_trashed_document_restore_get_view()
         self.assertEqual(response.status_code, 200)
 
-        self.assertEqual(Document.objects.count(), document_count)
+        self.assertEqual(Document.valid.count(), document_count)
 
     def test_trashed_document_restore_post_view_no_permission(self):
         self.test_document.delete()
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
 
         response = self._request_trashed_document_restore_post_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(DeletedDocument.objects.count(), 1)
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
 
     def test_trashed_document_restore_post_view_with_access(self):
         self.test_document.delete()
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
 
         self.grant_access(
             obj=self.test_document, permission=permission_document_restore
@@ -97,11 +97,11 @@ class TrashedDocumentViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(DeletedDocument.objects.count(), 0)
-        self.assertEqual(Document.objects.count(), 1)
+        self.assertEqual(Document.valid.count(), 1)
 
-    def test_trashed_document_delete_get_view_no_permissions(self):
+    def test_trashed_document_delete_get_view_no_permission(self):
         self.test_document.delete()
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
         self.assertEqual(DeletedDocument.objects.count(), 1)
 
         trashed_document_count = DeletedDocument.objects.count()
@@ -115,7 +115,7 @@ class TrashedDocumentViewTestCase(
 
     def test_trashed_document_delete_get_view_with_access(self):
         self.test_document.delete()
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
         self.assertEqual(DeletedDocument.objects.count(), 1)
 
         self.grant_access(
@@ -131,20 +131,20 @@ class TrashedDocumentViewTestCase(
             DeletedDocument.objects.count(), trashed_document_count
         )
 
-    def test_trashed_document_delete_post_view_no_permissions(self):
+    def test_trashed_document_delete_post_view_no_permission(self):
         self.test_document.delete()
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
         self.assertEqual(DeletedDocument.objects.count(), 1)
 
         response = self._request_trashed_document_delete_post_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
         self.assertEqual(DeletedDocument.objects.count(), 1)
 
     def test_trashed_document_delete_post_view_with_access(self):
         self.test_document.delete()
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
         self.assertEqual(DeletedDocument.objects.count(), 1)
 
         self.grant_access(
@@ -155,9 +155,9 @@ class TrashedDocumentViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(DeletedDocument.objects.count(), 0)
-        self.assertEqual(Document.objects.count(), 0)
+        self.assertEqual(Document.valid.count(), 0)
 
-    def test_trashed_document_list_view_no_permissions(self):
+    def test_trashed_document_list_view_no_permission(self):
         self.test_document.delete()
 
         response = self._request_trashed_document_list_view()
