@@ -8,13 +8,14 @@ from django.utils.encoding import force_text
 from django.utils.translation import ugettext_lazy as _, ungettext
 from django.views.generic import RedirectView
 
-from mayan.apps.common.generics import (
+from mayan.apps.common.classes import ModelQueryFields
+from mayan.apps.common.settings import setting_home_view
+from mayan.apps.converter.literals import DEFAULT_ROTATION, DEFAULT_ZOOM_LEVEL
+from mayan.apps.views.generics import (
     MultipleObjectConfirmActionView, SimpleView, SingleObjectListView
 )
-from mayan.apps.common.mixins import ExternalObjectMixin
-from mayan.apps.common.settings import setting_home_view
-from mayan.apps.common.utils import resolve
-from mayan.apps.converter.literals import DEFAULT_ROTATION, DEFAULT_ZOOM_LEVEL
+from mayan.apps.views.mixins import ExternalObjectMixin
+from mayan.apps.views.utils import resolve
 
 from ..forms import DocumentPageForm
 from ..icons import icon_document_pages
@@ -63,13 +64,14 @@ class DocumentPageListView(ExternalObjectMixin, SingleObjectListView):
         }
 
     def get_source_queryset(self):
-        return self.external_object.pages_all
+        queryset = ModelQueryFields.get(model=DocumentPage).get_queryset()
+        return queryset.filter(pk__in=self.external_object.pages.all())
 
 
 class DocumentPageNavigationBase(ExternalObjectMixin, RedirectView):
-    external_object_class = DocumentPage
     external_object_permission = permission_document_view
     external_object_pk_url_kwarg = 'document_page_id'
+    external_object_queryset = DocumentPage.valid
 
     def get_redirect_url(self, *args, **kwargs):
         """
@@ -151,9 +153,9 @@ class DocumentPageNavigationPrevious(DocumentPageNavigationBase):
 
 
 class DocumentPageView(ExternalObjectMixin, SimpleView):
-    external_object_class = DocumentPage
     external_object_permission = permission_document_view
     external_object_pk_url_kwarg = 'document_page_id'
+    external_object_queryset = DocumentPage.valid
     template_name = 'appearance/generic_form.html'
 
     def get_extra_context(self):
@@ -174,8 +176,7 @@ class DocumentPageView(ExternalObjectMixin, SimpleView):
         return {
             'form': document_page_form,
             'hide_labels': True,
-            'navigation_object_list': ('page',),
-            'page': self.external_object,
+            'object': self.external_object,
             'rotation': rotation,
             'title': ' '.join((base_title, zoom_text)),
             'read_only': True,
@@ -274,7 +275,7 @@ class DocumentPageDisable(MultipleObjectConfirmActionView):
         return result
 
     def get_source_queryset(self):
-        return DocumentPage.passthrough.all()
+        return DocumentPage.objects.all()
 
     def object_action(self, form, instance):
         instance.enabled = False
@@ -304,7 +305,7 @@ class DocumentPageEnable(MultipleObjectConfirmActionView):
         return result
 
     def get_source_queryset(self):
-        return DocumentPage.passthrough.all()
+        return DocumentPage.objects.all()
 
     def object_action(self, form, instance):
         instance.enabled = True
