@@ -12,16 +12,17 @@ from django.utils.encoding import force_text
 from django.utils.translation import ugettext_lazy as _, ungettext
 
 from mayan.apps.acls.models import AccessControlList
-from mayan.apps.common.compressed_files import ZipArchive
-from mayan.apps.common.generics import (
-    FormView, MultipleObjectConfirmActionView, MultipleObjectDownloadView,
-    MultipleObjectFormActionView, SingleObjectDetailView,
-    SingleObjectEditView, SingleObjectListView
-)
+from mayan.apps.common.classes import ModelQueryFields
 from mayan.apps.converter.layers import layer_saved_transformations
 from mayan.apps.converter.permissions import (
     permission_transformation_delete, permission_transformation_edit
 )
+from mayan.apps.storage.compressed_files import ZipArchive
+from mayan.apps.views.generics import (
+    FormView, MultipleObjectConfirmActionView, MultipleObjectDownloadView,
+    MultipleObjectFormActionView, SingleObjectDetailView,
+    SingleObjectEditView, SingleObjectListView
+)
 
 from ..events import event_document_download, event_document_view
 from ..forms import (
@@ -75,10 +76,7 @@ class DocumentListView(SingleObjectListView):
             return super(DocumentListView, self).get_context_data(**kwargs)
 
     def get_document_queryset(self):
-        return Document.objects.defer(
-            'description', 'uuid', 'date_added', 'language', 'in_trash',
-            'deleted_date_time'
-        ).all()
+        return Document.objects.all()
 
     def get_extra_context(self):
         return {
@@ -96,7 +94,8 @@ class DocumentListView(SingleObjectListView):
         }
 
     def get_source_queryset(self):
-        return self.get_document_queryset()
+        queryset = ModelQueryFields.get(model=Document).get_queryset()
+        return self.get_document_queryset().filter(pk__in=queryset)
 
 
 class DocumentDocumentTypeEditView(MultipleObjectFormActionView):
@@ -550,7 +549,7 @@ class DocumentPrint(FormView):
 
             if self.page_group == PAGE_RANGE_RANGE:
                 if self.page_range:
-                    page_range = parse_range(self.page_range)
+                    page_range = parse_range(astr=self.page_range)
                     pages = instance.pages.filter(page_number__in=page_range)
                 else:
                     pages = instance.pages.all()
@@ -624,8 +623,10 @@ class RecentAccessDocumentListView(DocumentListView):
 
 class RecentAddedDocumentListView(DocumentListView):
     def get_document_queryset(self):
-        return Document.objects.filter(
-            pk__in=Document.objects.order_by('-date_added')[
+        queryset = ModelQueryFields.get(model=Document).get_queryset()
+
+        return queryset.filter(
+            pk__in=queryset.order_by('-date_added')[
                 :setting_recent_added_count.value
             ].values('pk')
         ).order_by('-date_added')
