@@ -5,10 +5,10 @@ from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _, ungettext
 
 from mayan.apps.acls.models import AccessControlList
-from mayan.apps.common.generics import (
+from mayan.apps.common.settings import setting_home_view
+from mayan.apps.views.generics import (
     ConfirmView, MultipleObjectConfirmActionView
 )
-from mayan.apps.common.settings import setting_home_view
 
 from ..icons import icon_document_list_deleted
 from ..models import DeletedDocument, Document
@@ -17,7 +17,7 @@ from ..permissions import (
     permission_document_trash, permission_document_view,
     permission_empty_trash
 )
-from ..tasks import task_delete_document
+from ..tasks import task_delete_document, task_trash_can_empty
 
 from .document_views import DocumentListView
 
@@ -58,22 +58,20 @@ class DocumentTrashView(MultipleObjectConfirmActionView):
 
 
 class EmptyTrashCanView(ConfirmView):
+    action_cancel_redirect = post_action_redirect = reverse_lazy(
+        'documents:document_list_deleted'
+    )
     extra_context = {
         'title': _('Empty trash?')
     }
     view_permission = permission_empty_trash
-    action_cancel_redirect = post_action_redirect = reverse_lazy(
-        'documents:document_list_deleted'
-    )
 
     def view_action(self):
-        for deleted_document in DeletedDocument.objects.all():
-            task_delete_document.apply_async(
-                kwargs={'trashed_document_id': deleted_document.pk}
-            )
+        task_trash_can_empty.apply_async()
 
         messages.success(
-            message=_('Trash emptied successfully'), request=self.request
+            message=_('The trash emptying task has been queued.'),
+            request=self.request
         )
 
 
