@@ -1,9 +1,13 @@
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.common.apps import MayanAppConfig
-from mayan.apps.common.menus import menu_facet, menu_secondary
+from mayan.apps.common.menus import menu_facet, menu_secondary, menu_tools
 
-from .links import link_search, link_search_advanced, link_search_again
+from .classes import SearchModel
+from .links import (
+    link_search, link_search_advanced, link_search_again,
+    link_search_backend_reindex
+)
 
 
 class DynamicSearchApp(MayanAppConfig):
@@ -17,6 +21,9 @@ class DynamicSearchApp(MayanAppConfig):
     def ready(self):
         super(DynamicSearchApp, self).ready()
 
+        SearchModel.load_modules()
+        SearchModel.initialize()
+
         menu_facet.bind_links(
             links=(link_search, link_search_advanced),
             sources=(
@@ -26,3 +33,6 @@ class DynamicSearchApp(MayanAppConfig):
         menu_secondary.bind_links(
             links=(link_search_again,), sources=('search:results',)
         )
+        menu_tools.bind_links(
+            links=(link_search_backend_reindex,),
+        )
