@@ -1,39 +1,42 @@
 import logging
 
-from django.apps import apps
 from django.db.models import Q
-from django.utils.encoding import force_text, python_2_unicode_compatible
+from django.utils.encoding import force_text
 
 from ..classes import SearchBackend
 
-from .literals import (
-    QUERY_OPERATION_AND, QUERY_OPERATION_OR, TERM_NEGATION_CHARACTER,
-    TERM_OPERATION_OR, TERM_OPERATIONS, TERM_QUOTES, TERM_SPACE_CHARACTER
-)
-
+QUERY_OPERATION_AND = 1
+QUERY_OPERATION_OR = 2
+TERM_OPERATION_AND = 'AND'
+TERM_OPERATION_OR = 'OR'
+TERM_OPERATIONS = [TERM_OPERATION_AND, TERM_OPERATION_OR]
+TERM_QUOTES = ['"', '\'']
+TERM_NEGATION_CHARACTER = '-'
+TERM_SPACE_CHARACTER = ' '
 logger = logging.getLogger(name=__name__)
 
 
 class DjangoSearchBackend(SearchBackend):
-    def search(self, query_string, search_model, user, global_and_search=False):
-        AccessControlList = apps.get_model(
-            app_label='acls', model_name='AccessControlList'
-        )
-
+    def _search(self, query_string, search_model, user, global_and_search=False):
         search_query = self.get_search_query(
             search_model=search_model, query_string=query_string,
             global_and_search=global_and_search
         )
 
-        queryset = search_model.get_queryset().filter(search_query.query).distinct()
+        queryset = search_model.get_queryset().filter(
+            search_query.query
+        ).distinct()
 
-        if search_model.permission:
-            queryset = AccessControlList.objects.restrict_queryset(
-                permission=search_model.permission, queryset=queryset,
-                user=user
-            )
+        return SearchBackend.limit_queryset(queryset=queryset)
 
-        return queryset
+    def deindex_instance(self, instance):
+        """This backend doesn't remove instances."""
+
+    def index_instance(self, instance):
+        """
+        This backend doesn't index instances. Searches query the
+        database directly.
+        """
 
     def get_search_query(self, search_model, query_string, global_and_search=False):
         return SearchQuery(
@@ -42,8 +45,7 @@ class DjangoSearchBackend(SearchBackend):
         )
 
 
-@python_2_unicode_compatible
-class FieldQuery(object):
+class FieldQuery:
     def __init__(self, search_field, search_term_collection):
         query_operation = QUERY_OPERATION_AND
         self.query = None
@@ -87,8 +89,7 @@ class FieldQuery(object):
         return ' '.join(self.parts)
 
 
-@python_2_unicode_compatible
-class SearchQuery(object):
+class SearchQuery:
     def __init__(self, query_string, search_model, global_and_search=False):
         self.query = None
         self.text = []
@@ -127,8 +128,7 @@ class SearchQuery(object):
         return ' '.join(self.text[:-1])
 
 
-@python_2_unicode_compatible
-class SearchTerm(object):
+class SearchTerm:
     def __init__(self, negated, string, is_meta):
         self.negated = negated
         self.string = string
@@ -143,8 +143,7 @@ class SearchTerm(object):
             )
 
 
-@python_2_unicode_compatible
-class SearchTermCollection(object):
+class SearchTermCollection:
     def __init__(self, text):
         """
         Takes a text string and returns a list of dictionaries.
