@@ -1,17 +1,19 @@
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.smart_settings.classes import Namespace
+from mayan.apps.smart_settings.classes import SettingNamespace
 
-namespace = Namespace(label=_('Search'), name='search')
+from .literals import DEFAULT_RESULTS_LIMIT
 
-setting_search_backend = namespace.add_setting(
+namespace = SettingNamespace(label=_('Search'), name='search')
+
+setting_backend = namespace.add_setting(
     global_name='SEARCH_BACKEND',
     default='mayan.apps.dynamic_search.backends.django.DjangoSearchBackend',
     help_text=_(
         'Full path to the backend to be used to handle the search.'
     )
 )
-setting_search_backend_arguments = namespace.add_setting(
+setting_backend_arguments = namespace.add_setting(
     global_name='SEARCH_BACKEND_ARGUMENTS',
     default={}
 )
@@ -22,3 +24,7 @@ setting_disable_simple_search = namespace.add_setting(
         'search button.'
     )
 )
+setting_results_limit = namespace.add_setting(
+    global_name='SEARCH_RESULTS_LIMIT', default=DEFAULT_RESULTS_LIMIT,
+    help_text=_('Maximum number search results to fetch and display.')
+)
