@@ -1,11 +1,17 @@
-from mayan.apps.common.tests.base import GenericViewTestCase
+from django.test import override_settings
+
+from mayan.apps.documents.models.document_models import Document
 from mayan.apps.documents.permissions import permission_document_view
 from mayan.apps.documents.search import document_search
 from mayan.apps.documents.tests.mixins import DocumentTestMixin
+from mayan.apps.testing.tests.base import GenericViewTestCase
+from mayan.apps.storage.utils import fs_cleanup, mkdtemp
 
-from ..backends.django import DjangoSearchBackend
+from ..classes import SearchBackend, SearchModel
+from ..permissions import permission_search_tools
+from ..settings import setting_backend_arguments
 
-from .mixins import SearchViewTestMixin
+from .mixins import SearchToolsViewTestMixin, SearchViewTestMixin
 
 
 class AdvancedSearchViewTestCase(
@@ -21,7 +27,7 @@ class AdvancedSearchViewTestCase(
         for i in range(self.test_document_count):
             self._upload_test_document()
 
-        self.search_backend = DjangoSearchBackend()
+        self.search_backend = SearchBackend.get_instance()
 
     def test_advanced_search_past_first_page(self):
         test_document_label = self.test_documents[0].label
@@ -39,7 +45,7 @@ class AdvancedSearchViewTestCase(
         )
         self.assertEqual(queryset.count(), self.test_document_count)
 
-        with self.settings(COMMON_PAGINATE_BY=2):
+        with self.settings(VIEWS_PAGINATE_BY=2):
             # Functional test for the first page of advanced results
             response = self._request_search_results_view(
                 data={'label': test_document_label}, kwargs={
@@ -97,3 +103,63 @@ class SearchViewTestCase(
         self.assertContains(
             response=response, status_code=200, text=self.test_document.label
         )
+
+
+@override_settings(SEARCH_BACKEND='mayan.apps.dynamic_search.backends.whoosh.WhooshSearchBackend')
+class SearchToolsViewTestCase(
+    DocumentTestMixin, SearchToolsViewTestMixin, GenericViewTestCase
+):
+    def setUp(self):
+        self.old_value = setting_backend_arguments.value
+        super().setUp()
+        self.document_search_model = SearchModel.get_for_model(
+            instance=Document
+        )
+        setting_backend_arguments.set(
+            value={'index_path': mkdtemp()}
+        )
+        self.search_backend = SearchBackend.get_instance()
+
+    def tearDown(self):
+        fs_cleanup(
+            filename=setting_backend_arguments.value['index_path']
+        )
+        setting_backend_arguments.set(value=self.old_value)
+        super().tearDown()
+
+    def test_search_backend_reindex_view_no_permission(self):
+        self.search_backend.clear_search_model_index(
+            search_model=self.document_search_model
+        )
+        self.grant_access(
+            obj=self.test_document, permission=permission_document_view
+        )
+
+        response = self._request_search_backend_reindex_view()
+        self.assertEqual(response.status_code, 403)
+
+        queryset = self.search_backend.search(
+            search_model=self.document_search_model,
+            query_string={'q': self.test_document.label},
+            user=self._test_case_user
+        )
+        self.assertEqual(queryset.count(), 0)
+
+    def test_search_backend_reindex_view_with_permission(self):
+        self.search_backend.clear_search_model_index(
+            search_model=self.document_search_model
+        )
+        self.grant_access(
+            obj=self.test_document, permission=permission_document_view
+        )
+        self.grant_permission(permission=permission_search_tools)
+
+        response = self._request_search_backend_reindex_view()
+        self.assertEqual(response.status_code, 302)
+
+        queryset = self.search_backend.search(
+            search_model=self.document_search_model,
+            query_string={'q': self.test_document.label},
+            user=self._test_case_user
+        )
+        self.assertNotEqual(queryset.count(), 0)
