@@ -1,16 +1,23 @@
 import logging
 
+from django.contrib import messages
+from django.template import RequestContext
 from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 from django.views.generic.base import RedirectView
 
-from mayan.apps.common.generics import SimpleView, SingleObjectListView
-from mayan.apps.common.literals import LIST_MODE_CHOICE_ITEM
+from mayan.apps.views.generics import (
+    ConfirmView, SimpleView, SingleObjectListView
+)
+from mayan.apps.views.literals import LIST_MODE_CHOICE_ITEM
 
+from .classes import SearchBackend, SearchModel
 from .forms import SearchForm, AdvancedSearchForm
 from .icons import icon_search_submit
+from .links import link_search_again
 from .mixins import SearchModelMixin
-from .runtime import search_backend
+from .permissions import permission_search_tools
+from .tasks import task_index_search_model
 
 logger = logging.getLogger(name=__name__)
 
@@ -20,6 +27,13 @@ class ResultsView(SearchModelMixin, SingleObjectListView):
         context = {
             'hide_object': True,
             'no_results_icon': icon_search_submit,
+            'no_results_main_link': link_search_again.resolve(
+                context=RequestContext(
+                    request=self.request, dict_={
+                        'search_model': self.search_model
+                    }
+                )
+            ),
             'no_results_text': _(
                 'Try again using different terms. '
             ),
@@ -45,7 +59,7 @@ class ResultsView(SearchModelMixin, SingleObjectListView):
             else:
                 global_and_search = False
 
-            queryset = search_backend.search(
+            queryset = SearchBackend.get_instance().search(
                 global_and_search=global_and_search,
                 search_model=self.search_model,
                 query_string=self.request.GET, user=self.request.user
@@ -54,6 +68,50 @@ class ResultsView(SearchModelMixin, SingleObjectListView):
             return queryset
 
 
+class SearchAgainView(RedirectView):
+    query_string = True
+
+    def get_redirect_url(self, *args, **kwargs):
+        if ('q' in self.request.GET) and self.request.GET['q'].strip():
+            self.pattern_name = 'search:search'
+        else:
+            self.pattern_name = 'search:search_advanced'
+
+        return super().get_redirect_url(*args, **kwargs)
+
+
+class SearchBackendReindexView(ConfirmView):
+    extra_context = {
+        'message': _(
+            'This tool is required only for some search backends. '
+            'Search results will be affected while the backend is '
+            'being reindexed.'
+        ),
+        'title': _('Reindex search backend'),
+        'subtitle': _(
+            'This tool erases and populates the search backend\'s '
+            'internal index.'
+        ),
+    }
+    view_permission = permission_search_tools
+
+    def get_post_action_redirect(self):
+        return reverse(viewname='common:tools_list')
+
+    def view_action(self):
+        for search_model in SearchModel.all():
+            task_index_search_model.apply_async(
+                kwargs={
+                    'search_model_full_name': search_model.get_full_name(),
+                }
+            )
+
+        messages.success(
+            message=_('Search backend reindexing queued.'),
+            request=self.request
+        )
+
+
 class SearchView(SearchModelMixin, SimpleView):
     template_name = 'appearance/generic_form.html'
     title = _('Search')
@@ -89,8 +147,3 @@ class AdvancedSearchView(SearchView):
         return AdvancedSearchForm(
             data=self.request.GET, search_model=self.get_search_model()
         )
-
-
-class SearchAgainView(RedirectView):
-    pattern_name = 'search:search_advanced'
-    query_string = True
