@@ -2,6 +2,7 @@ from django.apps import apps
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.navigation.classes import Link
+from mayan.apps.navigation.utils import get_content_type_kwargs_factory
 
 from .icons import (
     icon_events_list, icon_events_for_object,
@@ -12,24 +13,6 @@ from .icons import (
 from .permissions import permission_events_view
 
 
-def get_kwargs_factory(variable_name):
-    def get_kwargs(context):
-        ContentType = apps.get_model(
-            app_label='contenttypes', model_name='ContentType'
-        )
-
-        content_type = ContentType.objects.get_for_model(
-            model=context[variable_name]
-        )
-        return {
-            'app_label': '"{}"'.format(content_type.app_label),
-            'model': '"{}"'.format(content_type.model),
-            'object_id': '{}.pk'.format(variable_name)
-        }
-
-    return get_kwargs
-
-
 def get_unread_notification_count(context):
     Notification = apps.get_model(
         app_label='events', model_name='Notification'
@@ -48,7 +31,7 @@ link_events_details = Link(
 )
 link_events_for_object = Link(
     icon_class=icon_events_for_object,
-    kwargs=get_kwargs_factory('resolved_object'),
+    kwargs=get_content_type_kwargs_factory(variable_name='resolved_object'),
     permissions=(permission_events_view,), text=_('Events'),
     view='events:events_for_object',
 )
@@ -70,7 +53,7 @@ link_notification_mark_read_all = Link(
 )
 link_object_event_types_user_subcriptions_list = Link(
     icon_class=icon_object_event_types_user_subcriptions_list,
-    kwargs=get_kwargs_factory('resolved_object'),
+    kwargs=get_content_type_kwargs_factory(variable_name='resolved_object'),
     permissions=(permission_events_view,), text=_('Subscriptions'),
     view='events:object_event_types_user_subcriptions_list',
 )
