@@ -9,7 +9,7 @@ from django.utils.translation import ugettext_lazy as _
 from actstream.models import Action, any_stream
 
 from mayan.apps.acls.models import AccessControlList
-from mayan.apps.common.generics import (
+from mayan.apps.views.generics import (
     FormView, SimpleView, SingleObjectListView
 )
 
@@ -174,7 +174,7 @@ class ObjectEventListView(EventListView):
     def get_object(self):
         content_type = get_object_or_404(
             klass=ContentType, app_label=self.kwargs['app_label'],
-            model=self.kwargs['model']
+            model=self.kwargs['model_name']
         )
 
         queryset = AccessControlList.objects.restrict_queryset(
@@ -187,7 +187,7 @@ class ObjectEventListView(EventListView):
         )
 
     def get_source_queryset(self):
-        return any_stream(self.object)
+        return any_stream(obj=self.object)
 
 
 class ObjectEventTypeSubscriptionListView(FormView):
@@ -223,7 +223,7 @@ class ObjectEventTypeSubscriptionListView(FormView):
     def get_object(self):
         object_content_type = get_object_or_404(
             klass=ContentType, app_label=self.kwargs['app_label'],
-            model=self.kwargs['model']
+            model=self.kwargs['model_name']
         )
 
         try:
