@@ -6,13 +6,13 @@ from django.core.files.base import ContentFile
 from django.db import models, transaction
 from django.db.models import Sum
 from django.template.defaultfilters import filesizeformat
-from django.utils.encoding import force_text, python_2_unicode_compatible
+from django.utils.encoding import force_text
 from django.utils.functional import cached_property
 from django.utils.text import format_lazy
 from django.utils.translation import ugettext_lazy as _
 
+from mayan.apps.lock_manager.backends.base import LockingBackend
 from mayan.apps.lock_manager.exceptions import LockError
-from mayan.apps.lock_manager.runtime import locking_backend
 from mayan.apps.storage.classes import DefinedStorage
 
 from .events import (
@@ -22,7 +22,6 @@ from .events import (
 logger = logging.getLogger(name=__name__)
 
 
-@python_2_unicode_compatible
 class Cache(models.Model):
     defined_storage_name = models.CharField(
         db_index=True, help_text=_(
@@ -54,7 +53,12 @@ class Cache(models.Model):
     get_maximum_size_display.short_description = _('Maximum size')
 
     def get_defined_storage(self):
-        return DefinedStorage.get(name=self.defined_storage_name)
+        try:
+            return DefinedStorage.get(name=self.defined_storage_name)
+        except KeyError:
+            return DefinedStorage(
+                dotted_path='', label=_('Unknown'), name='unknown'
+            )
 
     def get_total_size(self):
         """
@@ -90,10 +94,19 @@ class Cache(models.Model):
         """
         Deletes the entire cache.
         """
-        for partition in self.partitions.all():
-            partition.purge()
+        try:
+            DefinedStorage.get(name=self.defined_storage_name)
+        except KeyError:
+            """
+            Unknown or deleted storage. Must not be purged otherwise only
+            the database data will be erased but the actual storage files
+            will remain.
+            """
+        else:
+            for partition in self.partitions.all():
+                partition.purge()
 
-        event_cache_purged.commit(actor=_user, target=self)
+            event_cache_purged.commit(actor=_user, target=self)
 
     def save(self, *args, **kwargs):
         _user = kwargs.pop('_user', None)
@@ -140,7 +153,7 @@ class CachePartition(models.Model):
         lock_id = 'cache_partition-create_file-{}-{}'.format(self.pk, filename)
         try:
             logger.debug('trying to acquire lock: %s', lock_id)
-            lock = locking_backend.acquire_lock(lock_id)
+            lock = LockingBackend.get_instance().acquire_lock(lock_id)
             logger.debug('acquired lock: %s', lock_id)
             try:
                 self.cache.prune()
@@ -159,7 +172,7 @@ class CachePartition(models.Model):
                     with transaction.atomic():
                         partition_file = self.files.create(filename=filename)
                         yield partition_file.open(mode='wb')
-                        partition_file.update_size()
+
                 except Exception as exception:
                     logger.error(
                         'Unexpected exception while trying to save new '
@@ -169,6 +182,9 @@ class CachePartition(models.Model):
                         name=self.get_full_filename(filename=filename)
                     )
                     raise
+                finally:
+                    partition_file.close()
+                    partition_file.update_size()
             finally:
                 lock.release()
         except LockError:
@@ -208,6 +224,8 @@ class CachePartitionFile(models.Model):
         default=0, verbose_name=_('File size')
     )
 
+    _storage_object = None
+
     class Meta:
         get_latest_by = 'datetime'
         unique_together = ('partition', 'filename')
@@ -231,15 +249,21 @@ class CachePartitionFile(models.Model):
         # Open the file for reading. If the file is written to, the
         # .update_size() must be called.
         try:
-            return self.partition.cache.storage.open(
+            self._storage_object = self.partition.cache.storage.open(
                 name=self.full_filename, mode=mode
             )
+            return self._storage_object
         except Exception as exception:
             logger.error(
                 'Unexpected exception opening the cache file; %s', exception
             )
             raise
 
+    def close(self):
+        if self._storage_object is not None:
+            self._storage_object.close()
+        self._storage_object = None
+
     def update_size(self):
         self.file_size = self.partition.cache.storage.size(
             name=self.full_filename
