@@ -2,8 +2,8 @@ import logging
 
 from django.apps import apps
 
+from mayan.apps.lock_manager.backends.base import LockingBackend
 from mayan.apps.lock_manager.exceptions import LockError
-from mayan.apps.lock_manager.runtime import locking_backend
 from mayan.celery import app
 
 from .literals import LOCK_EXPIRE
@@ -26,12 +26,14 @@ def task_process_document_version(document_version_id):
         logger.debug('trying to acquire lock: %s', lock_id)
         # Acquire lock to avoid processing the same document version more
         # than once concurrently
-        lock = locking_backend.acquire_lock(name=lock_id, timeout=LOCK_EXPIRE)
+        lock = LockingBackend.get_instance().acquire_lock(name=lock_id, timeout=LOCK_EXPIRE)
         logger.debug('acquired lock: %s', lock_id)
     except LockError:
         logger.debug('unable to obtain lock: %s' % lock_id)
     else:
-        FileMetadataDriver.process_document_version(
-            document_version=document_version
-        )
-        lock.release()
+        try:
+            FileMetadataDriver.process_document_version(
+                document_version=document_version
+            )
+        finally:
+            lock.release()
