@@ -8,35 +8,43 @@ from ..permissions import (
 )
 
 from .literals import TEST_FILE_METADATA_KEY
+from .mixins import DocumentTypeViewsTestMixin, FileMetadataViewsTestMixin
 
 
-class FileMetadataViewsTestMixin(object):
-    def _request_document_version_driver_list_view(self):
-        return self.get(
-            viewname='file_metadata:document_driver_list',
-            kwargs={'document_id': self.test_document.pk}
+class DocumentTypeViewsTestCase(
+    DocumentTypeViewsTestMixin, GenericDocumentViewTestCase
+):
+    def test_document_type_settings_view_no_permission(self):
+        response = self._request_document_type_settings_view()
+        self.assertEqual(response.status_code, 404)
+
+    def test_document_type_settings_view_with_access(self):
+        self.grant_access(
+            obj=self.test_document_type,
+            permission=permission_document_type_file_metadata_setup
         )
 
-    def _request_document_version_file_metadata_list_view(self):
-        return self.get(
-            viewname='file_metadata:document_version_driver_file_metadata_list',
-            kwargs={
-                'document_version_driver_id': self.test_driver.pk
-            }
+        response = self._request_document_type_settings_view()
+        self.assertEqual(response.status_code, 200)
+
+    def test_document_type_submit_view_no_permission(self):
+        response = self._request_document_type_submit_view()
+        self.assertEqual(response.status_code, 200)
+
+        self.assertEqual(
+            self.test_document.latest_version.file_metadata_drivers.count(), 0
         )
 
-    def _request_document_submit_view(self):
-        return self.post(
-            viewname='file_metadata:document_submit',
-            kwargs={'document_id': self.test_document.pk}
+    def test_document_type_submit_view_with_access(self):
+        self.grant_access(
+            obj=self.test_document_type, permission=permission_file_metadata_submit
         )
 
-    def _request_multiple_document_submit_view(self):
-        return self.post(
-            viewname='file_metadata:document_multiple_submit',
-            data={
-                'id_list': self.test_document.pk,
-            }
+        response = self._request_document_type_submit_view()
+        self.assertEqual(response.status_code, 302)
+
+        self.assertEqual(
+            self.test_document.latest_version.file_metadata_drivers.count(), 1
         )
 
 
@@ -123,55 +131,3 @@ class FileMetadataViewsTestCase(
         self.assertEqual(
             self.test_document.latest_version.file_metadata_drivers.count(), 1
         )
-
-
-class DocumentTypeViewsTestMixin(object):
-    def _request_document_type_settings_view(self):
-        return self.get(
-            viewname='file_metadata:document_type_settings',
-            kwargs={'document_type_id': self.test_document.document_type.pk}
-        )
-
-    def _request_document_type_submit_view(self):
-        return self.post(
-            viewname='file_metadata:document_type_submit', data={
-                'document_type': self.test_document_type.pk,
-            }
-        )
-
-
-class DocumentTypeViewsTestCase(
-    DocumentTypeViewsTestMixin, GenericDocumentViewTestCase
-):
-    def test_document_type_settings_view_no_permission(self):
-        response = self._request_document_type_settings_view()
-        self.assertEqual(response.status_code, 404)
-
-    def test_document_type_settings_view_with_access(self):
-        self.grant_access(
-            obj=self.test_document_type,
-            permission=permission_document_type_file_metadata_setup
-        )
-
-        response = self._request_document_type_settings_view()
-        self.assertEqual(response.status_code, 200)
-
-    def test_document_type_submit_view_no_permission(self):
-        response = self._request_document_type_submit_view()
-        self.assertEqual(response.status_code, 200)
-
-        self.assertEqual(
-            self.test_document.latest_version.file_metadata_drivers.count(), 0
-        )
-
-    def test_document_type_submit_view_with_access(self):
-        self.grant_access(
-            obj=self.test_document_type, permission=permission_file_metadata_submit
-        )
-
-        response = self._request_document_type_submit_view()
-        self.assertEqual(response.status_code, 302)
-
-        self.assertEqual(
-            self.test_document.latest_version.file_metadata_drivers.count(), 1
-        )
