@@ -1,10 +1,10 @@
 from django.core import management
 
-from ...runtime import locking_backend
+from ...backends.base import LockingBackend
 
 
 class Command(management.BaseCommand):
     help = 'Erase all locks (acquired and stale).'
 
     def handle(self, *args, **options):
-        locking_backend.purge_locks()
+        LockingBackend.get_instance().purge_locks()
