@@ -4,8 +4,10 @@ from django import forms
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.acls.models import AccessControlList
-from mayan.apps.common.forms import DynamicModelForm
-from mayan.apps.common.settings import setting_project_title, setting_project_url
+from mayan.apps.common.settings import (
+    setting_project_title, setting_project_url
+)
+from mayan.apps.views.forms import DynamicModelForm
 
 from .classes import MailerBackend
 from .models import UserMailer
@@ -78,11 +80,7 @@ class UserMailerBackendSelectionForm(forms.Form):
 
     def __init__(self, *args, **kwargs):
         super(UserMailerBackendSelectionForm, self).__init__(*args, **kwargs)
-        self.fields['backend'].choices = [
-            (
-                key, backend.label
-            ) for key, backend in MailerBackend.get_all().items()
-        ]
+        self.fields['backend'].choices = MailerBackend.get_choices()
 
 
 class UserMailerDynamicForm(DynamicModelForm):
