@@ -2,8 +2,8 @@ from django.core import mail
 
 from actstream.models import Action
 
-from mayan.apps.common.tests.base import GenericViewTestCase
 from mayan.apps.documents.tests.base import DocumentTestMixin
+from mayan.apps.testing.tests.base import GenericViewTestCase
 
 from ..permissions import (
     permission_mailing_send_document, permission_user_mailer_use
