@@ -9,7 +9,6 @@ from .links import (
     link_execute, link_namespace_details, link_namespace_list,
     link_statistics, link_view
 )
-from .tasks import task_execute_statistic  # NOQA - Force registration of task
 
 
 class StatisticsApp(MayanAppConfig):
@@ -18,6 +17,13 @@ class StatisticsApp(MayanAppConfig):
     has_static_media = True
     has_tests = True
     name = 'mayan.apps.mayan_statistics'
+    static_media_ignore_patterns = (
+        'statistics/node_modules/chart.js/book.*',
+        'statistics/node_modules/chart.js/karma.conf.*',
+        'statistics/node_modules/chart.js/samples/*',
+        'statistics/node_modules/chart.js/src/*',
+        'statistics/node_modules/chart.js/*docs*',
+    )
     verbose_name = _('Statistics')
 
     def ready(self):
