@@ -1,5 +1,5 @@
 from django.apps import apps
-from django.utils.encoding import force_text, python_2_unicode_compatible
+from django.utils.encoding import force_text
 from django.utils.translation import ugettext_lazy as _
 
 from celery.schedules import crontab
@@ -9,8 +9,7 @@ from mayan.celery import app
 from .renderers import ChartJSLine
 
 
-@python_2_unicode_compatible
-class StatisticNamespace(object):
+class StatisticNamespace:
     _registry = {}
 
     @classmethod
@@ -40,8 +39,7 @@ class StatisticNamespace(object):
         return self._statistics
 
 
-@python_2_unicode_compatible
-class Statistic(object):
+class Statistic:
     _registry = {}
     renderer = None
 
