@@ -1,6 +1,6 @@
 from django.shortcuts import get_object_or_404
 
-from mayan.apps.common.http import URL
+from mayan.apps.views.http import URL
 
 from .models import DocumentMetadata, MetadataType
 
