@@ -124,6 +124,8 @@ class DocumentMetadataSerializer(serializers.HyperlinkedModelSerializer):
         except DjangoValidationError as exception:
             raise ValidationError(exception)
 
+        attrs['value'] = self.instance.value
+
         return attrs
 
 
@@ -173,4 +175,6 @@ class NewDocumentMetadataSerializer(serializers.ModelSerializer):
         except DjangoValidationError as exception:
             raise ValidationError(exception)
 
+        attrs['value'] = instance.value
+
         return attrs
