@@ -1,11 +1,11 @@
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.smart_settings.classes import Namespace
+from mayan.apps.smart_settings.classes import SettingNamespace
 
 from .parsers import MetadataParser
 from .validators import MetadataValidator
 
-namespace = Namespace(label=_('Metadata'), name='metadata')
+namespace = SettingNamespace(label=_('Metadata'), name='metadata')
 
 setting_available_validators = namespace.add_setting(
     global_name='METADATA_AVAILABLE_VALIDATORS',
