@@ -2,10 +2,10 @@
 
 from django.core.exceptions import ValidationError
 
-from mayan.apps.common.tests.base import BaseTestCase
 from mayan.apps.documents.models import DocumentType
 from mayan.apps.documents.tests.literals import TEST_DOCUMENT_TYPE_2_LABEL
 from mayan.apps.documents.tests.mixins import DocumentTestMixin
+from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..models import DocumentMetadata
 
