@@ -3,7 +3,6 @@ from furl import furl
 from django.urls import reverse
 
 from mayan.apps.common.settings import setting_home_view
-from mayan.apps.common.tests.base import GenericViewTestCase
 from mayan.apps.documents.models import DocumentType
 from mayan.apps.documents.permissions import (
     permission_document_properties_edit, permission_document_type_edit,
@@ -11,6 +10,7 @@ from mayan.apps.documents.permissions import (
 )
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
 from mayan.apps.documents.tests.literals import TEST_DOCUMENT_TYPE_2_LABEL
+from mayan.apps.testing.tests.base import GenericViewTestCase
 
 from ..models import MetadataType
 from ..permissions import (
@@ -25,14 +25,14 @@ from .literals import (
     TEST_METADATA_TYPE_NAME_2, TEST_METADATA_VALUE_EDITED
 )
 from .mixins import (
-    DocumentMetadataViewTestMixin, MetadataTypeTestMixin,
-    MetadataTypeViewTestMixin
+    DocumentMetadataMixin, DocumentMetadataViewTestMixin,
+    MetadataTypeTestMixin, MetadataTypeViewTestMixin
 )
 
 
 class DocumentMetadataViewTestCase(
-    DocumentMetadataViewTestMixin, MetadataTypeTestMixin,
-    GenericDocumentViewTestCase
+    DocumentMetadataMixin, DocumentMetadataViewTestMixin,
+    MetadataTypeTestMixin, GenericDocumentViewTestCase
 ):
     def setUp(self):
         super(DocumentMetadataViewTestCase, self).setUp()
@@ -41,11 +41,6 @@ class DocumentMetadataViewTestCase(
             metadata_type=self.test_metadata_type
         )
 
-    def _create_test_document_metadata(self):
-        self.test_document_metadata = self.test_document.metadata.create(
-            metadata_type=self.test_metadata_type, value=''
-        )
-
     def test_document_metadata_add_get_view_no_permission(self):
         response = self._request_test_document_metadata_add_get_view()
         self.assertEqual(response.status_code, 404)
@@ -363,7 +358,7 @@ class DocumentMetadataViewTestCase(
             set([self.test_documents[0].pk, self.test_documents[1].pk])
         )
 
-    def test_document_metadata_list_view_no_access(self):
+    def test_document_metadata_list_view_no_permission(self):
         self._create_test_document_metadata()
 
         response = self._request_test_document_metadata_list_view()
