@@ -8,7 +8,7 @@ from .settings import (
 )
 
 
-class IndexFilesystemCache(object):
+class IndexFilesystemCache:
     @staticmethod
     def get_key_hash(key):
         return hashlib.sha256(force_bytes(key)).hexdigest()
