@@ -4,7 +4,7 @@ import logging
 from stat import S_IFDIR, S_IFREG
 from time import time
 
-from fuse import FuseOSError, Operations
+from fuse import FuseOSError, LoggingMixIn, Operations
 
 from django.core.exceptions import MultipleObjectsReturned
 from django.db.models import (
@@ -20,7 +20,6 @@ from .literals import (
 )
 from .runtime import cache
 
-
 logger = logging.getLogger(name=__name__)
 
 
@@ -29,7 +28,7 @@ class Trim(Transform):
     lookup_name = 'trim'
 
 
-class IndexFilesystem(Operations):
+class IndexFilesystem(LoggingMixIn, Operations):
     @staticmethod
     def _clean_queryset(queryset, source_field_name, destination_field_name):
         queryset = IndexFilesystem._clean_queryset_end_of_lines(
@@ -155,7 +154,7 @@ class IndexFilesystem(Operations):
                     if access_only:
                         return True
                     else:
-                        return Document.objects.get(pk=document_pk)
+                        return Document.valid.get(pk=document_pk)
 
             for count, part in enumerate(parts[1:]):
                 try:
@@ -172,8 +171,12 @@ class IndexFilesystem(Operations):
                     else:
                         try:
                             if node.index_template_node.link_documents:
+                                queryset = Document.valid.filter(
+                                    pk__in=node.documents.values('pk')
+                                )
+
                                 document = IndexFilesystem._clean_queryset(
-                                    queryset=node.documents,
+                                    queryset=queryset,
                                     source_field_name='label',
                                     destination_field_name='label_clean'
                                 ).get(label_clean=part)
@@ -291,9 +294,12 @@ class IndexFilesystem(Operations):
 
         # Documents
         if node.index_template_node.link_documents:
+            queryset = Document.valid.filter(
+                pk__in=node.documents.values('pk')
+            )
 
             queryset = IndexFilesystem._clean_queryset(
-                queryset=node.documents, source_field_name='label',
+                queryset=queryset, source_field_name='label',
                 destination_field_name='label_clean'
             )
 
