@@ -1,8 +1,8 @@
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.smart_settings.classes import Namespace
+from mayan.apps.smart_settings.classes import SettingNamespace
 
-namespace = Namespace(label=_('Mirroring'), name='mirroring')
+namespace = SettingNamespace(label=_('Mirroring'), name='mirroring')
 
 setting_document_lookup_cache_timeout = namespace.add_setting(
     global_name='MIRRORING_DOCUMENT_CACHE_LOOKUP_TIMEOUT', default=10,
