@@ -1,6 +1,6 @@
 import warnings
 
-from mayan.apps.common.tests.base import BaseTestCase
+from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..caches import IndexFilesystemCache
 
@@ -10,11 +10,11 @@ from .literals import (
 )
 
 
-class MockDocument(object):
+class MockDocument:
     pk = TEST_DOCUMENT_PK
 
 
-class MockNode(object):
+class MockNode:
     pk = TEST_NODE_PK
 
 
