@@ -4,12 +4,11 @@ import unittest
 from fuse import FuseOSError
 
 from django.db import connection
+from django.test import tag
 
-from mayan.apps.common.tests.base import BaseTestCase
-from mayan.apps.documents.models import Document
 from mayan.apps.documents.tests.mixins import DocumentTestMixin
 from mayan.apps.document_indexing.tests.mixins import IndexTestMixin
-from mayan.apps.storage.utils import fs_cleanup
+from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..filesystems import IndexFilesystem
 
@@ -21,6 +20,7 @@ from .literals import (
 )
 
 
+@tag('mirroring')
 @unittest.skipIf(connection.vendor == 'mysql', 'Known to fail due to unsupported feature of database manager.')
 class IndexFilesystemTestCase(
     IndexTestMixin, DocumentTestMixin, BaseTestCase
@@ -73,7 +73,11 @@ class IndexFilesystemTestCase(
         index_filesystem = IndexFilesystem(index_slug=self.test_index.slug)
 
         self._upload_test_document()
-        fs_cleanup(filename=self.test_document.latest_version.file.file.name)
+
+        # Delete the physical document file without deleting the document
+        # database entry.
+        document_file = self.test_document.latest_version.file
+        document_file.storage.delete(document_file.name)
 
         self.assertEqual(
             index_filesystem.getattr(
@@ -95,8 +99,8 @@ class IndexFilesystemTestCase(
         index_filesystem = IndexFilesystem(index_slug=self.test_index.slug)
 
         file_handle = index_filesystem.open(
-            '/{}/{}'.format(TEST_NODE_EXPRESSION, self.test_document.label),
-            'rb'
+            path='/{}/{}'.format(TEST_NODE_EXPRESSION, self.test_document.label),
+            flags='rb'
         )
 
         self.assertEqual(
@@ -170,7 +174,7 @@ class IndexFilesystemTestCase(
 
         self.assertEqual(len(list(index_filesystem.readdir('/', ''))), 4)
 
-    def test_ignore_stub_documents(self):
+    def test_stub_documents(self):
         self._create_test_index()
 
         self.test_index.node_templates.create(
@@ -178,16 +182,14 @@ class IndexFilesystemTestCase(
             expression=TEST_NODE_EXPRESSION, link_documents=True
         )
 
-        self.test_document = Document.objects.create(
-            document_type=self.test_document_type, label='document_stub'
-        )
+        self._create_test_document_stub()
         index_filesystem = IndexFilesystem(index_slug=self.test_index.slug)
         self.test_index.rebuild()
 
         self.assertEqual(
             list(
                 index_filesystem.readdir('/', '')
-            )[2:], []
+            )[2:], [TEST_NODE_EXPRESSION]
         )
 
     def test_duplicated_documents_readdir(self):
