@@ -1,11 +1,13 @@
 from django.db import models
-from django.utils.encoding import python_2_unicode_compatible
 from django.utils.translation import ugettext_lazy as _
 
+from mayan.apps.events.classes import EventManagerSave
+from mayan.apps.events.decorators import method_event
+
+from .events import event_message_created, event_message_edited
 from .managers import MessageManager
 
 
-@python_2_unicode_compatible
 class Message(models.Model):
     """
     Model to store an information message that will be displayed at the login
@@ -39,3 +41,17 @@ class Message(models.Model):
 
     def __str__(self):
         return self.label
+
+    @method_event(
+        event_manager_class=EventManagerSave,
+        created={
+            'event': event_message_created,
+            'target': 'self',
+        },
+        edited={
+            'event': event_message_edited,
+            'target': 'self',
+        }
+    )
+    def save(self, *args, **kwargs):
+        return super().save(*args, **kwargs)
