@@ -18,14 +18,14 @@ from django.utils.encoding import force_str, force_text
 from django.utils.module_loading import import_string
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.common.literals import (
+from mayan.apps.common.settings import setting_home_view
+from mayan.apps.common.utils import get_related_field, resolve_attribute
+from mayan.apps.permissions import Permission
+from mayan.apps.views.literals import (
     TEXT_SORT_FIELD_PARAMETER, TEXT_SORT_FIELD_VARIABLE_NAME,
     TEXT_SORT_ORDER_CHOICE_ASCENDING, TEXT_SORT_ORDER_CHOICE_DESCENDING,
     TEXT_SORT_ORDER_PARAMETER, TEXT_SORT_ORDER_VARIABLE_NAME
 )
-from mayan.apps.common.settings import setting_home_view
-from mayan.apps.common.utils import get_related_field, resolve_attribute
-from mayan.apps.permissions import Permission
 
 from .html_widgets import SourceColumnLinkWidget
 from .utils import get_current_view_name
@@ -33,7 +33,7 @@ from .utils import get_current_view_name
 logger = logging.getLogger(name=__name__)
 
 
-class Link(object):
+class Link:
     _registry = {}
 
     @classmethod
@@ -224,7 +224,7 @@ class Link(object):
         return resolved_link
 
 
-class Menu(object):
+class Menu:
     _registry = {}
 
     @classmethod
@@ -242,15 +242,16 @@ class Menu(object):
         if name in self.__class__._registry:
             raise Exception('A menu with this name already exists')
 
+        self.bound_links = {}
         self.condition = condition
         self.icon_class = icon_class
-        self.name = name
         self.label = label
-        self.bound_links = {}
-        self.unbound_links = {}
         self.link_positions = {}
-        self.__class__._registry[name] = self
+        self.name = name
         self.non_sorted_sources = non_sorted_sources or []
+        self.proxy_exclusions = set()
+        self.unbound_links = {}
+        self.__class__._registry[name] = self
 
     def __repr__(self):
         return '<Menu: {}>'.format(self.name)
@@ -262,6 +263,9 @@ class Menu(object):
             source_links.append(link)
             self.link_positions[link] = position or 0
 
+    def add_proxy_exclusion(self, source):
+        self.proxy_exclusions.add(source)
+
     def add_unsorted_source(self, source):
         self.non_sorted_sources.append(source)
 
@@ -382,14 +386,15 @@ class Menu(object):
                             # Check to see if object is a proxy model. If it is, add its parent model
                             # menu links too.
                             if hasattr(resolved_navigation_object, '_meta'):
-                                parent_model = resolved_navigation_object._meta.proxy_for_model
-                                if parent_model:
-                                    parent_instance = parent_model.objects.filter(pk=resolved_navigation_object.pk)
-                                    if parent_instance:
-                                        for link_set in self.resolve(context=context, source=parent_instance.first()):
-                                            for link in link_set['links']:
-                                                if link.link not in self.unbound_links.get(bound_source, ()):
-                                                    resolved_links.append(link)
+                                if resolved_navigation_object._meta.model not in self.proxy_exclusions:
+                                    parent_model = resolved_navigation_object._meta.proxy_for_model
+                                    if parent_model:
+                                        parent_instance = parent_model.objects.filter(pk=resolved_navigation_object.pk)
+                                        if parent_instance:
+                                            for link_set in self.resolve(context=context, source=parent_instance.first()):
+                                                for link in link_set['links']:
+                                                    if link.link not in self.unbound_links.get(bound_source, ()):
+                                                        resolved_links.append(link)
 
                             for link in links:
                                 resolved_link = link.resolve(
@@ -514,7 +519,7 @@ class Menu(object):
             )
 
 
-class ResolvedLink(object):
+class ResolvedLink:
     def __init__(self, link, current_view_name):
         self.context = None
         self.current_view_name = current_view_name
@@ -584,7 +589,7 @@ class Separator(Link):
         return result
 
 
-class SourceColumn(object):
+class SourceColumn:
     _registry = {}
 
     @staticmethod
