@@ -4,9 +4,9 @@ from django.urls import reverse
 from furl import furl
 
 from mayan.apps.acls.classes import ModelPermission
-from mayan.apps.common.tests.base import GenericViewTestCase
-from mayan.apps.common.tests.literals import TEST_VIEW_NAME
 from mayan.apps.permissions import Permission, PermissionNamespace
+from mayan.apps.testing.literals import TEST_VIEW_NAME
+from mayan.apps.testing.tests.base import GenericViewTestCase
 
 from ..classes import Link, Menu
 
