@@ -1,12 +1,12 @@
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.smart_settings.classes import Namespace
+from mayan.apps.smart_settings.classes import SettingNamespace
 
 from .setting_migrations import OCRSettingMigration
 
-namespace = Namespace(
+namespace = SettingNamespace(
     label=_('OCR'), migration_class=OCRSettingMigration, name='ocr',
-    version='0002'
+    version='0003'
 )
 
 setting_ocr_backend = namespace.add_setting(
@@ -16,7 +16,7 @@ setting_ocr_backend = namespace.add_setting(
 )
 setting_ocr_backend_arguments = namespace.add_setting(
     global_name='OCR_BACKEND_ARGUMENTS',
-    default={}
+    default={'environment': {'OMP_THREAD_LIMIT': '1'}}
 )
 setting_auto_ocr = namespace.add_setting(
     global_name='OCR_AUTO_OCR', default=True,
