@@ -1,8 +1,8 @@
 from django.test import override_settings
 
-from mayan.apps.common.tests.base import BaseTestCase
 from mayan.apps.documents.tests.mixins import DocumentTestMixin
 from mayan.apps.documents.tests.literals import TEST_DEU_DOCUMENT_PATH
+from mayan.apps.testing.tests.base import BaseTestCase
 
 from .literals import (
     TEST_DOCUMENT_CONTENT, TEST_DOCUMENT_CONTENT_DEU_1,
@@ -32,7 +32,7 @@ class GermanOCRSupportTestCase(DocumentTestMixin, BaseTestCase):
     def setUp(self):
         super(GermanOCRSupportTestCase, self).setUp()
 
-        with open(TEST_DEU_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_DEU_DOCUMENT_PATH, mode='rb') as file_object:
             self.test_document = self.test_document_type.new_document(
                 file_object=file_object, language='deu'
             )
