@@ -1,20 +1,20 @@
-from importlib import import_module
 import itertools
 import logging
 
 from django.apps import apps
 from django.core.exceptions import PermissionDenied
 from django.db.utils import OperationalError, ProgrammingError
-from django.utils.encoding import force_text, python_2_unicode_compatible
+from django.utils.encoding import force_text
 from django.utils.translation import ugettext_lazy as _
 
+from mayan.apps.common.class_mixins import AppsModuleLoaderMixin
+
 from .exceptions import InvalidNamespace
 
 logger = logging.getLogger(name=__name__)
 
 
-@python_2_unicode_compatible
-class PermissionNamespace(object):
+class PermissionNamespace:
     _registry = {}
 
     @classmethod
@@ -47,9 +47,9 @@ class PermissionNamespace(object):
         return permission
 
 
-@python_2_unicode_compatible
-class Permission(object):
+class Permission(AppsModuleLoaderMixin):
     _imported_app = []
+    _loader_module_name = 'permissions'
     _permissions = {}
     _stored_permissions_cache = {}
 
@@ -92,31 +92,8 @@ class Permission(object):
             return cls._permissions[pk].stored_permission
 
     @classmethod
-    def initialize(cls):
-        module_name = 'permissions'
-
-        for app in apps.get_app_configs():
-            # Keep track of the apps that have already been imported to
-            # avoid importing them more than once. Does not causes a problem,
-            # it is an optimization to speed up statups.
-            if app not in cls._imported_app:
-                try:
-                    import_module('{}.{}'.format(app.name, module_name))
-                except ImportError as exception:
-                    non_fatal_messages = (
-                        'No module named {}'.format(module_name),
-                        'No module named \'{}.{}\''.format(app.name, module_name)
-                    )
-
-                    if force_text(exception) not in non_fatal_messages:
-                        logger.error(
-                            'Error importing %s %s.py file; %s', app.name,
-                            module_name, exception
-                        )
-                        raise
-                finally:
-                    cls._imported_app.append(app)
-
+    def load_modules(cls):
+        super().load_modules()
         # Invalidate cache always. This is for tests that build a new memory
         # only database and cause all cache references built in the .ready()
         # method to be invalid.
