@@ -1,4 +1,4 @@
-from mayan.apps.common.tests.base import GenericViewTestCase
+from mayan.apps.testing.tests.base import GenericViewTestCase
 from mayan.apps.user_management.permissions import permission_group_edit
 from mayan.apps.user_management.tests.mixins import GroupTestMixin
 
