@@ -3,7 +3,7 @@ import os
 from django.template import loader
 from django.template.base import Template
 from django.template.context import Context
-from django.utils.encoding import force_text, python_2_unicode_compatible
+from django.utils.encoding import force_text
 from django.utils.html import mark_safe
 from django.utils.translation import ugettext_lazy as _
 
@@ -13,8 +13,10 @@ from mayan.apps.task_manager.settings import (
     setting_celery_broker_url, setting_celery_result_backend
 )
 
+from .literals import DEFAULT_GUNICORN_WORKER_CLASS
 
-class Variable(object):
+
+class Variable:
     def __init__(self, name, default, environment_name):
         self.name = name
         self.default = default
@@ -40,8 +42,7 @@ class YAMLVariable(Variable):
         ).replace('...\n', '').replace('\n', '')
 
 
-@python_2_unicode_compatible
-class PlatformTemplate(object):
+class PlatformTemplate:
     _registry = {}
     context = {}
     context_defaults = {}
@@ -129,6 +130,11 @@ class PlatformTemplateSupervisord(PlatformTemplate):
         setting_celery_broker_url, setting_celery_result_backend
     )
     variables = (
+        Variable(
+            name='GUNICORN_WORKER_CLASS',
+            default=DEFAULT_GUNICORN_WORKER_CLASS,
+            environment_name='MAYAN_GUNICORN_WORKER_CLASS'
+        ),
         Variable(
             name='GUNICORN_WORKERS', default=2,
             environment_name='MAYAN_GUNICORN_WORKERS'
