@@ -1,8 +1,8 @@
-from django.utils.six import StringIO
+from io import StringIO
 
 from django.core import management
 
-from mayan.apps.common.tests.base import BaseTestCase
+from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..classes import PlatformTemplate
 
