@@ -8,13 +8,16 @@ from mayan.apps.acls.permissions import (
     permission_acl_edit, permission_acl_view
 )
 from mayan.apps.common.apps import MayanAppConfig
-from mayan.apps.common.html_widgets import TwoStateWidget
-from mayan.apps.common.menus import menu_object, menu_secondary, menu_setup
+from mayan.apps.common.classes import ModelCopy
+from mayan.apps.common.menus import (
+    menu_list_facet, menu_object, menu_secondary, menu_setup
+)
 from mayan.apps.events.classes import EventModelRegistry, ModelEventType
 from mayan.apps.events.links import (
     link_events_for_object, link_object_event_types_user_subcriptions_list
 )
 from mayan.apps.navigation.classes import SourceColumn
+from mayan.apps.views.html_widgets import TwoStateWidget
 
 from .classes import QuotaBackend
 from .events import event_quota_created, event_quota_edited
@@ -47,7 +50,15 @@ class QuotasApp(MayanAppConfig):
 
         EventModelRegistry.register(model=Quota)
 
-        QuotaBackend.initialize()
+        QuotaBackend.load_modules()
+
+        ModelCopy(
+            model=Quota, bind_link=True, register_permission=True
+        ).add_fields(
+            field_names=(
+                'backend_path', 'backend_data', 'enabled',
+            ),
+        )
 
         ModelEventType.register(
             event_types=(event_quota_created, event_quota_edited),
@@ -88,11 +99,16 @@ class QuotasApp(MayanAppConfig):
             source=Quota, widget=TwoStateWidget
         )
 
+        menu_list_facet.bind_links(
+            links=(
+                link_acl_list, link_events_for_object,
+                link_object_event_types_user_subcriptions_list,
+            ), sources=(Quota,)
+        )
+
         menu_object.bind_links(
             links=(
-                link_quota_edit, link_acl_list, link_events_for_object,
-                link_object_event_types_user_subcriptions_list,
-                link_quota_delete,
+                link_quota_edit, link_quota_delete,
             ), sources=(Quota,)
         )
 
