@@ -20,6 +20,11 @@ class RedactionsApp(MayanAppConfig):
     has_static_media = True
     has_tests = False
     name = 'mayan.apps.redactions'
+    static_media_ignore_patterns = (
+        'redactions/node_modules/cropperjs/src/*',
+        'redactions/node_modules/cropperjs/types/index.d.ts',
+        'redactions/node_modules/jquery-cropper/src/*',
+    )
     verbose_name = _('Redactions')
 
     def ready(self):
