@@ -1,6 +1,5 @@
 import errno
 import hashlib
-from importlib import import_module
 import logging
 import os
 import re
@@ -8,14 +7,14 @@ import sys
 
 import yaml
 
-from django.apps import apps
 from django.conf import settings
 from django.utils.functional import Promise
 from django.utils.encoding import (
-    force_bytes, force_text, python_2_unicode_compatible
+    force_bytes, force_text
 )
 from django.utils.translation import ugettext_lazy as _
 
+from mayan.apps.common.class_mixins import AppsModuleLoaderMixin
 from mayan.apps.common.serialization import yaml_dump, yaml_load
 
 from .literals import (
@@ -27,7 +26,7 @@ logger = logging.getLogger(name=__name__)
 
 def read_configuration_file(filepath):
     try:
-        with open(filepath) as file_object:
+        with open(file=filepath) as file_object:
             file_object.seek(0, os.SEEK_END)
             if file_object.tell():
                 file_object.seek(0)
@@ -47,22 +46,10 @@ def read_configuration_file(filepath):
             raise
 
 
-@python_2_unicode_compatible
-class Namespace(object):
+class SettingNamespace(AppsModuleLoaderMixin):
+    _loader_module_name = 'settings'
     _registry = {}
 
-    @staticmethod
-    def initialize():
-        for app in apps.get_app_configs():
-            try:
-                import_module('{}.settings'.format(app.name))
-            except ImportError as exception:
-                if force_text(exception) not in ('No module named settings', 'No module named \'{}.settings\''.format(app.name)):
-                    logger.error(
-                        'Error importing %s settings.py file; %s', app.name,
-                        exception
-                    )
-
     @classmethod
     def get(cls, name):
         return cls._registry[name]
@@ -106,7 +93,7 @@ class Namespace(object):
         return Setting(namespace=self, **kwargs)
 
     def get_config_version(self):
-        return Namespace.get_namespace_config(name=self.name).get(
+        return SettingNamespace.get_namespace_config(name=self.name).get(
             'version', NAMESPACE_VERSION_INITIAL
         )
 
@@ -123,7 +110,7 @@ class Namespace(object):
         return sorted(self._settings, key=lambda x: x.global_name)
 
 
-class NamespaceMigration(object):
+class SettingNamespaceMigration:
     @staticmethod
     def get_method_name(setting):
         return setting.global_name.lower()
@@ -139,7 +126,7 @@ class NamespaceMigration(object):
 
     def migrate(self, setting):
         if self.namespace.get_config_version() != self.namespace.version:
-            setting_method_name = NamespaceMigration.get_method_name(
+            setting_method_name = SettingNamespaceMigration.get_method_name(
                 setting=setting
             )
 
@@ -178,8 +165,7 @@ class NamespaceMigration(object):
             setting.raw_value = value
 
 
-@python_2_unicode_compatible
-class Setting(object):
+class Setting:
     _registry = {}
     _cache_hash = None
     _config_file_cache = None
@@ -226,7 +212,7 @@ class Setting(object):
 
         if not namespace:
             namespace_dictionary = {}
-            for _namespace in Namespace.get_all():
+            for _namespace in SettingNamespace.get_all():
                 namespace_dictionary[_namespace.name] = {
                     'version': _namespace.version
                 }
@@ -273,7 +259,7 @@ class Setting(object):
             path = settings.CONFIGURATION_FILEPATH
 
         try:
-            with open(path, mode='w') as file_object:
+            with open(file=path, mode='w') as file_object:
                 file_object.write(cls.dump_data())
         except IOError as exception:
             if exception.errno == errno.ENOENT:
@@ -366,6 +352,9 @@ class Setting(object):
 
         return self.yaml
 
+    def set(self, value):
+        self.value = Setting.serialize_value(value=value)
+
     @property
     def value(self):
         if not self.loaded:
