@@ -1,12 +1,14 @@
+import copy
+from contextlib import contextmanager
 import os
 
 from django.conf import settings
 from django.utils.encoding import force_bytes
 
-from mayan.apps.common.tests.mixins import EnvironmentTestCaseMixin
+from mayan.apps.testing.tests.mixins import EnvironmentTestCaseMixin
 from mayan.apps.storage.utils import fs_cleanup, NamedTemporaryFile
 
-from ..classes import Namespace, Setting
+from ..classes import SettingNamespace, Setting
 from ..utils import BaseSetting, SettingNamespaceSingleton
 
 from .literals import (
@@ -15,7 +17,7 @@ from .literals import (
 )
 
 
-class BoostrapSettingTestMixin(object):
+class BoostrapSettingTestMixin:
     def _create_test_bootstrap_singleton(self):
         self.test_globals = {}
         self.test_globals['BASE_DIR'] = ''
@@ -31,10 +33,10 @@ class BoostrapSettingTestMixin(object):
         )
 
 
-class SmartSettingsTestCaseMixin(object):
+class SmartSettingsTestCaseMixin:
     def setUp(self):
         super(SmartSettingsTestCaseMixin, self).setUp()
-        Namespace.invalidate_cache_all()
+        SettingNamespace.invalidate_cache_all()
 
         with NamedTemporaryFile(delete=False) as self.test_setting_config_file_object:
             settings.CONFIGURATION_FILEPATH = self.test_setting_config_file_object.name
@@ -43,9 +45,24 @@ class SmartSettingsTestCaseMixin(object):
 
     def tearDown(self):
         fs_cleanup(filename=self.test_setting_config_file_object.name)
-        Namespace.invalidate_cache_all()
+        SettingNamespace.invalidate_cache_all()
         super(SmartSettingsTestCaseMixin, self).tearDown()
 
+    @contextmanager
+    def override_setting(self, global_name, method=None, value=None):
+        setting = Setting.get(global_name=global_name)
+        old_value = copy.copy(setting.value)
+        if method is None:
+            setting.set(value=value)
+        else:
+            current_value = setting.value
+            getattr(current_value, method)(value)
+            setting.set(value=current_value)
+        try:
+            yield
+        finally:
+            setting.set(value=old_value)
+
 
 class SmartSettingTestMixin(EnvironmentTestCaseMixin):
     test_setting_global_name = None
@@ -86,14 +103,14 @@ class SmartSettingTestMixin(EnvironmentTestCaseMixin):
 
     def _create_test_settings_namespace(self, **kwargs):
         try:
-            self.test_settings_namespace = Namespace.get(
+            self.test_settings_namespace = SettingNamespace.get(
                 name=TEST_NAMESPACE_NAME
             )
             self.test_settings_namespace.migration_class = None
             self.test_settings_namespace.version = None
             self.test_settings_namespace.__dict__.update(kwargs)
         except KeyError:
-            self.test_settings_namespace = Namespace(
+            self.test_settings_namespace = SettingNamespace(
                 label=TEST_NAMESPACE_LABEL, name=TEST_NAMESPACE_NAME,
                 **kwargs
             )
@@ -105,7 +122,7 @@ class SmartSettingTestMixin(EnvironmentTestCaseMixin):
         )
 
 
-class SmartSettingViewTestMixin(object):
+class SmartSettingViewTestMixin:
     def _request_namespace_list_view(self):
         return self.get(viewname='settings:namespace_list')
 
