@@ -3,9 +3,9 @@ from pathlib import Path
 from django.conf import settings
 from django.utils.encoding import force_text
 
-from mayan.apps.common.settings import setting_paginate_by
-from mayan.apps.common.tests.base import BaseTestCase
 from mayan.apps.storage.utils import fs_cleanup
+from mayan.apps.testing.tests.base import BaseTestCase
+from mayan.apps.views.settings import setting_paginate_by
 
 from ..classes import Setting
 
@@ -79,7 +79,7 @@ class ClassesTestCase(SmartSettingTestMixin, BaseTestCase):
         self.assertTrue(Setting.check_changed())
 
 
-class NamespaceMigrationTestCase(SmartSettingTestMixin, BaseTestCase):
+class SettingNamespaceMigrationTestCase(SmartSettingTestMixin, BaseTestCase):
     def test_environment_migration(self):
         self._set_environment_variable(
             name='MAYAN_{}'.format(TEST_SETTING_GLOBAL_NAME),
