@@ -4,15 +4,16 @@ from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.common.apps import MayanAppConfig
 from mayan.apps.common.classes import MissingItem
-from mayan.apps.common.html_widgets import TwoStateWidget
+from mayan.apps.common.signals import signal_post_initial_setup, signal_post_upgrade
+from mayan.apps.converter.links import link_transformation_list
+from mayan.apps.documents.menus import menu_documents
+from mayan.apps.documents.signals import signal_post_version_upload
+from mayan.apps.logging.classes import ErrorLog
+from mayan.apps.navigation.classes import SourceColumn
+from mayan.apps.views.html_widgets import TwoStateWidget
 from mayan.apps.common.menus import (
     menu_list_facet, menu_object, menu_secondary, menu_setup
 )
-from mayan.apps.common.signals import post_initial_setup, post_upgrade
-from mayan.apps.converter.links import link_transformation_list
-from mayan.apps.documents.menus import menu_documents
-from mayan.apps.documents.signals import post_version_upload
-from mayan.apps.navigation.classes import SourceColumn
 
 from .classes import StagingFile
 from .handlers import (
@@ -27,7 +28,7 @@ from .links import (
     link_setup_source_create_pop3_email, link_setup_source_create_sane_scanner,
     link_setup_source_create_watch_folder, link_setup_source_create_webform,
     link_setup_source_create_staging_folder, link_setup_source_delete,
-    link_setup_source_edit, link_setup_source_logs, link_staging_file_delete,
+    link_setup_source_edit, link_staging_file_delete,
     link_document_version_upload
 )
 from .widgets import StagingFileThumbnailWidget
@@ -40,6 +41,10 @@ class SourcesApp(MayanAppConfig):
     has_static_media = True
     has_tests = True
     name = 'mayan.apps.sources'
+    static_media_ignore_patterns = (
+        'sources/node_modules/dropzone/index.js',
+        'sources/node_modules/dropzone/component.json'
+    )
     verbose_name = _('Sources')
 
     def ready(self):
@@ -51,12 +56,17 @@ class SourcesApp(MayanAppConfig):
         IMAPEmail = self.get_model(model_name='IMAPEmail')
         POP3Email = self.get_model(model_name='POP3Email')
         Source = self.get_model(model_name='Source')
-        SourceLog = self.get_model(model_name='SourceLog')
         SaneScanner = self.get_model(model_name='SaneScanner')
         StagingFolderSource = self.get_model(model_name='StagingFolderSource')
         WatchFolderSource = self.get_model(model_name='WatchFolderSource')
         WebFormSource = self.get_model(model_name='WebFormSource')
 
+        error_log = ErrorLog(app_config=self)
+        error_log.register_model(model=IMAPEmail)
+        error_log.register_model(model=POP3Email)
+        error_log.register_model(model=SaneScanner)
+        error_log.register_model(model=WatchFolderSource)
+
         MissingItem(
             label=_('Create a document source'),
             description=_(
@@ -96,22 +106,11 @@ class SourcesApp(MayanAppConfig):
             )
         )
 
-        SourceColumn(
-            source=SourceLog,
-            label=_('Date time'),
-            func=lambda context: context['object'].datetime
-        )
-        SourceColumn(
-            source=SourceLog,
-            label=_('Message'),
-            func=lambda context: context['object'].message
-        )
-
         menu_documents.bind_links(links=(link_document_create_multiple,))
 
         menu_list_facet.bind_links(
             links=(
-                link_setup_source_logs, link_transformation_list,
+                link_transformation_list,
             ), sources=(
                 POP3Email, IMAPEmail, SaneScanner, StagingFolderSource,
                 WatchFolderSource, WebFormSource
@@ -157,20 +156,20 @@ class SourcesApp(MayanAppConfig):
             )
         )
 
-        post_upgrade.connect(
-            receiver=handler_initialize_periodic_tasks,
-            dispatch_uid='sources_handler_initialize_periodic_tasks'
-        )
-        post_initial_setup.connect(
-            receiver=handler_create_default_document_source,
-            dispatch_uid='sources_handler_create_default_document_source'
-        )
-        post_version_upload.connect(
-            receiver=handler_copy_transformations_to_version,
-            dispatch_uid='sources_handler_copy_transformations_to_version'
-        )
         pre_delete.connect(
             receiver=handler_delete_interval_source_periodic_task,
             sender=DocumentType,
             dispatch_uid='sources_handler_delete_interval_source_periodic_task'
         )
+        signal_post_initial_setup.connect(
+            receiver=handler_create_default_document_source,
+            dispatch_uid='sources_handler_create_default_document_source'
+        )
+        signal_post_upgrade.connect(
+            receiver=handler_initialize_periodic_tasks,
+            dispatch_uid='sources_handler_initialize_periodic_tasks'
+        )
+        signal_post_version_upload.connect(
+            receiver=handler_copy_transformations_to_version,
+            dispatch_uid='sources_handler_copy_transformations_to_version'
+        )
