@@ -2,18 +2,18 @@ import base64
 import logging
 import os
 import time
+from urllib.parse import quote_plus, unquote_plus
 
 from furl import furl
 
 from django.core.files import File
 from django.core.files.base import ContentFile
 from django.urls import reverse
-from django.utils.encoding import force_text, python_2_unicode_compatible
+from django.utils.encoding import force_text
 from django.utils.functional import cached_property
-from django.utils.six.moves.urllib.parse import quote_plus, unquote_plus
 
+from mayan.apps.converter.classes import ConverterBase
 from mayan.apps.converter.transformations import TransformationResize
-from mayan.apps.converter.utils import get_converter_class
 from mayan.apps.storage.classes import DefinedStorage
 
 from .literals import STORAGE_NAME_SOURCE_STAGING_FOLDER_FILE
@@ -37,8 +37,7 @@ class SourceUploadedFile(File):
         self.extra_data = extra_data
 
 
-@python_2_unicode_compatible
-class StagingFile(object):
+class StagingFile:
     """
     Simple class to extend the File class to add preview capabilities
     files in a directory on a storage
@@ -61,7 +60,9 @@ class StagingFile(object):
 
     def as_file(self):
         return File(
-            file=open(self.get_full_path(), mode='rb'), name=self.filename
+            file=open(
+                file=self.get_full_path(), mode='rb'
+            ), name=self.filename
         )
 
     @property
@@ -87,7 +88,7 @@ class StagingFile(object):
                 'staging file cache file "%s" not found', self.cache_filename
             )
             image = self.get_image(transformations=transformation_list)
-            with self.storage.open(self.cache_filename, 'wb+') as file_object:
+            with self.storage.open(name=self.cache_filename, mode='wb+') as file_object:
                 file_object.write(image.getvalue())
 
         return self.cache_filename
@@ -143,8 +144,10 @@ class StagingFile(object):
         file_object = None
 
         try:
-            file_object = open(self.get_full_path(), mode='rb')
-            converter = get_converter_class()(file_object=file_object)
+            file_object = open(file=self.get_full_path(), mode='rb')
+            converter = ConverterBase.get_converter_class()(
+                file_object=file_object
+            )
 
             page_image = converter.get_page()
 
@@ -153,7 +156,7 @@ class StagingFile(object):
             if not self.storage.exists(cache_filename):
                 self.storage.save(name=cache_filename, content=ContentFile(content=''))
 
-            with self.storage.open(cache_filename, 'wb+') as file_object:
+            with self.storage.open(file=cache_filename, mode='wb+') as file_object:
                 file_object.write(page_image.getvalue())
         except Exception as exception:
             # Cleanup in case of error
