@@ -1,18 +1,18 @@
 import json
 import logging
 
+from django.conf import settings
 from django.db import models, transaction
-from django.utils.encoding import force_text, python_2_unicode_compatible
+from django.utils.encoding import force_text
 from django.utils.translation import ugettext_lazy as _
 
 from django_celery_beat.models import PeriodicTask, IntervalSchedule
 from model_utils.managers import InheritanceManager
 
-from mayan.apps.common.compressed_files import Archive
-from mayan.apps.common.exceptions import NoMIMETypeMatch
 from mayan.apps.converter.layers import layer_saved_transformations
 from mayan.apps.documents.models import Document, DocumentType
-from mayan.apps.documents.settings import setting_language
+from mayan.apps.storage.compressed_files import Archive
+from mayan.apps.storage.exceptions import NoMIMETypeMatch
 
 from ..literals import (
     DEFAULT_INTERVAL, SOURCE_CHOICES, SOURCE_UNCOMPRESS_CHOICES
@@ -22,7 +22,6 @@ from ..wizards import WizardStep
 logger = logging.getLogger(name=__name__)
 
 
-@python_2_unicode_compatible
 class Source(models.Model):
     label = models.CharField(
         db_index=True, help_text=_('A short text to describe this source.'),
@@ -107,13 +106,10 @@ class Source(models.Model):
         Upload an individual document
         """
         try:
-            with transaction.atomic():
-                document = Document(
-                    description=description or '', document_type=document_type,
-                    label=label or file_object.name,
-                    language=language or setting_language.value
-                )
-                document.save(_user=user)
+            document = document_type.new_document(
+                description=description, file_object=file_object, label=label,
+                language=language, _user=user
+            )
         except Exception as exception:
             logger.critical(
                 'Unexpected exception while trying to create new document '
@@ -213,6 +209,20 @@ class IntervalBaseModel(OutOfProcessSource):
     def _get_periodic_task_name(self, pk=None):
         return 'check_interval_source-%i' % (pk or self.pk)
 
+    def check_source(self, test=False):
+        try:
+            self._check_source(test=test)
+        except Exception as exception:
+            self.error_log.create(
+                text='{}; {}'.format(
+                    exception.__class__.__name__, exception
+                )
+            )
+            if settings.DEBUG:
+                raise
+        else:
+            self.error_log.all().delete()
+
     def delete(self, *args, **kwargs):
         pk = self.pk
         with transaction.atomic():
@@ -237,22 +247,3 @@ class IntervalBaseModel(OutOfProcessSource):
                 task='mayan.apps.sources.tasks.task_check_interval_source',
                 kwargs=json.dumps(obj={'source_id': self.pk})
             )
-
-
-class SourceLog(models.Model):
-    source = models.ForeignKey(
-        on_delete=models.CASCADE, related_name='logs', to=Source,
-        verbose_name=_('Source')
-    )
-    datetime = models.DateTimeField(
-        auto_now_add=True, editable=False, verbose_name=_('Date time')
-    )
-    message = models.TextField(
-        blank=True, editable=False, verbose_name=_('Message')
-    )
-
-    class Meta:
-        get_latest_by = 'datetime'
-        ordering = ('-datetime',)
-        verbose_name = _('Log entry')
-        verbose_name_plural = _('Log entries')
