@@ -1,6 +1,8 @@
 import shutil
 
-from mayan.apps.documents.tests.literals import TEST_SMALL_DOCUMENT_PATH
+from mayan.apps.documents.tests.literals import (
+    TEST_DOCUMENT_DESCRIPTION, TEST_SMALL_DOCUMENT_PATH
+)
 from mayan.apps.storage.utils import fs_cleanup, mkdtemp
 
 from ..literals import SOURCE_CHOICE_WEB_FORM, SOURCE_UNCOMPRESS_CHOICE_Y
@@ -14,26 +16,32 @@ from .literals import (
 )
 
 
-class DocumentVersionUploadViewTestMixin(object):
-    def _request_document_version_upload_view(self, source_file):
+class DocumentUploadIssueTestMixin:
+    def _request_test_source_create_view(self):
         return self.post(
-            viewname='sources:document_version_upload', kwargs={
-                'document_id': self.test_document.pk,
-                'source_id': self.test_source.pk,
-            }, data={'source-file': source_file}
+            viewname='sources:setup_source_create', kwargs={
+                'source_type_name': SOURCE_CHOICE_WEB_FORM
+            }, data={
+                'enabled': True, 'label': 'test', 'uncompress': 'n'
+            }
         )
 
-    def _request_document_version_upload_no_source_view(self, source_file):
+    def _request_test_source_edit_view(self):
         return self.post(
-            viewname='sources:document_version_upload', kwargs={
-                'document_id': self.test_document.pk,
-            }, data={'source-file': source_file}
+            viewname='documents:document_edit', kwargs={
+                'document_id': self.test_document.pk
+            },
+            data={
+                'description': TEST_DOCUMENT_DESCRIPTION,
+                'label': self.test_document.label,
+                'language': self.test_document.language
+            }
         )
 
 
-class DocumentUploadWizardViewTestMixin(object):
+class DocumentUploadWizardViewTestMixin:
     def _request_upload_wizard_view(self, document_path=TEST_SMALL_DOCUMENT_PATH):
-        with open(document_path, mode='rb') as file_object:
+        with open(file=document_path, mode='rb') as file_object:
             return self.post(
                 viewname='sources:document_upload_interactive', kwargs={
                     'source_id': self.test_source.pk
@@ -51,7 +59,24 @@ class DocumentUploadWizardViewTestMixin(object):
         )
 
 
-class StagingFolderAPIViewTestMixin(object):
+class DocumentVersionUploadViewTestMixin:
+    def _request_document_version_upload_view(self, source_file):
+        return self.post(
+            viewname='sources:document_version_upload', kwargs={
+                'document_id': self.test_document.pk,
+                'source_id': self.test_source.pk,
+            }, data={'source-file': source_file}
+        )
+
+    def _request_document_version_upload_no_source_view(self, source_file):
+        return self.post(
+            viewname='sources:document_version_upload', kwargs={
+                'document_id': self.test_document.pk,
+            }, data={'source-file': source_file}
+        )
+
+
+class StagingFolderAPIViewTestMixin:
     def setUp(self):
         super(StagingFolderTestMixin, self).setUp()
         self.test_staging_folders = []
@@ -101,7 +126,7 @@ class StagingFolderAPIViewTestMixin(object):
         return self.get(viewname='rest_api:stagingfolder-list')
 
 
-class StagingFolderFileAPIViewTestMixin(object):
+class StagingFolderFileAPIViewTestMixin:
     def _request_test_staging_folder_file_delete_api_view(self):
         return self.delete(
             viewname='rest_api:stagingfolderfile-detail', kwargs={
@@ -127,7 +152,7 @@ class StagingFolderFileAPIViewTestMixin(object):
         )
 
 
-class StagingFolderTestMixin(object):
+class StagingFolderTestMixin:
     def setUp(self):
         super(StagingFolderTestMixin, self).setUp()
         self.test_staging_folders = []
@@ -158,7 +183,7 @@ class StagingFolderTestMixin(object):
         )[0]
 
 
-class StagingFolderViewTestMixin(object):
+class StagingFolderViewTestMixin:
     def _request_test_staging_file_delete_view(self, staging_folder, staging_file):
         return self.post(
             viewname='sources:staging_file_delete', kwargs={
@@ -168,7 +193,7 @@ class StagingFolderViewTestMixin(object):
         )
 
 
-class SourceTestMixin(object):
+class SourceTestMixin:
     auto_create_test_source = True
 
     def setUp(self):
@@ -183,7 +208,7 @@ class SourceTestMixin(object):
         )
 
 
-class SourceViewTestMixin(object):
+class SourceViewTestMixin:
     def _request_setup_source_list_view(self):
         return self.get(viewname='sources:setup_source_list')
 
@@ -222,7 +247,7 @@ class SourceViewTestMixin(object):
         )
 
 
-class WatchFolderTestMixin(object):
+class WatchFolderTestMixin:
     def _create_test_watchfolder(self):
         self.test_watch_folder = WatchFolderSource.objects.create(
             document_type=self.test_document_type,
