@@ -1,9 +1,9 @@
 import os
 import shutil
 
-from mayan.apps.common.tests.base import BaseTestCase
 from mayan.apps.documents.tests.literals import TEST_NON_ASCII_DOCUMENT_PATH
 from mayan.apps.storage.utils import mkdtemp
+from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..classes import StagingFile
 
