@@ -1,10 +1,10 @@
 import importlib
 import logging
 
-from mayan.apps.common.tests.base import BaseTestCase
 from mayan.apps.smart_settings.tests.mixins import SmartSettingTestMixin
 from mayan.apps.sources import storages
 from mayan.apps.storage.classes import DefinedStorage
+from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..literals import STORAGE_NAME_SOURCE_STAGING_FOLDER_FILE
 from ..settings import setting_staging_file_image_cache_storage_arguments
