@@ -1,6 +1,5 @@
 from django.test import override_settings
 
-from mayan.apps.common.tests.base import GenericViewTestCase
 from mayan.apps.documents.models import Document
 from mayan.apps.documents.permissions import (
     permission_document_create, permission_document_new_version
@@ -10,8 +9,9 @@ from mayan.apps.documents.tests.literals import (
     TEST_COMPRESSED_DOCUMENT_PATH, TEST_DOCUMENT_DESCRIPTION,
     TEST_SMALL_DOCUMENT_CHECKSUM, TEST_SMALL_DOCUMENT_PATH
 )
+from mayan.apps.testing.tests.base import GenericViewTestCase
 
-from ..literals import SOURCE_CHOICE_WEB_FORM, SOURCE_UNCOMPRESS_CHOICE_Y
+from ..literals import SOURCE_UNCOMPRESS_CHOICE_Y
 from ..models import WebFormSource
 from ..permissions import (
     permission_sources_setup_create, permission_sources_setup_delete,
@@ -21,9 +21,9 @@ from ..permissions import (
 
 from .literals import TEST_SOURCE_LABEL, TEST_SOURCE_UNCOMPRESS_N
 from .mixins import (
-    DocumentUploadWizardViewTestMixin, DocumentVersionUploadViewTestMixin,
-    StagingFolderTestMixin, StagingFolderViewTestMixin, SourceTestMixin,
-    SourceViewTestMixin
+    DocumentUploadIssueTestMixin, DocumentUploadWizardViewTestMixin,
+    DocumentVersionUploadViewTestMixin, StagingFolderTestMixin,
+    StagingFolderViewTestMixin, SourceTestMixin, SourceViewTestMixin
 )
 
 
@@ -86,7 +86,7 @@ class DocumentUploadWizardViewTestCase(
             obj=self.test_document_type, permission=permission_document_create
         )
 
-        with open(TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
             response = self.post(
                 viewname='sources:document_upload_interactive', kwargs={
                     'source_id': self.test_source.pk
@@ -125,41 +125,22 @@ class DocumentUploadWizardViewTestCase(
         )
 
 
-class DocumentUploadIssueTestCase(GenericDocumentViewTestCase):
+class DocumentUploadIssueTestCase(
+    DocumentUploadIssueTestMixin, GenericDocumentViewTestCase
+):
     auto_upload_test_document = False
     auto_login_superuser = True
     auto_login_user = False
     create_test_case_superuser = True
     create_test_case_user = False
 
-    def _request_test_source_create_view(self):
-        return self.post(
-            viewname='sources:setup_source_create', kwargs={
-                'source_type_name': SOURCE_CHOICE_WEB_FORM
-            }, data={
-                'enabled': True, 'label': 'test', 'uncompress': 'n'
-            }
-        )
-
-    def _request_test_source_edit_view(self):
-        return self.post(
-            viewname='documents:document_edit', kwargs={
-                'document_id': self.test_document.pk
-            },
-            data={
-                'description': TEST_DOCUMENT_DESCRIPTION,
-                'label': self.test_document.label,
-                'language': self.test_document.language
-            }
-        )
-
     def test_issue_25(self):
         # Create new webform source
         self._request_test_source_create_view()
         self.assertEqual(WebFormSource.objects.count(), 1)
 
         # Upload the test document
-        with open(TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
             self.post(
                 viewname='sources:document_upload_interactive', data={
                     'document-language': 'eng',
@@ -193,7 +174,7 @@ class DocumentVersionUploadViewTestCase(
     def test_document_version_upload_view_no_permission(self):
         version_count = self.test_document.versions.count()
 
-        with open(TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
             response = self._request_document_version_upload_view(
                 source_file=file_object
             )
@@ -211,7 +192,7 @@ class DocumentVersionUploadViewTestCase(
         )
         version_count = self.test_document.versions.count()
 
-        with open(TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
             response = self._request_document_version_upload_view(
                 source_file=file_object
             )
@@ -225,7 +206,7 @@ class DocumentVersionUploadViewTestCase(
     def test_document_version_upload_no_source_view_no_permission(self):
         version_count = self.test_document.versions.count()
 
-        with open(TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
             response = self._request_document_version_upload_no_source_view(
                 source_file=file_object
             )
@@ -243,7 +224,7 @@ class DocumentVersionUploadViewTestCase(
         )
         version_count = self.test_document.versions.count()
 
-        with open(TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
             response = self._request_document_version_upload_no_source_view(
                 source_file=file_object
             )
