@@ -9,13 +9,7 @@ from django.utils.encoding import force_text
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.acls.models import AccessControlList
-from mayan.apps.common.generics import (
-    ConfirmView, MultiFormView, SingleObjectCreateView,
-    SingleObjectDeleteView, SingleObjectEditView, SingleObjectListView
-)
 from mayan.apps.common.menus import menu_facet
-from mayan.apps.common.mixins import ExternalObjectMixin
-from mayan.apps.common.models import SharedUploadedFile
 from mayan.apps.documents.models import (
     DocumentType, Document, DocumentVersion
 )
@@ -24,14 +18,19 @@ from mayan.apps.documents.permissions import (
 )
 from mayan.apps.documents.tasks import task_upload_new_version
 from mayan.apps.navigation.classes import Link
+from mayan.apps.storage.models import SharedUploadedFile
+from mayan.apps.views.generics import (
+    ConfirmView, MultiFormView, SingleObjectCreateView,
+    SingleObjectDeleteView, SingleObjectEditView, SingleObjectListView
+)
+from mayan.apps.views.mixins import ExternalObjectMixin
 
 from .exceptions import SourceException
 from .forms import (
     NewDocumentForm, NewVersionForm, WebFormUploadForm, WebFormUploadFormHTML5
 )
 from .icons import (
-    icon_log, icon_setup_sources, icon_staging_folder_file,
-    icon_upload_view_link
+    icon_setup_sources, icon_staging_folder_file, icon_upload_view_link
 )
 from .literals import SOURCE_UNCOMPRESS_CHOICE_ASK, SOURCE_UNCOMPRESS_CHOICE_Y
 from .links import (
@@ -59,9 +58,9 @@ class SourceCheckView(ExternalObjectMixin, ConfirmView):
     Trigger the task_check_interval_source task for a given source to
     test/debug their configuration irrespective of the schedule task setup.
     """
+    external_object_permission = permission_sources_setup_create
     external_object_pk_url_kwarg = 'source_id'
     external_object_queryset = Source.objects.select_subclasses()
-    external_object_permission = permission_sources_setup_create
 
     def get_extra_context(self):
         return {
@@ -112,9 +111,9 @@ class SourceCreateView(SingleObjectCreateView):
 
 
 class SourceDeleteView(ExternalObjectMixin, SingleObjectDeleteView):
-    external_object_queryset = Source.objects.select_subclasses()
     external_object_permission = permission_sources_setup_delete
     external_object_pk_url_kwarg = 'source_id'
+    external_object_queryset = Source.objects.select_subclasses()
     post_action_redirect = reverse_lazy(
         viewname='sources:setup_source_list'
     )
@@ -133,9 +132,9 @@ class SourceDeleteView(ExternalObjectMixin, SingleObjectDeleteView):
 
 
 class SourceEditView(ExternalObjectMixin, SingleObjectEditView):
-    external_object_queryset = Source.objects.select_subclasses()
     external_object_permission = permission_sources_setup_edit
     external_object_pk_url_kwarg = 'source_id'
+    external_object_queryset = Source.objects.select_subclasses()
     post_action_redirect = reverse_lazy(
         viewname='sources:setup_source_list'
     )
@@ -194,28 +193,6 @@ class SourceListView(SingleObjectListView):
         }
 
 
-class SourceLogListView(ExternalObjectMixin, SingleObjectListView):
-    external_object_queryset = Source.objects.select_subclasses()
-    external_object_permission = permission_sources_setup_view
-    external_object_pk_url_kwarg = 'source_id'
-
-    def get_extra_context(self):
-        return {
-            'hide_object': True,
-            'no_results_icon': icon_log,
-            'no_results_text': _(
-                'Any error produced during the usage of a source will be '
-                'listed here to assist in debugging.'
-            ),
-            'no_results_title': _('No log entries available'),
-            'object': self.external_object,
-            'title': _('Log entries for source: %s') % self.external_object,
-        }
-
-    def get_source_queryset(self):
-        return self.external_object.logs.all()
-
-
 class StagingFileDeleteView(ExternalObjectMixin, SingleObjectDeleteView):
     external_object_class = StagingFolderSource
     external_object_permission = permission_staging_file_delete
