@@ -19,7 +19,7 @@ def NamedTemporaryFile(*args, **kwargs):
     return tempfile.NamedTemporaryFile(*args, **kwargs)
 
 
-class PassthroughStorageProcessor(object):
+class PassthroughStorageProcessor:
     def __init__(
         self, app_label, defined_storage_name, log_file, model_name,
         file_attribute='file'
@@ -61,7 +61,7 @@ class PassthroughStorageProcessor(object):
             )
             content_type = ContentType.objects.get_for_model(model=model)
 
-            self.database = dbm.open(self.log_file, flag='c')
+            self.database = dbm.open(file=self.log_file, flag='c')
 
             for instance in model.objects.all():
                 key = '{}.{}'.format(content_type.name, instance.pk)
@@ -136,6 +136,11 @@ def mkdtemp(*args, **kwargs):
 
 
 def mkstemp(*args, **kwargs):
+    """
+    Creates a temporary file in the most secure manner possible.
+    There are no race conditions in the file’s creation, assuming that
+    the platform properly implements the os.O_EXCL flag for os.open().
+    """
     kwargs.update({'dir': setting_temporary_directory.value})
     return tempfile.mkstemp(*args, **kwargs)
 
