@@ -6,12 +6,13 @@ from mayan.apps.acls.classes import ModelPermission
 from mayan.apps.acls.links import link_acl_list
 from mayan.apps.acls.permissions import permission_acl_edit, permission_acl_view
 from mayan.apps.common.apps import MayanAppConfig
-from mayan.apps.common.classes import ModelFieldRelated
+from mayan.apps.common.classes import (
+    ModelCopy, ModelFieldRelated, ModelQueryFields
+)
 from mayan.apps.common.menus import (
     menu_facet, menu_list_facet, menu_main, menu_multi_item, menu_object,
     menu_secondary
 )
-from mayan.apps.documents.search import document_page_search, document_search
 from mayan.apps.events.classes import EventModelRegistry, ModelEventType
 from mayan.apps.events.links import (
     link_events_for_object, link_object_event_types_user_subcriptions_list,
@@ -20,7 +21,7 @@ from mayan.apps.events.permissions import permission_events_view
 from mayan.apps.navigation.classes import SourceColumn
 
 from .events import (
-    event_tag_attach, event_tag_edited, event_tag_remove
+    event_tag_attach, event_tag_edited, event_tag_removed
 )
 from .handlers import handler_index_document, handler_tag_pre_delete
 from .html_widgets import widget_document_tags
@@ -37,7 +38,6 @@ from .permissions import (
     permission_tag_attach, permission_tag_delete, permission_tag_edit,
     permission_tag_remove, permission_tag_view
 )
-from .search import tag_search  # NOQA
 
 
 class TagsApp(MayanAppConfig):
@@ -68,9 +68,17 @@ class TagsApp(MayanAppConfig):
 
         EventModelRegistry.register(model=Tag)
 
+        ModelCopy(
+            model=Tag, bind_link=True, register_permission=True
+        ).add_fields(
+            field_names=(
+                'label', 'color', 'documents',
+            ),
+        )
+
         ModelEventType.register(
             model=Tag, event_types=(
-                event_tag_attach, event_tag_edited, event_tag_remove
+                event_tag_attach, event_tag_edited, event_tag_removed
             )
         )
 
@@ -93,6 +101,12 @@ class TagsApp(MayanAppConfig):
             )
         )
 
+        model_query_fields_document = ModelQueryFields.get(model=Document)
+        model_query_fields_document.add_prefetch_related_field(field_name='tags')
+
+        model_query_fields_tag = ModelQueryFields.get(model=Tag)
+        model_query_fields_tag.add_prefetch_related_field(field_name='documents')
+
         SourceColumn(
             attribute='label', is_identifier=True, is_sortable=True,
             source=DocumentTag
@@ -124,11 +138,6 @@ class TagsApp(MayanAppConfig):
             ), include_label=True, label=_('Documents'), source=Tag
         )
 
-        document_page_search.add_model_field(
-            field='document_version__document__tags__label', label=_('Tags')
-        )
-        document_search.add_model_field(field='tags__label', label=_('Tags'))
-
         menu_facet.bind_links(
             links=(link_document_tag_list,), sources=(Document,)
         )
