@@ -13,6 +13,6 @@ event_tag_created = namespace.add_event_type(
 event_tag_edited = namespace.add_event_type(
     label=_('Tag edited'), name='tag_edited'
 )
-event_tag_remove = namespace.add_event_type(
+event_tag_removed = namespace.add_event_type(
     label=_('Tag removed from document'), name='remove'
 )
