@@ -1,6 +1,5 @@
 from django.db import models, transaction
 from django.urls import reverse
-from django.utils.encoding import python_2_unicode_compatible
 from django.utils.translation import ugettext_lazy as _
 
 from colorful.fields import RGBColorField
@@ -10,12 +9,11 @@ from mayan.apps.documents.models import Document
 from mayan.apps.documents.permissions import permission_document_view
 
 from .events import (
-    event_tag_attach, event_tag_created, event_tag_edited, event_tag_remove
+    event_tag_attach, event_tag_created, event_tag_edited, event_tag_removed
 )
 from .html_widgets import widget_single_tag
 
 
-@python_2_unicode_compatible
 class Tag(models.Model):
     """
     This model represents a binary property that can be applied to a document.
@@ -86,7 +84,7 @@ class Tag(models.Model):
         Remove a tag from a document and commit the corresponding event.
         """
         self.documents.remove(document)
-        event_tag_remove.commit(
+        event_tag_removed.commit(
             action_object=self, actor=user, target=document
         )
 
