@@ -45,9 +45,11 @@ class WritableTagSerializer(serializers.ModelSerializer):
         model = Tag
 
     def _add_documents(self, documents_pk_list, instance):
-        instance.documents.add(
-            *Document.objects.filter(pk__in=documents_pk_list.split(','))
-        )
+        for document in Document.objects.filter(pk__in=documents_pk_list.split(',')):
+            instance.attach_to(
+                document=document,
+                user=self.context['request'].user
+            )
 
     def create(self, validated_data):
         documents_pk_list = validated_data.pop('documents_pk_list', '')
@@ -110,6 +112,9 @@ class NewDocumentTagSerializer(serializers.Serializer):
         )
         tag = get_object_or_404(klass=queryset, pk=validated_data['tag_pk'])
 
-        tag.documents.add(validated_data['document'])
+        tag.attach_to(
+            document=validated_data['document'],
+            user=self.context['request'].user
+        )
 
         return {'tag_pk': tag.pk}
