@@ -8,7 +8,7 @@ from .literals import (
 )
 
 
-class DocumentTagViewTestMixin(object):
+class DocumentTagViewTestMixin:
     def _request_test_document_tag_attach_view(self):
         return self.post(
             viewname='tags:tag_attach', kwargs={
@@ -52,7 +52,7 @@ class DocumentTagViewTestMixin(object):
         )
 
 
-class TagAPIViewTestMixin(object):
+class TagAPIViewTestMixin:
     def _request_test_document_attach_tag_api_view(self):
         return self.post(
             viewname='rest_api:document-tag-list', kwargs={
@@ -82,12 +82,18 @@ class TagAPIViewTestMixin(object):
         )
 
     def _request_test_tag_create_api_view(self):
-        return self.post(
+        pk_list = list(Tag.objects.values_list('pk', flat=True))
+
+        response = self.post(
             viewname='rest_api:tag-list', data={
                 'label': TEST_TAG_LABEL, 'color': TEST_TAG_COLOR
             }
         )
 
+        self.test_tag = Tag.objects.exclude(pk__in=pk_list).first()
+
+        return response
+
     def _request_test_tag_delete_api_view(self):
         return self.delete(
             viewname='rest_api:tag-detail', kwargs={'pk': self.test_tag.pk}
@@ -123,11 +129,13 @@ class TagAPIViewTestMixin(object):
         return self.get(viewname='rest_api:tag-list')
 
 
-class TagTestMixin(object):
-    def _create_test_tag(self):
+class TagTestMixin:
+    def _create_test_tag(self, add_test_document=False):
         self.test_tag = Tag.objects.create(
             color=TEST_TAG_COLOR, label=TEST_TAG_LABEL
         )
+        if add_test_document:
+            self.test_tag.documents.add(self.test_document)
 
     def _create_test_tag_2(self):
         self.test_tag_2 = Tag.objects.create(
@@ -135,7 +143,7 @@ class TagTestMixin(object):
         )
 
 
-class TagViewTestMixin(object):
+class TagViewTestMixin:
     def _request_test_tag_create_view(self):
         return self.post(
             viewname='tags:tag_create', data={
@@ -176,9 +184,9 @@ class TagViewTestMixin(object):
         return self.get(viewname='tags:tag_list')
 
 
-class TaggedDocumentUploadViewTestMixin(object):
+class TaggedDocumentUploadViewTestMixin:
     def _request_upload_interactive_document_create_view(self):
-        with open(TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
             return self.post(
                 viewname='sources:document_upload_interactive', kwargs={
                     'source_id': self.test_source.pk
