@@ -4,8 +4,12 @@ from rest_framework import status
 
 from mayan.apps.documents.permissions import permission_document_view
 from mayan.apps.documents.tests.mixins import DocumentTestMixin
+from mayan.apps.events.tests.mixins import EventTestCaseMixin
 from mayan.apps.rest_api.tests.base import BaseAPITestCase
 
+from ..events import (
+    event_tag_attach, event_tag_created, event_tag_edited, event_tag_removed
+)
 from ..models import Tag
 from ..permissions import (
     permission_tag_attach, permission_tag_create, permission_tag_delete,
@@ -15,7 +19,11 @@ from ..permissions import (
 from .mixins import TagAPIViewTestMixin, TagTestMixin
 
 
-class TagAPIViewTestCase(TagAPIViewTestMixin, TagTestMixin, BaseAPITestCase):
+class TagAPIViewTestCase(
+    EventTestCaseMixin, TagAPIViewTestMixin, TagTestMixin, BaseAPITestCase
+):
+    _test_event_object_name = 'test_tag'
+
     def test_tag_create_view_no_permission(self):
         tag_count = Tag.objects.count()
 
@@ -24,6 +32,9 @@ class TagAPIViewTestCase(TagAPIViewTestMixin, TagTestMixin, BaseAPITestCase):
 
         self.assertEqual(Tag.objects.count(), tag_count)
 
+        event = self._get_test_object_event()
+        self.assertEqual(event, None)
+
     def test_tag_create_view_with_permission(self):
         self.grant_permission(permission=permission_tag_create)
 
@@ -34,7 +45,10 @@ class TagAPIViewTestCase(TagAPIViewTestMixin, TagTestMixin, BaseAPITestCase):
 
         self.assertEqual(Tag.objects.count(), tag_count + 1)
 
-    def test_tag_delete_view_no_access(self):
+        event = self._get_test_object_event()
+        self.assertEqual(event.verb, event_tag_created.id)
+
+    def test_tag_delete_view_no_permission(self):
         self._create_test_tag()
 
         tag_count = Tag.objects.count()
@@ -73,7 +87,7 @@ class TagAPIViewTestCase(TagAPIViewTestMixin, TagTestMixin, BaseAPITestCase):
 
         self.assertEqual(response.data['label'], self.test_tag.label)
 
-    def test_tag_edit_via_patch_no_access(self):
+    def test_tag_edit_via_patch_no_permission(self):
         self._create_test_tag()
 
         tag_label = self.test_tag.label
@@ -86,6 +100,9 @@ class TagAPIViewTestCase(TagAPIViewTestMixin, TagTestMixin, BaseAPITestCase):
         self.assertEqual(self.test_tag.label, tag_label)
         self.assertEqual(self.test_tag.color, tag_color)
 
+        event = self._get_test_object_event()
+        self.assertEqual(event.verb, event_tag_created.id)
+
     def test_tag_edit_via_patch_with_access(self):
         self._create_test_tag()
 
@@ -101,7 +118,10 @@ class TagAPIViewTestCase(TagAPIViewTestMixin, TagTestMixin, BaseAPITestCase):
         self.assertNotEqual(self.test_tag.label, tag_label)
         self.assertNotEqual(self.test_tag.color, tag_color)
 
-    def test_tag_edit_via_put_no_access(self):
+        event = self._get_test_object_event()
+        self.assertEqual(event.verb, event_tag_edited.id)
+
+    def test_tag_edit_via_put_no_permission(self):
         self._create_test_tag()
 
         tag_label = self.test_tag.label
@@ -114,6 +134,9 @@ class TagAPIViewTestCase(TagAPIViewTestMixin, TagTestMixin, BaseAPITestCase):
         self.assertEqual(self.test_tag.label, tag_label)
         self.assertEqual(self.test_tag.color, tag_color)
 
+        event = self._get_test_object_event()
+        self.assertEqual(event.verb, event_tag_created.id)
+
     def test_tag_edit_via_put_with_access(self):
         self._create_test_tag()
 
@@ -129,6 +152,9 @@ class TagAPIViewTestCase(TagAPIViewTestMixin, TagTestMixin, BaseAPITestCase):
         self.assertNotEqual(self.test_tag.label, tag_label)
         self.assertNotEqual(self.test_tag.color, tag_color)
 
+        event = self._get_test_object_event()
+        self.assertEqual(event.verb, event_tag_edited.id)
+
     def test_tag_list_api_view_no_permission(self):
         self._create_test_tag()
         response = self._request_test_tag_list_api_view()
@@ -150,21 +176,24 @@ class TagAPIViewTestCase(TagAPIViewTestMixin, TagTestMixin, BaseAPITestCase):
 
 
 class TagDocumentAPIViewTestCase(
-    DocumentTestMixin, TagAPIViewTestMixin, TagTestMixin, BaseAPITestCase
+    DocumentTestMixin, EventTestCaseMixin, TagAPIViewTestMixin, TagTestMixin,
+    BaseAPITestCase
 ):
+    _test_event_object_name = 'test_tag'
     auto_upload_test_document = False
 
-    def test_tag_document_list_view_no_access(self):
-        self._create_test_tag()
+    def setUp(self):
+        super().setUp()
         self._upload_test_document()
+        self._create_test_tag()
+
+    def test_tag_document_list_view_no_permission(self):
         self.test_tag.documents.add(self.test_document)
 
         response = self._request_test_tag_document_list_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_tag_document_list_view_with_tag_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
         self.test_tag.documents.add(self.test_document)
 
         self.grant_access(obj=self.test_tag, permission=permission_tag_view)
@@ -175,8 +204,6 @@ class TagDocumentAPIViewTestCase(
         self.assertEqual(response.data['count'], 0)
 
     def test_tag_document_list_view_with_document_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
         self.test_tag.documents.add(self.test_document)
 
         self.grant_access(
@@ -186,8 +213,6 @@ class TagDocumentAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_tag_document_list_view_with_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
         self.test_tag.documents.add(self.test_document)
 
         self.grant_access(obj=self.test_tag, permission=permission_tag_view)
@@ -202,19 +227,16 @@ class TagDocumentAPIViewTestCase(
             force_text(self.test_document.uuid)
         )
 
-    def test_document_attach_tag_view_no_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
-
+    def test_document_attach_tag_view_no_permission(self):
         response = self._request_test_document_attach_tag_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertTrue(self.test_tag not in self.test_document.tags.all())
 
-    def test_document_attach_tag_view_with_document_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
+        event = self._get_test_object_event()
+        self.assertEqual(event.verb, event_tag_created.id)
 
+    def test_document_attach_tag_view_with_document_access(self):
         self.grant_access(
             obj=self.test_document, permission=permission_tag_attach
         )
@@ -224,10 +246,10 @@ class TagDocumentAPIViewTestCase(
 
         self.assertTrue(self.test_tag not in self.test_document.tags.all())
 
-    def test_document_attach_tag_view_with_tag_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
+        event = self._get_test_object_event()
+        self.assertEqual(event.verb, event_tag_created.id)
 
+    def test_document_attach_tag_view_with_tag_access(self):
         self.grant_access(
             obj=self.test_tag, permission=permission_tag_attach
         )
@@ -237,10 +259,10 @@ class TagDocumentAPIViewTestCase(
 
         self.assertTrue(self.test_tag not in self.test_document.tags.all())
 
-    def test_document_attach_tag_view_with_full_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
+        event = self._get_test_object_event()
+        self.assertEqual(event.verb, event_tag_created.id)
 
+    def test_document_attach_tag_view_with_full_access(self):
         self.grant_access(
             obj=self.test_document, permission=permission_tag_attach
         )
@@ -253,17 +275,16 @@ class TagDocumentAPIViewTestCase(
 
         self.assertTrue(self.test_tag in self.test_document.tags.all())
 
-    def test_document_tag_detail_view_no_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
+        event = self._get_test_object_event()
+        self.assertEqual(event.verb, event_tag_attach.id)
+
+    def test_document_tag_detail_view_no_permission(self):
         self.test_tag.documents.add(self.test_document)
 
         response = self._request_test_document_tag_detail_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_document_tag_detail_view_with_document_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
         self.test_tag.documents.add(self.test_document)
 
         self.grant_access(
@@ -274,8 +295,6 @@ class TagDocumentAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_document_tag_detail_view_with_tag_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
         self.test_tag.documents.add(self.test_document)
 
         self.grant_access(obj=self.test_tag, permission=permission_tag_view)
@@ -284,8 +303,6 @@ class TagDocumentAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_document_tag_detail_view_with_full_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
         self.test_tag.documents.add(self.test_document)
 
         self.grant_access(obj=self.test_tag, permission=permission_tag_view)
@@ -297,17 +314,13 @@ class TagDocumentAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(response.data['label'], self.test_tag.label)
 
-    def test_document_tag_list_view_no_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
+    def test_document_tag_list_view_no_permission(self):
         self.test_tag.documents.add(self.test_document)
 
         response = self._request_test_document_tag_list_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_document_tag_list_view_with_document_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
         self.test_tag.documents.add(self.test_document)
 
         self.grant_access(
@@ -319,8 +332,6 @@ class TagDocumentAPIViewTestCase(
         self.assertEqual(response.data['count'], 0)
 
     def test_document_tag_list_view_with_tag_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
         self.test_tag.documents.add(self.test_document)
 
         self.grant_access(obj=self.test_tag, permission=permission_tag_view)
@@ -329,8 +340,6 @@ class TagDocumentAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_document_tag_list_view_with_full_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
         self.test_tag.documents.add(self.test_document)
 
         self.grant_access(
@@ -342,9 +351,7 @@ class TagDocumentAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(response.data['results'][0]['label'], self.test_tag.label)
 
-    def test_document_tag_remove_view_no_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
+    def test_document_tag_remove_view_no_permission(self):
         self.test_tag.documents.add(self.test_document)
 
         response = self._request_test_document_tag_remove_api_view()
@@ -352,9 +359,10 @@ class TagDocumentAPIViewTestCase(
 
         self.assertTrue(self.test_tag in self.test_document.tags.all())
 
+        event = self._get_test_object_event()
+        self.assertEqual(event.verb, event_tag_created.id)
+
     def test_document_tag_remove_view_with_document_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
         self.test_tag.documents.add(self.test_document)
 
         self.grant_access(
@@ -366,9 +374,10 @@ class TagDocumentAPIViewTestCase(
 
         self.assertTrue(self.test_tag in self.test_document.tags.all())
 
+        event = self._get_test_object_event()
+        self.assertEqual(event.verb, event_tag_created.id)
+
     def test_document_tag_remove_view_with_tag_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
         self.test_tag.documents.add(self.test_document)
 
         self.grant_access(obj=self.test_tag, permission=permission_tag_remove)
@@ -378,9 +387,10 @@ class TagDocumentAPIViewTestCase(
 
         self.assertTrue(self.test_tag in self.test_document.tags.all())
 
+        event = self._get_test_object_event()
+        self.assertEqual(event.verb, event_tag_created.id)
+
     def test_document_tag_remove_view_with_full_access(self):
-        self._create_test_tag()
-        self._upload_test_document()
         self.test_tag.documents.add(self.test_document)
 
         self.grant_access(
@@ -392,3 +402,15 @@ class TagDocumentAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
 
         self.assertFalse(self.test_tag in self.test_document.tags.all())
+
+        event = self._get_test_object_event()
+        self.assertEqual(event.verb, event_tag_removed.id)
+
+
+class TagDocumentStubAPIViewTestCase(TagDocumentAPIViewTestCase):
+    auto_upload_document = False
+
+    def setUp(self):
+        super().setUp()
+        self._create_test_document_stub()
+        self.test_document = self.test_document_stub
