@@ -1,30 +1,28 @@
-from mayan.apps.common.tests.base import BaseTestCase
 from mayan.apps.documents.tests.mixins import DocumentTestMixin
+from mayan.apps.testing.tests.base import BaseTestCase
 
 from .mixins import TagTestMixin
 
 
-class TagTestCase(DocumentTestMixin, TagTestMixin, BaseTestCase):
-    auto_upload_test_document = False
-
+class TagDocumentTestCase(DocumentTestMixin, TagTestMixin, BaseTestCase):
     def test_document_addition(self):
         self._create_test_tag()
-        self._upload_test_document()
 
-        self.test_tag.documents.add(self.test_document)
+        self.test_tag.attach_to(document=self.test_document)
 
         self.assertTrue(self.test_document in self.test_tag.documents.all())
 
     def test_document_remove(self):
-        self._create_test_tag()
-        self._upload_test_document()
+        self._create_test_tag(add_test_document=True)
 
-        self.test_tag.documents.remove(self.test_document)
+        self.test_tag.remove_from(document=self.test_document)
 
         self.assertTrue(
             self.test_document not in self.test_tag.documents.all()
         )
 
+
+class TagModuelTestCase(TagTestMixin, BaseTestCase):
     def test_method_get_absolute_url(self):
         self._create_test_tag()
 
