@@ -12,10 +12,8 @@ from .mixins import TagTestMixin
 class DocumentTagHTMLWidgetTestCase(
     DocumentViewTestMixin, TagTestMixin, GenericDocumentViewTestCase
 ):
-    def test_document_tags_widget_no_permissions(self):
-        self._create_test_tag()
-
-        self.test_tag.documents.add(self.test_document)
+    def test_document_tags_widget_no_permission(self):
+        self._create_test_tag(add_test_document=True)
 
         response = self._request_test_document_list_view()
         self.assertNotContains(
@@ -26,9 +24,7 @@ class DocumentTagHTMLWidgetTestCase(
         )
 
     def test_document_tags_widget_with_document_access(self):
-        self._create_test_tag()
-
-        self.test_tag.documents.add(self.test_document)
+        self._create_test_tag(add_test_document=True)
 
         self.grant_access(
             obj=self.test_document, permission=permission_document_view
@@ -43,9 +39,7 @@ class DocumentTagHTMLWidgetTestCase(
         )
 
     def test_document_tags_widget_with_tag_access(self):
-        self._create_test_tag()
-
-        self.test_tag.documents.add(self.test_document)
+        self._create_test_tag(add_test_document=True)
 
         self.grant_access(
             obj=self.test_tag, permission=permission_tag_view
@@ -60,9 +54,7 @@ class DocumentTagHTMLWidgetTestCase(
         )
 
     def test_document_tags_widget_with_full_access(self):
-        self._create_test_tag()
-
-        self.test_tag.documents.add(self.test_document)
+        self._create_test_tag(add_test_document=True)
 
         self.grant_access(
             obj=self.test_document, permission=permission_document_view
