@@ -7,18 +7,17 @@ from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _, ungettext
 
 from mayan.apps.acls.models import AccessControlList
-from mayan.apps.common.generics import (
+from mayan.apps.common.classes import ModelQueryFields
+from mayan.apps.documents.models import Document
+from mayan.apps.documents.views.document_views import DocumentListView
+from mayan.apps.views.generics import (
     MultipleObjectFormActionView, MultipleObjectConfirmActionView,
     SingleObjectCreateView, SingleObjectEditView, SingleObjectListView
 )
-from mayan.apps.common.mixins import ExternalObjectMixin
-from mayan.apps.documents.models import Document
-from mayan.apps.documents.views.document_views import DocumentListView
+from mayan.apps.views.mixins import ExternalObjectMixin
 
 from .forms import TagMultipleSelectionForm
-from .icons import (
-    icon_menu_tags, icon_tag_delete_submit, icon_document_tag_remove_submit
-)
+from .icons import icon_menu_tags, icon_document_tag_remove_submit
 from .links import link_document_tag_multiple_attach, link_tag_create
 from .models import Tag
 from .permissions import (
@@ -151,13 +150,12 @@ class TagDeleteActionView(MultipleObjectConfirmActionView):
         queryset = self.object_list
 
         result = {
+            'delete_view': True,
             'message': _('Will be removed from all documents.'),
-            'submit_icon_class': icon_tag_delete_submit,
-            'submit_label': _('Delete'),
             'title': ungettext(
-                'Delete the selected tag?',
-                'Delete the selected tags?',
-                queryset.count()
+                singular='Delete the selected tag?',
+                plural='Delete the selected tags?',
+                number=queryset.count()
             )
         }
 
@@ -165,7 +163,7 @@ class TagDeleteActionView(MultipleObjectConfirmActionView):
             result.update(
                 {
                     'object': queryset.first(),
-                    'title': _('Delete tag: %s') % queryset.first()
+                    'title': _('Delete tag: %s?') % queryset.first()
                 }
             )
 
@@ -224,7 +222,8 @@ class TagListView(SingleObjectListView):
         }
 
     def get_source_queryset(self):
-        return self.get_tag_queryset()
+        queryset = ModelQueryFields.get(model=Tag).get_queryset()
+        return queryset.filter(pk__in=self.get_tag_queryset())
 
     def get_tag_queryset(self):
         return Tag.objects.all()
@@ -276,7 +275,7 @@ class DocumentTagListView(ExternalObjectMixin, TagListView):
         )
         return context
 
-    def get_source_queryset(self):
+    def get_tag_queryset(self):
         return self.external_object.get_tags(
             permission=permission_tag_view, user=self.request.user
         )
