@@ -1,13 +1,12 @@
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.common.apps import MayanAppConfig
-from mayan.apps.common.html_widgets import TwoStateWidget
 from mayan.apps.common.menus import menu_tools
 from mayan.apps.navigation.classes import SourceColumn
+from mayan.apps.views.html_widgets import TwoStateWidget
 
 from .classes import CeleryQueue, Task
 from .links import link_task_manager
-from .settings import *  # NOQA
 
 
 class TaskManagerApp(MayanAppConfig):
@@ -19,7 +18,7 @@ class TaskManagerApp(MayanAppConfig):
     def ready(self):
         super(TaskManagerApp, self).ready()
 
-        CeleryQueue.initialize()
+        CeleryQueue.load_modules()
 
         SourceColumn(
             attribute='label', is_identifier=True, label=_('Label'),
