@@ -1,19 +1,17 @@
-from importlib import import_module
 import logging
 
 from kombu import Exchange, Queue
 
-from django.apps import apps
-from django.utils.encoding import force_text, python_2_unicode_compatible
+from django.utils.encoding import force_text
 from django.utils.module_loading import import_string
 
+from mayan.apps.common.class_mixins import AppsModuleLoaderMixin
 from mayan.celery import app as celery_app
 
 logger = logging.getLogger(name=__name__)
 
 
-@python_2_unicode_compatible
-class TaskType(object):
+class TaskType:
     _registry = {}
 
     @classmethod
@@ -46,8 +44,7 @@ class TaskType(object):
             raise
 
 
-@python_2_unicode_compatible
-class Task(object):
+class Task:
     def __init__(self, task_type, kwargs):
         self.task_type = task_type
         self.kwargs = kwargs
@@ -56,25 +53,10 @@ class Task(object):
         return force_text(self.task_type)
 
 
-@python_2_unicode_compatible
-class CeleryQueue(object):
+class CeleryQueue(AppsModuleLoaderMixin):
+    _loader_module_name = 'queues'
     _registry = {}
 
-    @staticmethod
-    def initialize():
-        for app in apps.get_app_configs():
-            try:
-                import_module('{}.queues'.format(app.name))
-            except ImportError as exception:
-                if force_text(exception) not in ('No module named queues', 'No module named \'{}.queues\''.format(app.name)):
-                    logger.error(
-                        'Error importing %s queues.py file; %s', app.name,
-                        exception
-                    )
-                    raise
-
-        CeleryQueue.update_celery()
-
     @classmethod
     def all(cls):
         return sorted(
@@ -85,6 +67,11 @@ class CeleryQueue(object):
     def get(cls, queue_name):
         return cls._registry[queue_name]
 
+    @classmethod
+    def load_modules(cls):
+        super().load_modules()
+        CeleryQueue.update_celery()
+
     @classmethod
     def update_celery(cls):
         for instance in cls.all():
@@ -151,7 +138,7 @@ class CeleryQueue(object):
                 )
 
 
-class Worker(object):
+class Worker:
     _registry = {}
 
     @classmethod
