@@ -2,17 +2,16 @@ from django.apps import apps
 from django.contrib.auth import get_user_model
 from django.contrib.auth.signals import user_logged_in, user_logged_out
 from django.db.models.signals import post_save
-from django.utils import six
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.acls.classes import ModelPermission
 from mayan.apps.acls.links import link_acl_list
 from mayan.apps.acls.permissions import permission_acl_edit, permission_acl_view
 from mayan.apps.common.apps import MayanAppConfig
-from mayan.apps.common.html_widgets import TwoStateWidget
+from mayan.apps.common.classes import ModelCopy
 from mayan.apps.common.menus import (
-    menu_list_facet, menu_multi_item, menu_object, menu_secondary, menu_setup,
-    menu_user
+    menu_list_facet, menu_multi_item, menu_object, menu_related,
+    menu_secondary, menu_setup, menu_user
 )
 from mayan.apps.dashboards.dashboards import dashboard_main
 from mayan.apps.events.classes import EventModelRegistry, ModelEventType
@@ -23,6 +22,7 @@ from mayan.apps.events.permissions import permission_events_view
 from mayan.apps.metadata.classes import MetadataLookup
 from mayan.apps.navigation.classes import SourceColumn
 from mayan.apps.rest_api.fields import DynamicSerializerField
+from mayan.apps.views.html_widgets import TwoStateWidget
 
 from .dashboard_widgets import (
     DashboardWidgetGroupTotal, DashboardWidgetUserTotal
@@ -54,7 +54,6 @@ from .permissions import (
     permission_group_view, permission_user_delete, permission_user_edit,
     permission_user_view
 )
-from .search import group_search, user_search  # NOQA
 
 
 def get_groups():
@@ -84,6 +83,7 @@ class UserManagementApp(MayanAppConfig):
 
         Group = apps.get_model(app_label='auth', model_name='Group')
         User = get_user_model()
+        UserOptions = self.get_model(model_name='UserOptions')
 
         DynamicSerializerField.add_serializer(
             klass=get_user_model(),
@@ -109,19 +109,17 @@ class UserManagementApp(MayanAppConfig):
         User._meta.verbose_name_plural = _('Users')
         User._meta.ordering = ('last_name', 'first_name')
 
-        User._meta.get_field('username').verbose_name = _('Username')
-        User._meta.get_field('first_name').verbose_name = _('First name')
-        User._meta.get_field('last_name').verbose_name = _('Last name')
         User._meta.get_field('email').verbose_name = _('Email')
+        User._meta.get_field('first_name').verbose_name = _('First name')
+        User._meta.get_field('groups').verbose_name = _('Groups')
         User._meta.get_field('is_active').verbose_name = _('Is active?')
-        if six.PY3:
-            User.has_usable_password.short_description = _(
-                'Has usable password?'
-            )
-        else:
-            User.has_usable_password.__func__.short_description = _(
-                'Has usable password?'
-            )
+        User._meta.get_field('last_name').verbose_name = _('Last name')
+        User._meta.get_field('password').verbose_name = _('Password')
+        User._meta.get_field('username').verbose_name = _('Username')
+
+        User.has_usable_password.short_description = _(
+            'Has usable password?'
+        )
 
         Group.add_to_class(
             name='get_users', value=method_group_get_users
@@ -143,6 +141,28 @@ class UserManagementApp(MayanAppConfig):
             value=get_users
         )
 
+        ModelCopy(
+            model=Group, bind_link=True, register_permission=True
+        ).add_fields(
+            field_names=(
+                'name', 'user',
+            ),
+        )
+        ModelCopy(model=UserOptions).add_fields(
+            field_names=('user', 'block_password_change'),
+            field_value_templates={
+                'id': '{user.user_options.id}'
+            }
+        )
+        ModelCopy(
+            model=User, bind_link=True, register_permission=True
+        ).add_fields(
+            field_names=(
+                'username', 'first_name', 'last_name', 'email', 'is_active',
+                'password', 'groups', 'user_options'
+            ),
+        )
+
         ModelEventType.register(
             event_types=(event_group_created, event_group_edited), model=Group
         )
@@ -251,6 +271,20 @@ class UserManagementApp(MayanAppConfig):
         menu_object.bind_links(
             links=(link_user_delete, link_user_edit,), sources=(User,)
         )
+        menu_related.bind_links(
+            links=(link_user_list,), sources=(
+                'user_management:group_multiple_delete',
+                'user_management:group_list', 'user_management:group_create',
+                Group
+            )
+        )
+        menu_related.bind_links(
+            links=(link_group_setup,), sources=(
+                User, 'authentication:user_multiple_set_password',
+                'user_management:user_multiple_delete',
+                'user_management:user_list', 'user_management:user_create'
+            )
+        )
         menu_secondary.bind_links(
             links=(link_group_list, link_group_create), sources=(
                 'user_management:group_multiple_delete',
@@ -265,6 +299,7 @@ class UserManagementApp(MayanAppConfig):
                 'user_management:user_list', 'user_management:user_create'
             )
         )
+
         menu_setup.bind_links(links=(link_user_setup, link_group_setup))
         menu_user.bind_links(
             links=(
