@@ -1,9 +1,10 @@
 from django.utils.encoding import force_text
 
-from mayan.apps.common.tests.base import GenericViewTestCase
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
+from mayan.apps.testing.tests.base import GenericViewTestCase
 
-from ..models import WebLink
+from ..links import link_web_link_instance_view
+from ..models import ResolvedWebLink, WebLink
 from ..permissions import (
     permission_web_link_create, permission_web_link_delete,
     permission_web_link_edit, permission_web_link_view,
@@ -17,7 +18,7 @@ from .mixins import WebLinkTestMixin, WebLinkViewTestMixin
 class WebLinkViewTestCase(
     WebLinkTestMixin, WebLinkViewTestMixin, GenericViewTestCase
 ):
-    def test_web_link_create_view_no_permissions(self):
+    def test_web_link_create_view_no_permission(self):
         web_link_count = WebLink.objects.count()
 
         response = self._request_test_web_link_create_view()
@@ -35,7 +36,7 @@ class WebLinkViewTestCase(
 
         self.assertEqual(WebLink.objects.count(), web_link_count + 1)
 
-    def test_web_link_delete_view_no_permissions(self):
+    def test_web_link_delete_view_no_permission(self):
         self._create_test_web_link()
 
         web_link_count = WebLink.objects.count()
@@ -59,7 +60,7 @@ class WebLinkViewTestCase(
 
         self.assertEqual(WebLink.objects.count(), web_link_count - 1)
 
-    def test_web_link_edit_view_no_permissions(self):
+    def test_web_link_edit_view_no_permission(self):
         self._create_test_web_link()
 
         web_link_label = self.test_web_link.label
@@ -109,10 +110,9 @@ class DocumentWebLinkViewTestCase(
 ):
     def setUp(self):
         super(DocumentWebLinkViewTestCase, self).setUp()
-        self._create_test_web_link()
-        self.test_web_link.document_types.add(self.test_document_type)
+        self._create_test_web_link(add_document_type=True)
 
-    def test_document_web_links_list_view_no_permissions(self):
+    def test_document_web_links_list_view_no_permission(self):
         response = self._request_test_document_web_link_list_view()
         self.assertNotContains(
             response=response, text=force_text(self.test_document),
@@ -174,8 +174,20 @@ class DocumentWebLinkViewTestCase(
             response=response, text=force_text(self.test_web_link),
             status_code=200
         )
+        # Test if a valid resolved link navigate link is present.
+        # Ensures the view is returning ResolvedWebLink proxies and not the
+        # base model WebLink.
+        context = self._get_context_from_test_response(response=response)
+        context['object'] = ResolvedWebLink.objects.get_for(
+            document=self.test_document, user=self._test_case_user
+        ).first()
+        resolved_web_link_link = link_web_link_instance_view.resolve(context=context)
+        self.assertContains(
+            response=response, text=resolved_web_link_link.url,
+            status_code=200
+        )
 
-    def test_document_resolved_web_link_view_no_permissions(self):
+    def test_document_resolved_web_link_view_no_permission(self):
         response = self._request_test_document_web_link_instance_view()
         self.assertEqual(response.status_code, 404)
 
