@@ -32,8 +32,9 @@ environment_secret_key = os.environ.get('MAYAN_SECRET_KEY')
 if environment_secret_key:
     SECRET_KEY = environment_secret_key
 else:
+    SECRET_KEY_PATH = os.path.join(MEDIA_ROOT, SYSTEM_DIR, SECRET_KEY_FILENAME)
     try:
-        with open(os.path.join(MEDIA_ROOT, SYSTEM_DIR, SECRET_KEY_FILENAME)) as file_object:  # NOQA: F821
+        with open(file=SECRET_KEY_PATH) as file_object:  # NOQA: F821
             SECRET_KEY = file_object.read().strip()
     except IOError:
         SECRET_KEY = DEFAULT_SECRET_KEY
@@ -83,6 +84,7 @@ INSTALLED_APPS = (
     'mayan.apps.events',
     'mayan.apps.file_caching',
     'mayan.apps.lock_manager',
+    'mayan.apps.logging',
     'mayan.apps.mimetype',
     'mayan.apps.navigation',
     'mayan.apps.permissions',
@@ -92,7 +94,9 @@ INSTALLED_APPS = (
     'mayan.apps.smart_settings',
     'mayan.apps.task_manager',
     'mayan.apps.templating',
+    'mayan.apps.testing',
     'mayan.apps.user_management',
+    'mayan.apps.views',
     # Project apps
     'mayan.apps.motd',
     # Document apps
@@ -121,7 +125,7 @@ INSTALLED_APPS = (
 )
 
 MIDDLEWARE = (
-    'mayan.apps.common.middleware.error_logging.ErrorLoggingMiddleware',
+    'mayan.apps.logging.middleware.error_logging.ErrorLoggingMiddleware',
     'django.middleware.security.SecurityMiddleware',
     'whitenoise.middleware.WhiteNoiseMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
@@ -236,12 +240,12 @@ STATIC_ROOT = os.environ.get(
 
 STATICFILES_FINDERS = (
     'django.contrib.staticfiles.finders.FileSystemFinder',
-    'mayan.apps.common.finders.MayanAppDirectoriesFinder',
+    'mayan.apps.views.finders.MayanAppDirectoriesFinder',
 )
 
 STATICFILES_STORAGE = 'whitenoise.storage.CompressedManifestStaticFilesStorage'
 
-TEST_RUNNER = 'mayan.apps.common.tests.runner.MayanTestRunner'
+TEST_RUNNER = 'mayan.apps.testing.runner.MayanTestRunner'
 
 # ---------- Django REST framework -----------
 
