@@ -1,8 +1,8 @@
 from .. import *  # NOQA
 
+CELERY_BROKER_URL = 'memory://'
 CELERY_TASK_ALWAYS_EAGER = True
 CELERY_TASK_EAGER_PROPAGATES = True
-BROKER_BACKEND = 'memory'
 
 COMMON_PRODUCTION_ERROR_LOG_PATH = '/tmp/mayan-errors.log'
 
@@ -10,8 +10,6 @@ DOCUMENT_PARSING_AUTO_PARSING = False
 
 FILE_METADATA_AUTO_PROCESS = False
 
-INSTALLED_APPS += ('test_without_migrations',)  # NOQA: F405
-
 INSTALLED_APPS = [
     cls for cls in INSTALLED_APPS if cls != 'whitenoise.runserver_nostatic'
 ]
